@@ -1,6 +1,6 @@
 /*
  *
- *  Copyright (C) 1994-2015, OFFIS e.V.
+ *  Copyright (C) 1994-2013, OFFIS e.V.
  *  All rights reserved.  See COPYRIGHT file for details.
  *
  *  This software and supporting documentation were developed by
@@ -320,7 +320,7 @@ searchCommentOrEol(char *s)
 }
 
 
-static void
+static char *
 convertNewlineCharacters(char *s)
 {
     // convert the string "\n" into the \r\n combination required by DICOM
@@ -329,6 +329,7 @@ convertNewlineCharacters(char *s)
         *s = '\r';
         *++s = '\n';
     }
+    return s;
 }
 
 static OFBool
@@ -350,7 +351,7 @@ parseValue(char *&s, char *&value, DcmEVR &vr, const DcmTagKey &tagkey)
             {
                 value = new char[len - 1];
                 OFStandard::strlcpy(value, s + 1, len - 1);
-                convertNewlineCharacters(value);
+                value = convertNewlineCharacters(value);
             }
             else
                 value = NULL;
@@ -524,7 +525,7 @@ insertIntoSet(DcmStack &stack, const E_TransferSyntax xfer, const DcmTagKey &tag
         if (newTagVR == EVR_pixelSQ)
             newElement = new DcmPixelData(tag);
         else if (newTagVR == EVR_pixelItem)
-            newElement = new DcmPixelItem(DCM_PixelItemTag);
+            newElement = new DcmPixelItem(DcmTag(DCM_Item, EVR_OB));
         else
             newElementError = newDicomElement(newElement, tag);
 
@@ -574,7 +575,7 @@ insertIntoSet(DcmStack &stack, const E_TransferSyntax xfer, const DcmTagKey &tag
                               // special handling for pixel sequence
                               if (newTagVR == EVR_pixelSQ)
                               {
-                                  DcmPixelSequence *pixelSeq = new DcmPixelSequence(DCM_PixelSequenceTag);
+                                  DcmPixelSequence *pixelSeq = new DcmPixelSequence(DcmTag(DCM_PixelData, EVR_OB));
                                   if (pixelSeq != NULL)
                                   {
                                       OFstatic_cast(DcmPixelData *, newElement)->putOriginalRepresentation(xfer, NULL, pixelSeq);
@@ -953,8 +954,20 @@ int main(int argc, char *argv[])
       cmd.endOptionBlock();
 
       cmd.beginOptionBlock();
-      if (cmd.findOption("--enable-new-vr")) dcmEnableGenerationOfNewVRs();
-      if (cmd.findOption("--disable-new-vr")) dcmDisableGenerationOfNewVRs();
+      if (cmd.findOption("--enable-new-vr"))
+      {
+          dcmEnableUnknownVRGeneration.set(OFTrue);
+          dcmEnableUnlimitedTextVRGeneration.set(OFTrue);
+          dcmEnableOtherFloatStringVRGeneration.set(OFTrue);
+          dcmEnableOtherDoubleStringVRGeneration.set(OFTrue);
+      }
+      if (cmd.findOption("--disable-new-vr"))
+      {
+          dcmEnableUnknownVRGeneration.set(OFFalse);
+          dcmEnableUnlimitedTextVRGeneration.set(OFFalse);
+          dcmEnableOtherFloatStringVRGeneration.set(OFFalse);
+          dcmEnableOtherDoubleStringVRGeneration.set(OFFalse);
+      }
       cmd.endOptionBlock();
 
       cmd.beginOptionBlock();
