@@ -1,6 +1,6 @@
 /*
  *
- *  Copyright (C) 2005-2014, OFFIS e.V.
+ *  Copyright (C) 2005-2013, OFFIS e.V.
  *  All rights reserved.  See COPYRIGHT file for details.
  *
  *  This software and supporting documentation were developed by
@@ -415,7 +415,10 @@ int main(int argc, char *argv[])
 
       OFLog::configureFromCommandLine(cmd, app);
 
-      dcmEnableGenerationOfNewVRs();
+      dcmEnableUnknownVRGeneration.set(OFTrue);
+      dcmEnableUnlimitedTextVRGeneration.set(OFTrue);
+      dcmEnableOtherFloatStringVRGeneration.set(OFTrue);
+      dcmEnableOtherDoubleStringVRGeneration.set(OFTrue);
 
       cmd.beginOptionBlock();
       if (cmd.findOption("--generate"))
