@@ -1,6 +1,6 @@
 /*
  *
- *  Copyright (C) 2003-2015, OFFIS e.V.
+ *  Copyright (C) 2003-2013, OFFIS e.V.
  *  All rights reserved.  See COPYRIGHT file for details.
  *
  *  This software and supporting documentation were developed by
@@ -299,7 +299,7 @@ static OFCondition putElementContent(xmlNodePtr current,
                 OFLOG_ERROR(xml2dcmLogger, "filename for element " << element->getTag() << " is missing, empty element inserted");
         } else {
             OFString dicomVal;
-            /* convert character set from UTF-8 (for specific VRs only) */
+            /* convert character set from UTF8 (for specific VRs only) */
             if (((dcmEVR == EVR_PN) || (dcmEVR == EVR_SH) || (dcmEVR == EVR_LO) ||
                  (dcmEVR == EVR_ST) || (dcmEVR == EVR_LT) || (dcmEVR == EVR_UT)) &&
                 (xmlStrlen(elemVal) > 0) && convertUtf8ToCharset(elemVal, dicomVal))
@@ -434,7 +434,7 @@ static OFCondition parsePixelSequence(DcmPixelSequence *sequence,
             if (xmlStrcmp(current->name, OFreinterpret_cast(const xmlChar *, "pixel-item")) == 0)
             {
                 /* create new pixel item */
-                DcmPixelItem *newItem = new DcmPixelItem(DCM_PixelItemTag);
+                DcmPixelItem *newItem = new DcmPixelItem(DcmTag(DCM_Item, EVR_OB));
                 if (newItem != NULL)
                 {
                     sequence->insert(newItem);
@@ -504,7 +504,7 @@ static OFCondition parseDataSet(DcmItem *dataset,
                     if (newElem->getTag() == DCM_PixelData)
                     {
                         /* create new pixel sequence */
-                        DcmPixelSequence *sequence = new DcmPixelSequence(DCM_PixelSequenceTag);
+                        DcmPixelSequence *sequence = new DcmPixelSequence(DcmTag(DCM_PixelData, EVR_OB));
                         if (sequence != NULL)
                         {
                             /* ... insert it into the dataset and proceed with the pixel items */
@@ -825,9 +825,19 @@ int main(int argc, char *argv[])
 
         cmd.beginOptionBlock();
         if (cmd.findOption("--enable-new-vr"))
-            dcmEnableGenerationOfNewVRs();
+        {
+            dcmEnableUnknownVRGeneration.set(OFTrue);
+            dcmEnableUnlimitedTextVRGeneration.set(OFTrue);
+            dcmEnableOtherFloatStringVRGeneration.set(OFTrue);
+            dcmEnableOtherDoubleStringVRGeneration.set(OFTrue);
+        }
         if (cmd.findOption("--disable-new-vr"))
-            dcmDisableGenerationOfNewVRs();
+        {
+            dcmEnableUnknownVRGeneration.set(OFFalse);
+            dcmEnableUnlimitedTextVRGeneration.set(OFFalse);
+            dcmEnableOtherFloatStringVRGeneration.set(OFFalse);
+            dcmEnableOtherDoubleStringVRGeneration.set(OFFalse);
+        }
         cmd.endOptionBlock();
 
         cmd.beginOptionBlock();
