@@ -1,6 +1,6 @@
 /*
  *
- *  Copyright (C) 1994-2015, OFFIS e.V.
+ *  Copyright (C) 1994-2011, OFFIS e.V.
  *  All rights reserved.  See COPYRIGHT file for details.
  *
  *  This software and supporting documentation were developed by
@@ -64,26 +64,6 @@ class DCMTK_DCMDATA_EXPORT DcmElement
      */
     DcmElement &operator=(const DcmElement &obj);
 
-    /** comparison operator that compares the normalized value of this element
-     *  with a given element of the same type (e.g. an DcmUnsignedShort with a
-     *  DcmUnsignedShort). The tag of the element is also considered as the first
-     *  component that is compared, followed by the object types (VR, i.e. DCMTK'S EVR).
-     *  DcmElement's default implementation does only compare the tag and EVR while
-     *  the derived classes implement the value comparisons by comparing all the
-     *  components that make up the value, preferably in the order declared in
-     *  the object (if applicable).
-     *  @param  rhs the right hand side of the comparison
-     *  @return 0 if the object values are equal.
-     *          -1 if either the value of the first component that does not match
-     *          is lower in this object than in rhs, or all compared components match
-     *          but this object has fewer components than rhs. Also returned if rhs
-     *          cannot be casted to this object type.
-     *          1 if either the value of the first component that does not match
-     *          is greater in this object than in rhs object, or all compared
-     *          components match but the this component is longer.
-     */
-    virtual int compare(const DcmElement& rhs) const =0;
-
     /** Virtual object copying. This method can be used for DcmObject
      *  and derived classes to get a deep copy of an object. Internally
      *  the assignment operator is called if the given DcmObject parameter
@@ -660,8 +640,7 @@ class DCMTK_DCMDATA_EXPORT DcmElement
      *  Note that the value returned by this method does not include the pad byte
      *  to even size needed for a buffer into which a frame is to be loaded.
      *  @param dataset dataset in which this pixel data element is contained
-     *  @param frameSize frame size in bytes (without padding) returned in this
-     *    parameter upon success
+     *  @param frameSize frame size in bytes (without padding) returned in this parameter upon success
      *  @return EC_Normal if successful, an error code otherwise
      */
     virtual OFCondition getUncompressedFrameSize(DcmItem *dataset,
@@ -748,18 +727,6 @@ class DCMTK_DCMDATA_EXPORT DcmElement
                                      const size_t len,
                                      OFString &val);
 
-    /** check for correct value multiplicity (VM)
-     *  @param vmNum value multiplicity of the value to be checked.
-     *    For empty values (vmNum=0), the status of the check is always EC_Normal (i.e. no error).
-     *  @param vmStr value multiplicity (according to the data dictionary) to be checked for.
-     *    (valid values: "1", "1-2", "1-3", "1-8", "1-99", "1-n", "2", "2-n", "2-2n",
-     *                   "3", "3-n", "3-3n", "4", "5", "5-n", "6", "7", "7-7n", "8", "9",
-     *                   "16", "24", "32", "256")
-     *  @return status of the check, EC_ValueMultiplicityViolated in case of error
-     */
-    static OFCondition checkVM(const unsigned long vmNum,
-                               const OFString &vmStr);
-
   protected:
 
     /** This function returns this element's value. The returned value corresponds to the
@@ -852,6 +819,20 @@ class DCMTK_DCMDATA_EXPORT DcmElement
      */
     void setByteOrder(E_ByteOrder val) { fByteOrder = val; }
 
+    /* --- static helper functions --- */
+
+    /** check for correct value multiplicity (VM)
+     *  @param vmNum value multiplicity of the value to be checked.
+     *    For empty values (vmNum=0), the status of the check is always EC_Normal (i.e. no error).
+     *  @param vmStr value multiplicity (according to the data dictionary) to be checked for.
+     *    (valid values: "1", "1-2", "1-3", "1-8", "1-99", "1-n", "2", "2-n", "2-2n",
+     *                   "3", "3-n", "3-3n", "4", "5", "5-n", "6", "7", "7-7n", "8", "9",
+     *                   "16", "24", "32", "256")
+     *  @return status of the check, EC_ValueMultiplicityViolated in case of error
+     */
+    static OFCondition checkVM(const unsigned long vmNum,
+                               const OFString &vmStr);
+
   private:
 
     /// current byte order of attribute value in memory
