@@ -74,7 +74,7 @@ public:
   /** processes as many bytes as possible from the given input block.
    *  @param buf pointer to memory block, must not be NULL
    *  @param buflen length of memory block
-   *  @return number of bytes actually processed.
+   *  @return number of bytes actually processed. 
    */
   virtual offile_off_t write(const void *buf, offile_off_t buflen);
 
@@ -94,11 +94,6 @@ public:
    */
   virtual void flushBuffer(void *& buffer, offile_off_t& length);
 
-  /** query the number of bytes in buffer without flushing it.
-   *  @return number of bytes in buffer.
-   */
-  virtual offile_off_t filled();
-
 private:
 
   /// private unimplemented copy constructor
@@ -146,11 +141,6 @@ public:
    */
   virtual void flushBuffer(void *& buffer, offile_off_t& length);
 
-  /** query the number of bytes in buffer without flushing it.
-   *  @return number of bytes in buffer.
-   */
-  virtual offile_off_t filled();
-
 private:
 
   /// private unimplemented copy constructor
