@@ -1,6 +1,6 @@
 /*
  *
- *  Copyright (C) 1994-2015, OFFIS e.V.
+ *  Copyright (C) 1994-2013, OFFIS e.V.
  *  All rights reserved.  See COPYRIGHT file for details.
  *
  *  This software and supporting documentation were developed by
@@ -64,26 +64,6 @@ public:
      */
     DcmSequenceOfItems &operator=(const DcmSequenceOfItems &obj);
 
-    /** comparison operator that compares the normalized value of this object
-     *  with a given object of the same type. The tag of the element is also
-     *  considered as the first component that is compared, followed by the
-     *  object types (VR, i.e. DCMTK'S EVR) and the comparison of all value
-     *  components of the object, preferrably in the order declared in the
-     *  object (if applicable). For sequences that means that all
-     *  containted items are compared element by element, so this may be
-     *  an expensive operation!
-     *  @param  rhs the right hand side of the comparison
-     *  @return 0 if the object values are equal.
-     *          -1 if either the value of the  first component that does not match
-     *          is lower in this object than in rhs, or all compared components match
-     *          but this object has fewer components than rhs. Also returned if rhs
-     *          cannot be casted to this object type.
-     *          1 if either the value of the first component that does not match
-     *          is greater in this object than in rhs object, or all compared
-     *          components match but the this component is longer.
-     */
-    virtual int compare(const DcmElement& rhs) const;
-
     /// returns current status flag
     inline OFCondition error() const { return errorFlag; }
 
@@ -308,8 +288,7 @@ public:
      *  character codes below 128 are considered to be ASCII codes and all others are
      *  considered to be non-ASCII.
      *  @param checkAllStrings if true, also check elements with string values not affected
-     *    by SpecificCharacterSet (0008,0005), default: only check PN, LO, LT, SH, ST, UC
-     *    and UT
+     *    by SpecificCharacterSet (0008,0005), default: only check PN, LO, LT, SH, ST, UT
      *  @return true if object contains non-ASCII characters, false otherwise
      */
     virtual OFBool containsExtendedCharacters(const OFBool checkAllStrings = OFFalse);
@@ -317,7 +296,7 @@ public:
     /** check if this object is affected by SpecificCharacterSet at any nesting level.
      *  In detail, it is checked whether this object contains any data elements that
      *  according to their VR are affected by the SpecificCharacterSet (0008,0005)
-     *  element. This is true for the following VRs: PN, LO, LT, SH, ST, UC and UT
+     *  element. This is true for the following VRs: PN, LO, LT, SH, ST and UT
      *  @return true if object is affected by SpecificCharacterSet, false otherwise
      */
     virtual OFBool isAffectedBySpecificCharacterSet() const;
