@@ -1,6 +1,6 @@
 /*
  *
- *  Copyright (C) 1994-2014, OFFIS e.V.
+ *  Copyright (C) 1994-2013, OFFIS e.V.
  *  All rights reserved.  See COPYRIGHT file for details.
  *
  *  This software and supporting documentation were developed by
@@ -127,61 +127,6 @@ DcmByteString &DcmByteString::operator=(const DcmByteString &obj)
 }
 
 
-int DcmByteString::compare(const DcmElement& rhs) const
-{
-    int result = DcmElement::compare(rhs);
-    if (result != 0)
-    {
-        return result;
-    }
-
-    /* cast away constness (dcmdata is not const correct...) */
-    DcmByteString* myThis = NULL;
-    DcmByteString* myRhs = NULL;
-    myThis = OFconst_cast(DcmByteString*, this);
-    myRhs = OFstatic_cast(DcmByteString*, OFconst_cast(DcmElement*, &rhs));
-
-    /* iterate over all components and test equality */
-    unsigned long thisVM = myThis->getVM();
-    for (unsigned long count = 0; count < thisVM; count++)
-    {
-        OFString val;
-        if (myThis->getOFString(val, count).good())
-        {
-            OFString rhsVal;
-            if (myRhs->getOFString(rhsVal, count).good())
-            {
-                int result = val.compare(rhsVal);
-                if (result != 0)
-                {
-                    return result;
-                }
-            }
-            else
-            {
-                break; // values equal until this point (rhs shorter)
-            }
-        }
-    }
-
-    /* we get here if all values are equal. Now look at the number of components. */
-    unsigned long rhsVM = myRhs->getVM();
-    if (thisVM < rhsVM)
-    {
-        return -1;
-    }
-    else if (thisVM > rhsVM)
-    {
-        return 1;
-    }
-
-    /* all values as well as VM equal: objects are equal */
-    return 0;
-}
-
-
-
-
 OFCondition DcmByteString::copyFrom(const DcmObject& rhs)
 {
     if (this != &rhs)
@@ -553,15 +498,7 @@ Uint8 *DcmByteString::newValueField()
         // back to the caller.
         value = new (std::nothrow) Uint8[lengthField + 2];
 #else
-        /* make sure that the pointer is set to NULL in case of error */
-        try
-        {
-            value = new Uint8[lengthField + 2];
-        }
-        catch (STD_NAMESPACE bad_alloc const &)
-        {
-            value = NULL;
-        }
+        value = new Uint8[lengthField + 2];
 #endif
 
         /* terminate string after real length */
@@ -582,15 +519,7 @@ Uint8 *DcmByteString::newValueField()
         // back to the caller.
         value = new (std::nothrow) Uint8[lengthField + 1];
 #else
-        /* make sure that the pointer is set to NULL in case of error */
-        try
-        {
-            value = new Uint8[lengthField + 1];
-        }
-        catch (STD_NAMESPACE bad_alloc const &)
-        {
-            value = NULL;
-        }
+        value = new Uint8[lengthField + 1];
 #endif
     }
     /* make sure that the string is properly terminated by a 0 byte */
