@@ -1,6 +1,6 @@
 /*
  *
- *  Copyright (C) 1994-2015, OFFIS e.V.
+ *  Copyright (C) 1994-2011, OFFIS e.V.
  *  All rights reserved.  See COPYRIGHT file for details.
  *
  *  This software and supporting documentation were developed by
@@ -91,15 +91,15 @@ OFBool DcmDataDictionary::loadSkeletonDictionary()
     ** (and construct) sequences.
     */
     e = makeSkelEntry(0xfffe, 0xe000, 0xfffe, 0xe000,
-                      EVR_na, "Item", 1, 1, "DICOM",
+                      EVR_na, "Item", 1, 1, "DICOM3",
                       DcmDictRange_Unspecified, DcmDictRange_Unspecified, NULL);
     addEntry(e);
     e = makeSkelEntry(0xfffe, 0xe00d, 0xfffe, 0xe00d,
-                      EVR_na, "ItemDelimitationItem", 1, 1, "DICOM",
+                      EVR_na, "ItemDelimitationItem", 1, 1, "DICOM3",
                       DcmDictRange_Unspecified, DcmDictRange_Unspecified, NULL);
     addEntry(e);
     e = makeSkelEntry(0xfffe, 0xe0dd, 0xfffe, 0xe0dd,
-                      EVR_na, "SequenceDelimitationItem", 1, 1, "DICOM",
+                      EVR_na, "SequenceDelimitationItem", 1, 1, "DICOM3",
                       DcmDictRange_Unspecified, DcmDictRange_Unspecified, NULL);
     addEntry(e);
 
@@ -149,13 +149,13 @@ stripWhitespace(char* s)
 static char*
 stripTrailingWhitespace(char* s)
 {
+    size_t i, n;
+
     if (s == NULL) return s;
-    for
-    (
-        char* it = s + strlen(s) - 1;
-        it >= s && isspace(OFstatic_cast(unsigned char, *it));
-        *it-- = '\0'
-    );
+
+    n = strlen(s);
+    for (i = n - 1; i >= 0 && isspace(OFstatic_cast(unsigned char, s[i])); i--)
+        s[i] = '\0';
     return s;
 }
 
