@@ -1,6 +1,6 @@
 /*
  *
- *  Copyright (C) 1994-2016, OFFIS e.V.
+ *  Copyright (C) 1994-2013, OFFIS e.V.
  *  All rights reserved.  See COPYRIGHT file for details.
  *
  *  This software and supporting documentation were developed by
@@ -47,7 +47,7 @@ const Uint32 DCM_GroupLengthElementLength = 12;
 
 
 DcmMetaInfo::DcmMetaInfo()
-  : DcmItem(DCM_ItemTag),
+  : DcmItem(ItemTag),
     preambleUsed(OFFalse),
     fPreambleTransferState(ERW_init),
     Xfer(META_HEADER_DEFAULT_TRANSFERSYNTAX)
@@ -173,11 +173,10 @@ void DcmMetaInfo::print(STD_NAMESPACE ostream&out,
 OFCondition DcmMetaInfo::writeXML(STD_NAMESPACE ostream &out,
                                   const size_t flags)
 {
-    OFCondition l_error = EC_Normal;
     if (flags & DCMTypes::XF_useNativeModel)
     {
         /* in Native DICOM Model, there is no concept of a "file format" */
-        l_error = makeOFCondition(OFM_dcmdata, EC_CODE_CannotConvertToXML, OF_error,
+        return makeOFCondition(OFM_dcmdata, EC_CODE_CannotConvertToXML, OF_error,
             "Cannot convert File Meta Information to Native DICOM Model");
     } else {
         OFString xmlString;
@@ -194,16 +193,14 @@ OFCondition DcmMetaInfo::writeXML(STD_NAMESPACE ostream &out,
             do
             {
                 dO = elementList->get();
-                l_error = dO->writeXML(out, flags);
-            } while (l_error.good() && elementList->seek(ELP_next));
-        }
-        if (l_error.good())
-        {
-            /* XML end tag for "meta-header" */
-            out << "</meta-header>" << OFendl;
+                dO->writeXML(out, flags);
+            } while (elementList->seek(ELP_next));
         }
+        /* XML end tag for "meta-header" */
+        out << "</meta-header>" << OFendl;
+        /* always report success */
+        return EC_Normal;
     }
-    return l_error;
 }
 
 
