@@ -1,6 +1,6 @@
 /*
  *
- *  Copyright (C) 1994-2016, OFFIS e.V.
+ *  Copyright (C) 1994-2012, OFFIS e.V.
  *  All rights reserved.  See COPYRIGHT file for details.
  *
  *  This software and supporting documentation were developed by
@@ -162,73 +162,14 @@ DcmSequenceOfItems &DcmSequenceOfItems::operator=(const DcmSequenceOfItems &obj)
 }
 
 
-// ********************************
-
-
 OFCondition DcmSequenceOfItems::copyFrom(const DcmObject& rhs)
 {
-    if (this != &rhs)
-    {
-        if (rhs.ident() != ident()) return EC_IllegalCall;
-        *this = OFstatic_cast(const DcmSequenceOfItems &, rhs);
-    }
-    return EC_Normal;
-}
-
-
-// ********************************
-
-
-int DcmSequenceOfItems::compare(const DcmElement& rhs) const
-{
-    int result = DcmElement::compare(rhs);
-    if (result != 0)
-    {
-        return result;
-    }
-
-    /* cast away constness (dcmdata is not const correct...) */
-    DcmSequenceOfItems* myThis = NULL;
-    DcmSequenceOfItems* myRhs = NULL;
-    myThis = OFconst_cast(DcmSequenceOfItems*, this);
-    myRhs = OFstatic_cast(DcmSequenceOfItems*, OFconst_cast(DcmElement*, &rhs));
-
-    /* iterate over all items and test equality */
-    unsigned long thisVM = myThis->card();
-    for (unsigned long count = 0; count < thisVM; count++)
-    {
-        DcmItem* val = myThis->getItem(count);
-        if (val)
-        {
-            DcmItem* rhsVal = myRhs->getItem(count);
-            if (rhsVal)
-            {
-                int result = val->compare(*rhsVal);
-                if (result != 0)
-                {
-                    return result;
-                }
-            }
-            else
-            {
-                break; // values equal until this point (rhs shorter)
-            }
-        }
-    }
-
-    /* we get here if all values are equal. Now look at the number of components. */
-    unsigned long rhsVM = myRhs->card();
-    if (thisVM < rhsVM)
-    {
-        return -1;
-    }
-    else if (thisVM > rhsVM)
-    {
-        return 1;
-    }
-
-    /* all values as well as VM equal: objects are equal */
-    return 0;
+  if (this != &rhs)
+  {
+      if (rhs.ident() != ident()) return EC_IllegalCall;
+      *this = OFstatic_cast(const DcmSequenceOfItems &, rhs);
+  }
+  return EC_Normal;
 }
 
 
@@ -290,7 +231,7 @@ void DcmSequenceOfItems::print(STD_NAMESPACE ostream&out,
             } while (itemList->seek(ELP_next));
         }
         /* print sequence end line */
-        DcmTag delimItemTag(DCM_SequenceDelimitationItemTag);
+        DcmTag delimItemTag(DCM_SequenceDelimitationItem);
         if (getLengthField() == DCM_UndefinedLength)
             printInfoLine(out, flags, level, "(SequenceDelimitationItem)", &delimItemTag);
         else
@@ -305,7 +246,6 @@ void DcmSequenceOfItems::print(STD_NAMESPACE ostream&out,
 OFCondition DcmSequenceOfItems::writeXML(STD_NAMESPACE ostream&out,
                                          const size_t flags)
 {
-    OFCondition l_error = EC_Normal;
     if (flags & DCMTypes::XF_useNativeModel)
     {
         /* use common method from DcmElement to write start tag */
@@ -321,17 +261,12 @@ OFCondition DcmSequenceOfItems::writeXML(STD_NAMESPACE ostream&out,
             {
                 out << "<Item number=\"" << (itemNo++) << "\">" << OFendl;
                 dO = itemList->get();
-                l_error = dO->writeXML(out, flags);
-                /* exit loop in case of error */
-                if (l_error.bad()) break;
+                dO->writeXML(out, flags);
                 out << "</Item>" << OFendl;
             } while (itemList->seek(ELP_next));
         }
-        if (l_error.good())
-        {
-            /* use common method from DcmElement to write end tag */
-            DcmElement::writeXMLEndTag(out, flags);
-        }
+        /* use common method from DcmElement to write end tag */
+        DcmElement::writeXMLEndTag(out, flags);
     } else {
         OFString xmlString;
         DcmVR vr(getTag().getVR());
@@ -363,16 +298,14 @@ OFCondition DcmSequenceOfItems::writeXML(STD_NAMESPACE ostream&out,
             do
             {
                 dO = itemList->get();
-                l_error = dO->writeXML(out, flags);
-            } while (l_error.good() && itemList->seek(ELP_next));
-        }
-        if (l_error.good())
-        {
-            /* XML end tag for "sequence" */
-            out << "</sequence>" << OFendl;
+                dO->writeXML(out, flags);
+            } while (itemList->seek(ELP_next));
         }
+        /* XML end tag for "sequence" */
+        out << "</sequence>" << OFendl;
     }
-    return l_error;
+    /* always report success */
+    return EC_Normal;
 }
 
 
@@ -554,7 +487,7 @@ OFCondition DcmSequenceOfItems::readTagAndLength(DcmInputStream &inStream,
         inStream.read(&elementTag, 2);
         swapIfNecessary(gLocalByteOrder, iByteOrder, &groupTag, 2, 2);
         swapIfNecessary(gLocalByteOrder, iByteOrder, &elementTag, 2, 2);
-        // tag has been read
+        // tag has ben read
 
         DcmTag newTag(groupTag, elementTag);
 
@@ -795,13 +728,13 @@ OFCondition DcmSequenceOfItems::write(DcmOutputStream &outStream,
                         if (outStream.avail() >= 8)
                         {
                             // write sequence delimitation item
-                            const DcmTag delim(DCM_SequenceDelimitationItemTag);
+                            DcmTag delim(DCM_SequenceDelimitationItem);
                             errorFlag = writeTag(outStream, delim, oxfer);
                             Uint32 delimLen = 0L;
                             outStream.write(&delimLen, 4); // 4 bytes length
                         } else {
                             // the complete sequence is written but it
-                            // is not possible to write the delimitation item into the buffer.
+                            // is not possible to write the delimination item into the buffer.
                             errorFlag = EC_StreamNotifyClient;
                             setTransferState(ERW_inWork);
                         }
@@ -915,11 +848,11 @@ OFCondition DcmSequenceOfItems::writeSignatureFormat(DcmOutputStream &outStream,
                     if (outStream.avail() >= 4)
                     {
                         // write sequence delimitation item
-                        const DcmTag delim(DCM_SequenceDelimitationItemTag);
+                        DcmTag delim(DCM_SequenceDelimitationItem);
                         errorFlag = writeTag(outStream, delim, oxfer);
                     } else {
                         // Every subelement of the item was written but it
-                        // is not possible to write the delimitation item
+                        // is not possible to write the delimination item
                         // into the buffer.
                         setTransferState(ERW_inWork);
                         errorFlag = EC_StreamNotifyClient;
