@@ -1,6 +1,6 @@
 /*
  *
- *  Copyright (C) 1994-2015, OFFIS e.V.
+ *  Copyright (C) 1994-2014, OFFIS e.V.
  *  All rights reserved.  See COPYRIGHT file for details.
  *
  *  This software and supporting documentation were developed by
@@ -79,7 +79,6 @@ END_EXTERN_C
 #include "dcmtk/ofstd/ofcrc32.h"
 #include "dcmtk/ofstd/ofdefine.h"
 #include "dcmtk/ofstd/ofstd.h"
-#include "dcmtk/ofstd/ofnetdb.h"
 
 struct UIDNameMap {
     const char* uid;
@@ -126,9 +125,6 @@ static const UIDNameMap uidNameMap[] = {
     { UID_MPEG2MainProfileAtHighLevelTransferSyntax,           "MPEG2MainProfile@HighLevel" },
     { UID_MPEG4HighProfileLevel4_1TransferSyntax,              "MPEG4HighProfile/Level4.1" },
     { UID_MPEG4BDcompatibleHighProfileLevel4_1TransferSyntax,  "MPEG4BDcompatibleHighProfile/Level4.1" },
-    { UID_MPEG4HighProfileLevel4_2_For2DVideoTransferSyntax,   "MPEG4HighProfile/Level4.2For2DVideo" },
-    { UID_MPEG4HighProfileLevel4_2_For3DVideoTransferSyntax,   "MPEG4HighProfile/Level4.2For3DVideo" },
-    { UID_MPEG4StereoHighProfileLevel4_2TransferSyntax,        "MPEG4StereoHighProfile/Level4.2" },
     { UID_JPEG2000Part2MulticomponentImageCompressionLosslessOnlyTransferSyntax, "JPEG2000MulticomponentLosslessOnly" },
     { UID_JPEG2000Part2MulticomponentImageCompressionTransferSyntax,             "JPEG2000Multicomponent" },
     { UID_JPIPReferencedTransferSyntax,                        "JPIPReferenced" },
@@ -151,7 +147,6 @@ static const UIDNameMap uidNameMap[] = {
     { UID_ChestCADSRStorage,                                   "ChestCADSRStorage" },
     { UID_ColonCADSRStorage,                                   "ColonCADSRStorage" },
     { UID_ColorSoftcopyPresentationStateStorage,               "ColorSoftcopyPresentationStateStorage" },
-    { UID_CompositingPlanarMPRVolumetricPresentationStateStorage, "CompositingPlanarMPRVolumetricPresentationStateStorage" },
     { UID_Comprehensive3DSRStorage,                            "Comprehensive3DSRStorage" },
     { UID_ComprehensiveSRStorage,                              "ComprehensiveSRStorage" },
     { UID_ComputedRadiographyImageStorage,                     "ComputedRadiographyImageStorage" },
@@ -174,11 +169,9 @@ static const UIDNameMap uidNameMap[] = {
     { UID_EnhancedUSVolumeStorage,                             "EnhancedUSVolumeStorage" },
     { UID_EnhancedXAImageStorage,                              "EnhancedXAImageStorage" },
     { UID_EnhancedXRFImageStorage,                             "EnhancedXRFImageStorage" },
-    { UID_ExtensibleSRStorage,                                 "ExtensibleSRStorage" },
     { UID_GeneralAudioWaveformStorage,                         "GeneralAudioWaveformStorage" },
     { UID_GeneralECGWaveformStorage,                           "GeneralECGWaveformStorage" },
     { UID_GenericImplantTemplateStorage,                       "GenericImplantTemplateStorage" },
-    { UID_GrayscalePlanarMPRVolumetricPresentationStateStorage, "GrayscalePlanarMPRVolumetricPresentationStateStorage" },
     { UID_GrayscaleSoftcopyPresentationStateStorage,           "GrayscaleSoftcopyPresentationStateStorage" },
     { UID_HangingProtocolStorage,                              "HangingProtocolStorage" },
     { UID_HemodynamicWaveformStorage,                          "HemodynamicWaveformStorage" },
@@ -210,7 +203,6 @@ static const UIDNameMap uidNameMap[] = {
     { UID_OphthalmicThicknessMapStorage,                       "OphthalmicThicknessMapStorage" },
     { UID_OphthalmicTomographyImageStorage,                    "OphthalmicTomographyImageStorage" },
     { UID_OphthalmicVisualFieldStaticPerimetryMeasurementsStorage, "OphthalmicVisualFieldStaticPerimetryMeasurementsStorage" },
-    { UID_ParametricMapStorage,                                "ParametricMapStorage" },
     { UID_PositronEmissionTomographyImageStorage,              "PositronEmissionTomographyImageStorage" },
     { UID_ProcedureLogStorage,                                 "ProcedureLogStorage" },
     { UID_PseudoColorSoftcopyPresentationStateStorage,         "PseudoColorSoftcopyPresentationStateStorage" },
@@ -249,8 +241,6 @@ static const UIDNameMap uidNameMap[] = {
     { UID_VLPhotographicImageStorage,                          "VLPhotographicImageStorage" },
     { UID_VLSlideCoordinatesMicroscopicImageStorage,           "VLSlideCoordinatesMicroscopicImageStorage" },
     { UID_VLWholeSlideMicroscopyImageStorage,                  "VLWholeSlideMicroscopyImageStorage" },
-    { UID_WideFieldOphthalmicPhotographyStereographicProjectionImageStorage, "WideFieldOphthalmicPhotographyStereographicProjectionImageStorage" },
-    { UID_WideFieldOphthalmicPhotography3DCoordinatesImageStorage, "OphthalmicPhotography3DCoordinatesImageStorage" },
     { UID_XAXRFGrayscaleSoftcopyPresentationStateStorage,      "XAXRFGrayscaleSoftcopyPresentationStateStorage" },
     { UID_XRay3DAngiographicImageStorage,                      "XRay3DAngiographicImageStorage" },
     { UID_XRay3DCraniofacialImageStorage,                      "XRay3DCraniofacialImageStorage" },
@@ -289,10 +279,10 @@ static const UIDNameMap uidNameMap[] = {
     { UID_MOVEPatientRootQueryRetrieveInformationModel,              "MOVEPatientRootQueryRetrieveInformationModel" },
     { UID_MOVEStudyRootQueryRetrieveInformationModel,                "MOVEStudyRootQueryRetrieveInformationModel" },
     { UID_RETIRED_FINDPatientStudyOnlyQueryRetrieveInformationModel, "RETIRED_FINDPatientStudyOnlyQueryRetrieveInformationModel" },
-    { UID_GETCompositeInstanceRetrieveWithoutBulkData,               "GETCompositeInstanceRetrieveWithoutBulkData" },
-    { UID_GETCompositeInstanceRootRetrieve,                          "GETCompositeInstanceRootRetrieve" },
+    { UID_RETIRED_GETCompositeInstanceRetrieveWithoutBulkData,       "RETIRED_GETCompositeInstanceRetrieveWithoutBulkData" },
+    { UID_RETIRED_GETCompositeInstanceRootRetrieve,                  "RETIRED_GETCompositeInstanceRootRetrieve" },
     { UID_RETIRED_GETPatientStudyOnlyQueryRetrieveInformationModel,  "RETIRED_GETPatientStudyOnlyQueryRetrieveInformationModel" },
-    { UID_MOVECompositeInstanceRootRetrieve,                         "MOVECompositeInstanceRootRetrieve" },
+    { UID_RETIRED_MOVECompositeInstanceRootRetrieve,                 "RETIRED_MOVECompositeInstanceRootRetrieve" },
     { UID_RETIRED_MOVEPatientStudyOnlyQueryRetrieveInformationModel, "RETIRED_MOVEPatientStudyOnlyQueryRetrieveInformationModel" },
 
     // Worklist
@@ -320,8 +310,7 @@ static const UIDNameMap uidNameMap[] = {
     { UID_UnifiedProcedureStepWatchSOPClass,                   "UnifiedProcedureStepWatchSOPClass" },
     { UID_UnifiedProcedureStepPullSOPClass,                    "UnifiedProcedureStepPullSOPClass" },
     { UID_UnifiedProcedureStepEventSOPClass,                   "UnifiedProcedureStepEventSOPClass" },
-    { UID_UPSGlobalSubscriptionSOPInstance,                    "UPSGlobalSubscriptionSOPInstance" },
-    { UID_UPSFilteredGlobalSubscriptionSOPInstance,            "UPSFilteredGlobalSubscriptionSOPInstance" },
+    { UID_UnifiedWorklistAndProcedureStepSOPInstance,          "UnifiedWorklistAndProcedureStepSOPInstance" },
 
     // Storage Commitment
     { UID_RETIRED_StorageCommitmentPullModelSOPClass,          "RETIRED_StorageCommitmentPullModelSOPClass" },
@@ -422,9 +411,6 @@ static const UIDNameMap uidNameMap[] = {
     { UID_RETIRED_StudyComponentManagementSOPClass,            "RETIRED_StudyComponentManagementSOPClass" },
     { UID_VerificationSOPClass,                                "VerificationSOPClass" },
 
-    // Mapping Resources
-    { UID_DICOMContentMappingResource,                         "DICOMContentMappingResource" },
-
     // Coding Schemes
     { UID_DICOMControlledTerminologyCodingScheme,              "DICOMControlledTerminologyCodingScheme" },
     { UID_DICOMUIDRegistryCodingScheme,                        "DICOMUIDRegistryCodingScheme" },
@@ -529,7 +515,7 @@ static const int uidNameMap_size = OFstatic_cast(int, sizeof(uidNameMap) / sizeo
  *  are not included in this list.
  *
  *  THIS LIST CONTAINS ALL STORAGE SOP CLASSES INCLUDING RETIRED ONES
- *  AND IS (MUCH) LARGER THAN 64 ENTRIES.
+ *  AND IS LARGER THAN 64 ENTRIES.
  */
 
 const char* dcmAllStorageSOPClassUIDs[] = {
@@ -547,7 +533,6 @@ const char* dcmAllStorageSOPClassUIDs[] = {
     UID_ChestCADSRStorage,
     UID_ColonCADSRStorage,
     UID_ColorSoftcopyPresentationStateStorage,
-    UID_CompositingPlanarMPRVolumetricPresentationStateStorage,
     UID_Comprehensive3DSRStorage,
     UID_ComprehensiveSRStorage,
     UID_ComputedRadiographyImageStorage,
@@ -570,11 +555,9 @@ const char* dcmAllStorageSOPClassUIDs[] = {
     UID_EnhancedUSVolumeStorage,
     UID_EnhancedXAImageStorage,
     UID_EnhancedXRFImageStorage,
-    UID_ExtensibleSRStorage,
     UID_GeneralAudioWaveformStorage,
     UID_GeneralECGWaveformStorage,
     UID_GenericImplantTemplateStorage,
-    UID_GrayscalePlanarMPRVolumetricPresentationStateStorage,
     UID_GrayscaleSoftcopyPresentationStateStorage,
     UID_HemodynamicWaveformStorage,
     UID_ImplantAssemblyTemplateStorage,
@@ -604,7 +587,6 @@ const char* dcmAllStorageSOPClassUIDs[] = {
     UID_OphthalmicThicknessMapStorage,
     UID_OphthalmicTomographyImageStorage,
     UID_OphthalmicVisualFieldStaticPerimetryMeasurementsStorage,
-    UID_ParametricMapStorage,
     UID_PositronEmissionTomographyImageStorage,
     UID_ProcedureLogStorage,
     UID_PseudoColorSoftcopyPresentationStateStorage,
@@ -644,8 +626,6 @@ const char* dcmAllStorageSOPClassUIDs[] = {
     UID_VLPhotographicImageStorage,
     UID_VLSlideCoordinatesMicroscopicImageStorage,
     UID_VLWholeSlideMicroscopyImageStorage,
-    UID_WideFieldOphthalmicPhotographyStereographicProjectionImageStorage,
-    UID_WideFieldOphthalmicPhotography3DCoordinatesImageStorage,
     UID_XAXRFGrayscaleSoftcopyPresentationStateStorage,
     UID_XRay3DAngiographicImageStorage,
     UID_XRay3DCraniofacialImageStorage,
@@ -805,17 +785,11 @@ const char* dcmLongSCUStorageSOPClassUIDs[] = {
     // recently approved
 //  UID_BreastProjectionXRayImageStorageForPresentation,
 //  UID_BreastProjectionXRayImageStorageForProcessing,
-//  UID_CompositingPlanarMPRVolumetricPresentationStateStorage
 //  UID_CornealTopographyMapStorage,
-//  UID_ExtensibleSRStorage,
-//  UID_GrayscalePlanarMPRVolumetricPresentationStateStorage
 //  UID_LegacyConvertedEnhancedCTImageStorage,
 //  UID_LegacyConvertedEnhancedMRImageStorage,
 //  UID_LegacyConvertedEnhancedPETImageStorage,
-//  UID_ParametricMapStorage,
 //  UID_RadiopharmaceuticalRadiationDoseSRStorage,
-//  UID_WideFieldOphthalmicPhotographyStereographicProjectionImageStorage,
-//  UID_WideFieldOphthalmicPhotography3DCoordinatesImageStorage,
     // retired
     UID_RETIRED_HardcopyColorImageStorage,
     UID_RETIRED_HardcopyGrayscaleImageStorage,
@@ -986,7 +960,6 @@ const char* dcmImageSOPClassUIDs[] = {
     UID_OphthalmicPhotography8BitImageStorage,
     UID_OphthalmicThicknessMapStorage,
     UID_OphthalmicTomographyImageStorage,
-    UID_ParametricMapStorage,
     UID_PositronEmissionTomographyImageStorage,
     UID_RTImageStorage,
     UID_SecondaryCaptureImageStorage,
@@ -1000,8 +973,6 @@ const char* dcmImageSOPClassUIDs[] = {
     UID_VLPhotographicImageStorage,
     UID_VLSlideCoordinatesMicroscopicImageStorage,
     UID_VLWholeSlideMicroscopyImageStorage,
-    UID_WideFieldOphthalmicPhotographyStereographicProjectionImageStorage,
-    UID_WideFieldOphthalmicPhotography3DCoordinatesImageStorage,
     UID_XRay3DAngiographicImageStorage,
     UID_XRay3DCraniofacialImageStorage,
     UID_XRayAngiographicImageStorage,
@@ -1057,7 +1028,6 @@ static const DcmModalityTable modalities[] = {
     { UID_ChestCADSRStorage,                                       "SRh", 4096 },
     { UID_ColonCADSRStorage,                                       "SRo", 4096 },
     { UID_ColorSoftcopyPresentationStateStorage,                   "PSc", 4096 },
-    { UID_CompositingPlanarMPRVolumetricPresentationStateStorage,  "VPc", 4096 },
     { UID_Comprehensive3DSRStorage,                                "SR3", 4096 },
     { UID_ComprehensiveSRStorage,                                  "SRc", 4096 },
     { UID_ComputedRadiographyImageStorage,                         "CR",  2048 * 2048 * 2 },
@@ -1080,11 +1050,9 @@ static const DcmModalityTable modalities[] = {
     { UID_EnhancedUSVolumeStorage,                                 "USe", 512 * 512 },
     { UID_EnhancedXAImageStorage,                                  "XAe", 256 * 512 * 512 },
     { UID_EnhancedXRFImageStorage,                                 "RFe", 256 * 512 * 512 },
-    { UID_ExtensibleSRStorage,                                     "SRx", 4096 },
     { UID_GeneralAudioWaveformStorage,                             "AUG", 4096 },
     { UID_GeneralECGWaveformStorage,                               "ECG", 4096 },
     { UID_GenericImplantTemplateStorage,                           "IT",  4096 },
-    { UID_GrayscalePlanarMPRVolumetricPresentationStateStorage,    "VPg", 4096 },
     { UID_GrayscaleSoftcopyPresentationStateStorage,               "PSg", 4096 },
     { UID_HemodynamicWaveformStorage,                              "WVh", 4096 },
     { UID_ImplantAssemblyTemplateStorage,                          "ITa", 4096 },
@@ -1114,7 +1082,6 @@ static const DcmModalityTable modalities[] = {
     { UID_OphthalmicThicknessMapStorage,                           "OPm", 768 * 576 },
     { UID_OphthalmicTomographyImageStorage,                        "OPt", 768 * 576 * 3 },
     { UID_OphthalmicVisualFieldStaticPerimetryMeasurementsStorage, "OPp", 4096 },
-    { UID_ParametricMapStorage,                                    "PM",  256 * 256 * 4 },
     { UID_PositronEmissionTomographyImageStorage,                  "PI",  512 * 512 * 2 },
     { UID_ProcedureLogStorage,                                     "SRp", 4096 },
     { UID_PseudoColorSoftcopyPresentationStateStorage,             "PSp", 4096 },
@@ -1154,8 +1121,6 @@ static const DcmModalityTable modalities[] = {
     { UID_VLPhotographicImageStorage,                              "VLp", 768 * 576 * 3 },
     { UID_VLSlideCoordinatesMicroscopicImageStorage,               "VLs", 768 * 576 * 3 },
     { UID_VLWholeSlideMicroscopyImageStorage,                      "VLw", 10000 * 10000 * 3},
-    { UID_WideFieldOphthalmicPhotographyStereographicProjectionImageStorage, "OWs", 768 * 576 * 3 },
-    { UID_WideFieldOphthalmicPhotography3DCoordinatesImageStorage, "OW3", 768 * 576 * 3 },
     { UID_XAXRFGrayscaleSoftcopyPresentationStateStorage,          "PSx", 4096 },
     { UID_XRay3DAngiographicImageStorage,                          "XA3", 256 * 512 * 512 },
     { UID_XRay3DCraniofacialImageStorage,                          "XC3", 256 * 512 * 512 },
@@ -1179,10 +1144,10 @@ static const DcmModalityTable modalities[] = {
     { UID_RETIRED_XRayAngiographicBiPlaneImageStorage,             "XB",  512 * 512 * 2 },
     // draft
     { UID_DRAFT_RTBeamsDeliveryInstructionStorage,                 "RBd", 4096 },
-    { UID_DRAFT_SRAudioStorage,                                    "SR_", 4096 },  /* was "SRw" */
-    { UID_DRAFT_SRComprehensiveStorage,                            "SR_", 4096 },  /* was "SRx" */
-    { UID_DRAFT_SRDetailStorage,                                   "SR_", 4096 },  /* was "SRy" */
-    { UID_DRAFT_SRTextStorage,                                     "SR_", 4096 },  /* was "SRz" */
+    { UID_DRAFT_SRAudioStorage,                                    "SRw", 4096 },
+    { UID_DRAFT_SRComprehensiveStorage,                            "SRx", 4096 },
+    { UID_DRAFT_SRDetailStorage,                                   "SRy", 4096 },
+    { UID_DRAFT_SRTextStorage,                                     "SRz", 4096 },
     { UID_DRAFT_WaveformStorage,                                   "WVd", 4096 },
     // DICOS
     { UID_DICOS_CTImageStorage,                                    "CTs", 512 * 512 * 2 },
@@ -1242,8 +1207,9 @@ unsigned long dcmGuessModalityBytes(const char *sopClassUID)
 const char*
 dcmFindNameOfUID(const char* uid, const char* defaultValue)
 {
+    int i = 0;
     if (uid == NULL) return defaultValue;
-    for (int i = 0; i < uidNameMap_size; i++) {
+    for (i=0; i<uidNameMap_size; i++) {
       if (uidNameMap[i].uid != NULL && strcmp(uid, uidNameMap[i].uid) == 0) {
         return uidNameMap[i].name;
       }
@@ -1258,8 +1224,8 @@ dcmFindNameOfUID(const char* uid, const char* defaultValue)
 // Returns NULL of the name is not known.
 //
 
-const char*
-dcmFindUIDFromName(const char* name)
+const char *
+dcmFindUIDFromName(const char * name)
 {
     if (name == NULL) return NULL;
     for(int i = 0; i < uidNameMap_size; i++)
@@ -1279,8 +1245,9 @@ dcmFindUIDFromName(const char* name)
 OFBool
 dcmIsaStorageSOPClassUID(const char* uid)
 {
+    int i = 0;
     if (uid == NULL) return OFFalse;
-    for (int i = 0; i < numberOfAllDcmStorageSOPClassUIDs; i++) {
+    for (i=0; i<numberOfAllDcmStorageSOPClassUIDs; i++) {
       if (dcmAllStorageSOPClassUIDs[i] != NULL && strcmp(uid, dcmAllStorageSOPClassUIDs[i]) == 0) {
         return OFTrue;
       }
@@ -1288,28 +1255,10 @@ dcmIsaStorageSOPClassUID(const char* uid)
     return OFFalse;
 }
 
-
-/*
-** dcmIsImageStorageSOPClassUID(const char* uid)
-** Returns true if the uid is one of the Image Storage SOP Classes.
-** Performs a table lookup in the dcmImageSOPClassUIDs table.
-*/
-OFBool
-dcmIsImageStorageSOPClassUID(const char* uid)
-{
-    if (uid == NULL) return OFFalse;
-    for (int i = 0; i < numberOfDcmImageSOPClassUIDs; i++) {
-      if (dcmImageSOPClassUIDs[i] != NULL && strcmp(uid, dcmImageSOPClassUIDs[i]) == 0) {
-        return OFTrue;
-      }
-    }
-    return OFFalse;
-}
-
 // ********************************
 
 #ifndef HAVE_GETHOSTID
-#if defined(HAVE_SYSINFO) && defined(HAVE_SYS_SYSTEMINFO_H)
+#ifdef HAVE_SYSINFO
 
 #include <sys/systeminfo.h>
 static long gethostid(void)
@@ -1472,7 +1421,7 @@ static unsigned char *getMACAddress(unsigned char buffer[6])
                 varBindList.list = varBind;
                 varBind[0].name = MIB_NULL;
                 varBind[1].name = MIB_NULL;
-                /* copy in the OID to find the number of entries in the interface table */
+                /* copy in the OID to find the number of entries in the inteface table */
                 varBindList.len = 1;        /* only retrieving one item */
                 m_Copy(&varBind[0].name, &MIB_ifEntryNum);
                 ret = m_Query(SNMP_PDU_GETNEXT, &varBindList, &errorStatus, &errorIndex);
@@ -1558,6 +1507,7 @@ static long gethostid(void)
     long result = 0;
 #if (defined(HAVE_GETHOSTNAME) && defined(HAVE_GETHOSTBYNAME)) || defined(HAVE_WINDOWS_H)
     char name[1024];
+    struct hostent *hent = NULL;
     char **p = NULL;
     struct in_addr in;
 #ifdef HAVE_WINSOCK_H
@@ -1572,12 +1522,21 @@ static long gethostid(void)
     */
     if (gethostname(name, 1024) == 0)
     {
-        if (OFStandard::OFHostent hent = OFStandard::getHostByName(name))
+#if defined(HAVE_GETHOSTBYNAME_R)
+        // use gethostbyname_r instead of gethostbyname
+        int h_errnop=0;
+        struct hostent theHostent;
+        char buffer[GETHOSTBYNAME_R_BUFSIZE];
+        if ((hent = gethostbyname_r(name, &theHostent, buffer, GETHOSTBYNAME_R_BUFSIZE, &h_errnop)) != NULL)
+#else
+        if ((hent = gethostbyname(name)) != NULL)
+#endif
         {
-            if (!hent.h_addr_list.empty())
+            p = hent->h_addr_list;
+            if (p && *p)
             {
-                memcpy(&in.s_addr, hent.h_addr_list.front().c_str(), sizeof(in.s_addr));
-                result = OFstatic_cast(long, in.s_addr);
+                (void) memcpy(&in.s_addr, *p, sizeof(in.s_addr));
+                result = (long)in.s_addr;
             }
         }
     }
@@ -1694,13 +1653,13 @@ initCounterOfCurrentUID()
 static char*
 stripTrailing(char* s, char c)
 {
+    size_t i, n;
+
     if (s == NULL) return s;
-    for
-    (
-        char* it = s + strlen(s) - 1;
-        it >= s && *it == c;
-        *it-- = '\0'
-    );
+
+    n = strlen(s);
+    for (i = n - 1; (i >= 0) && (s[i] == c); i--)
+        s[i] = '\0';
     return s;
 }
 
