@@ -1,6 +1,6 @@
 /*
  *
- *  Copyright (C) 1994-2016, OFFIS e.V.
+ *  Copyright (C) 1994-2013, OFFIS e.V.
  *  All rights reserved.  See COPYRIGHT file for details.
  *
  *  This software and supporting documentation were developed by
@@ -30,43 +30,14 @@
 #include "dcmtk/ofstd/ofstdinc.h"
 
 /*
-** global flags
-*/
+ * global flags
+ */
 OFGlobal<OFBool> dcmEnableUnknownVRGeneration(OFTrue);
 OFGlobal<OFBool> dcmEnableUnlimitedTextVRGeneration(OFTrue);
-OFGlobal<OFBool> dcmEnableOtherFloatVRGeneration(OFTrue);
-OFGlobal<OFBool> dcmEnableOtherDoubleVRGeneration(OFTrue);
-OFGlobal<OFBool> dcmEnableOtherLongVRGeneration(OFTrue);
-OFGlobal<OFBool> dcmEnableUniversalResourceIdentifierOrLocatorVRGeneration(OFTrue);
-OFGlobal<OFBool> dcmEnableUnlimitedCharactersVRGeneration(OFTrue);
+OFGlobal<OFBool> dcmEnableOtherFloatStringVRGeneration(OFTrue);
+OFGlobal<OFBool> dcmEnableOtherDoubleStringVRGeneration(OFTrue);
 OFGlobal<OFBool> dcmEnableUnknownVRConversion(OFFalse);
 
-/*
-** global functions
-*/
-void dcmEnableGenerationOfNewVRs()
-{
-    dcmEnableUnknownVRGeneration.set(OFTrue);
-    dcmEnableUnlimitedTextVRGeneration.set(OFTrue);
-    dcmEnableOtherFloatVRGeneration.set(OFTrue);
-    dcmEnableOtherDoubleVRGeneration.set(OFTrue);
-    dcmEnableOtherLongVRGeneration.set(OFTrue);
-    dcmEnableUniversalResourceIdentifierOrLocatorVRGeneration.set(OFTrue);
-    dcmEnableUnlimitedCharactersVRGeneration.set(OFTrue);
-}
-
-void dcmDisableGenerationOfNewVRs()
-{
-    dcmEnableUnknownVRGeneration.set(OFFalse);
-    dcmEnableUnlimitedTextVRGeneration.set(OFFalse);
-    dcmEnableOtherFloatVRGeneration.set(OFFalse);
-    dcmEnableOtherDoubleVRGeneration.set(OFFalse);
-    dcmEnableOtherLongVRGeneration.set(OFFalse);
-    dcmEnableUniversalResourceIdentifierOrLocatorVRGeneration.set(OFFalse);
-    dcmEnableUnlimitedCharactersVRGeneration.set(OFFalse);
-}
-
-
 /*
 ** VR property table
 */
@@ -104,7 +75,6 @@ static const DcmVREntry DcmVRDict[] = {
     { EVR_OB, "OB", sizeof(Uint8), DCMVR_PROP_EXTENDEDLENGTHENCODING, 0, DCM_UndefinedLength },
     { EVR_OD, "OD", sizeof(Float64), DCMVR_PROP_EXTENDEDLENGTHENCODING, 0, DCM_UndefinedLength },
     { EVR_OF, "OF", sizeof(Float32), DCMVR_PROP_EXTENDEDLENGTHENCODING, 0, DCM_UndefinedLength },
-    { EVR_OL, "OL", sizeof(Uint32), DCMVR_PROP_EXTENDEDLENGTHENCODING, 0, DCM_UndefinedLength },
     { EVR_OW, "OW", sizeof(Uint16), DCMVR_PROP_EXTENDEDLENGTHENCODING, 0, DCM_UndefinedLength },
     { EVR_PN, "PN", sizeof(char), DCMVR_PROP_ISASTRING, 0, 64 },
     { EVR_SH, "SH", sizeof(char), DCMVR_PROP_ISASTRING, 0, 16 },
@@ -113,10 +83,8 @@ static const DcmVREntry DcmVRDict[] = {
     { EVR_SS, "SS", sizeof(Sint16), DCMVR_PROP_NONE, 2, 2 },
     { EVR_ST, "ST", sizeof(char), DCMVR_PROP_ISASTRING, 0, 1024 },
     { EVR_TM, "TM", sizeof(char), DCMVR_PROP_ISASTRING, 0, 16 },
-    { EVR_UC, "UC", sizeof(char), DCMVR_PROP_ISASTRING|DCMVR_PROP_EXTENDEDLENGTHENCODING, 0, DCM_UndefinedLength },
     { EVR_UI, "UI", sizeof(char), DCMVR_PROP_ISASTRING, 0, 64 },
     { EVR_UL, "UL", sizeof(Uint32), DCMVR_PROP_NONE, 4, 4 },
-    { EVR_UR, "UR", sizeof(char), DCMVR_PROP_ISASTRING|DCMVR_PROP_EXTENDEDLENGTHENCODING, 0, DCM_UndefinedLength },
     { EVR_US, "US", sizeof(Uint16), DCMVR_PROP_NONE, 2, 2 },
     { EVR_UT, "UT", sizeof(char), DCMVR_PROP_ISASTRING|DCMVR_PROP_EXTENDEDLENGTHENCODING, 0, DCM_UndefinedLength },
     { EVR_ox, "ox", sizeof(Uint8), DCMVR_PROP_NONSTANDARD | DCMVR_PROP_EXTENDEDLENGTHENCODING, 0, DCM_UndefinedLength },
@@ -273,77 +241,39 @@ DcmVR::getValidEVR() const
     ** If the generation of post-1993 VRs is not globally enabled then use OB instead.
     ** We may not want to generate these "new" VRs if other software cannot handle it.
     */
-    DcmEVR oldVR = evr;
     switch (evr) {
         case EVR_UN:
             if (!dcmEnableUnknownVRGeneration.get())
+            {
+                DCMDATA_TRACE("DcmVR::getValidEVR() VR=\"UN\" replaced by \"OB\" since support is disabled");
                 evr = EVR_OB; /* handle UN as if OB */
+            }
             break;
         case EVR_UT:
             if (!dcmEnableUnlimitedTextVRGeneration.get())
             {
-                if (dcmEnableUnknownVRGeneration.get())
-                    evr = EVR_UN; /* handle UT as if UN */
-                else
-                    evr = EVR_OB; /* handle UT as if OB */
+                DCMDATA_TRACE("DcmVR::getValidEVR() VR=\"UT\" replaced by \"OB\" since support is disabled");
+                evr = EVR_OB; /* handle UT as if OB */
             }
             break;
         case EVR_OF:
-            if (!dcmEnableOtherFloatVRGeneration.get())
+            if (!dcmEnableOtherFloatStringVRGeneration.get())
             {
-                if (dcmEnableUnknownVRGeneration.get())
-                    evr = EVR_UN; /* handle OF as if UN */
-                else
-                    evr = EVR_OB; /* handle OF as if OB */
+                DCMDATA_TRACE("DcmVR::getValidEVR() VR=\"OF\" replaced by \"OB\" since support is disabled");
+                evr = EVR_OB; /* handle OF as if OB */
             }
             break;
         case EVR_OD:
-            if (!dcmEnableOtherDoubleVRGeneration.get())
+            if (!dcmEnableOtherDoubleStringVRGeneration.get())
             {
-                if (dcmEnableUnknownVRGeneration.get())
-                    evr = EVR_UN; /* handle OD as if UN */
-                else
-                    evr = EVR_OB; /* handle OD as if OB */
-            }
-            break;
-        case EVR_OL:
-            if (!dcmEnableOtherLongVRGeneration.get())
-            {
-                if (dcmEnableUnknownVRGeneration.get())
-                    evr = EVR_UN; /* handle OL as if UN */
-                else
-                    evr = EVR_OB; /* handle OL as if OB */
-            }
-            break;
-        case EVR_UR:
-            if (!dcmEnableUniversalResourceIdentifierOrLocatorVRGeneration.get())
-            {
-                if (dcmEnableUnlimitedTextVRGeneration.get())
-                    evr = EVR_UT; /* handle UR as if UT */
-                else if (dcmEnableUnknownVRGeneration.get())
-                    evr = EVR_UN; /* handle UR as if UN */
-                else
-                    evr = EVR_OB; /* handle UR as if OB */
-            }
-            break;
-        case EVR_UC:
-            if (!dcmEnableUnlimitedCharactersVRGeneration.get())
-            {
-                if (dcmEnableUnknownVRGeneration.get())
-                    evr = EVR_UN; /* handle UC as if UN */
-                else
-                    evr = EVR_OB; /* handle UC as if OB */
+                DCMDATA_TRACE("DcmVR::getValidEVR() VR=\"OD\" replaced by \"OB\" since support is disabled");
+                evr = EVR_OB; /* handle OD as if OB */
             }
             break;
         default:
             /* in all other cases, do nothing */
             break;
     }
-    if (oldVR != evr)
-    {
-        DCMDATA_TRACE("DcmVR::getValidEVR() VR=\"" << DcmVR(oldVR).getVRName()
-            << "\" replaced by \"" << DcmVR(evr).getVRName() << "\" since support is disabled");
-    }
 
     return evr;
 }
