@@ -1,6 +1,6 @@
 /*
  *
- *  Copyright (C) 1994-2016, OFFIS e.V.
+ *  Copyright (C) 1994-2011, OFFIS e.V.
  *  All rights reserved.  See COPYRIGHT file for details.
  *
  *  This software and supporting documentation were developed by
@@ -59,70 +59,14 @@ DcmFloatingPointDouble &DcmFloatingPointDouble::operator=(const DcmFloatingPoint
 }
 
 
-int DcmFloatingPointDouble::compare(const DcmElement& rhs) const
-{
-    int result = DcmElement::compare(rhs);
-    if (result != 0)
-    {
-        return result;
-    }
-
-    /* cast away constness (dcmdata is not const correct...) */
-    DcmFloatingPointDouble* myThis = NULL;
-    DcmFloatingPointDouble* myRhs = NULL;
-    myThis = OFconst_cast(DcmFloatingPointDouble*, this);
-    myRhs = OFstatic_cast(DcmFloatingPointDouble*, OFconst_cast(DcmElement*, &rhs));
-
-    /* iterate over all components and test equality */
-    unsigned long thisVM = myThis->getVM();
-    for (unsigned long count = 0; count < thisVM; count++)
-    {
-        Float64 val = 0;
-        if (myThis->getFloat64(val, count).good())
-        {
-            Float64 rhsVal = 0;
-            if (myRhs->getFloat64(rhsVal, count).good())
-            {
-                if (val > rhsVal)
-                {
-                    return 1;
-                }
-                else if (val < rhsVal)
-                {
-                    return -1;
-                }
-            }
-            else
-            {
-                break; // values equal until this point (rhs shorter)
-            }
-        }
-    }
-
-    /* we get here if all values are equal. Now look at the number of components */
-    unsigned long rhsVM = myRhs->getVM();
-    if (thisVM < rhsVM)
-    {
-        return -1;
-    }
-    else if (thisVM > rhsVM)
-    {
-        return 1;
-    }
-
-    /* all values as well as VM equal: objects are equal */
-    return 0;
-}
-
-
 OFCondition DcmFloatingPointDouble::copyFrom(const DcmObject& rhs)
 {
-    if (this != &rhs)
-    {
-        if (rhs.ident() != ident()) return EC_IllegalCall;
-        *this = OFstatic_cast(const DcmFloatingPointDouble &, rhs);
-    }
-    return EC_Normal;
+  if (this != &rhs)
+  {
+    if (rhs.ident() != ident()) return EC_IllegalCall;
+    *this = OFstatic_cast(const DcmFloatingPointDouble &, rhs);
+  }
+  return EC_Normal;
 }
 
 
@@ -165,7 +109,7 @@ void DcmFloatingPointDouble::print(STD_NAMESPACE ostream&out,
         errorFlag = getFloat64Array(doubleVals);
         if (doubleVals != NULL)
         {
-            const unsigned long count = getLengthField() / OFstatic_cast(unsigned long, sizeof(Float64)) /* do not use getVM()! */;
+            const unsigned long count = getVM();
             const unsigned long maxLength = (flags & DCMTypes::PF_shortenLongTagValues) ?
                 DCM_OptPrintLineLength : OFstatic_cast(unsigned long, -1) /*unlimited*/;
             unsigned long printedLength = 0;
