@@ -1,6 +1,6 @@
 /*
  *
- *  Copyright (C) 1994-2014, OFFIS e.V.
+ *  Copyright (C) 1994-2013, OFFIS e.V.
  *  All rights reserved.  See COPYRIGHT file for details.
  *
  *  This software and supporting documentation were developed by
@@ -68,62 +68,14 @@ DcmOtherByteOtherWord &DcmOtherByteOtherWord::operator=(const DcmOtherByteOtherW
 }
 
 
-int DcmOtherByteOtherWord::compare(const DcmElement& rhs) const
-{
-    int result = DcmElement::compare(rhs);
-    if (result != 0)
-    {
-        return result;
-    }
-
-    /* cast away constness (dcmdata is not const correct...) */
-    DcmOtherByteOtherWord* myThis = NULL;
-    DcmOtherByteOtherWord* myRhs = NULL;
-    myThis = OFconst_cast(DcmOtherByteOtherWord*, this);
-    myRhs =  OFstatic_cast(DcmOtherByteOtherWord*, OFconst_cast(DcmElement*, &rhs));
-
-    unsigned long thisLength = myThis->getLength();
-    unsigned long rhsLength= myRhs->getLength();
-    Uint8* thisData = OFstatic_cast(Uint8*, myThis->getValue());
-    Uint8* rhsData = OFstatic_cast(Uint8*, myRhs->getValue());
-    unsigned long maxLength = (thisLength > rhsLength) ? rhsLength : thisLength;
-    /* iterate over all components and test equality */
-    for (unsigned long count = 0; count < maxLength; count++)
-    {
-        if (thisData[count] > rhsData[count])
-        {
-            return 1;
-        }
-        else if (thisData[count] < rhsData[count])
-        {
-            return -1;
-        }
-        /* otherwise they are equal, continue comparison */
-    }
-
-    /* we get here if all values are equal. Now look at the number of components. */
-    if (thisLength < rhsLength)
-    {
-        return -1;
-    }
-    else if (thisLength > rhsLength)
-    {
-        return 1;
-    }
-
-    /* all values as well as VM equal: objects are equal */
-    return 0;
-}
-
-
 OFCondition DcmOtherByteOtherWord::copyFrom(const DcmObject& rhs)
 {
-    if (this != &rhs)
-    {
-        if (rhs.ident() != ident()) return EC_IllegalCall;
-        *this = OFstatic_cast(const DcmOtherByteOtherWord &, rhs);
-    }
-    return EC_Normal;
+  if (this != &rhs)
+  {
+    if (rhs.ident() != ident()) return EC_IllegalCall;
+    *this = OFstatic_cast(const DcmOtherByteOtherWord &, rhs);
+  }
+  return EC_Normal;
 }
 
 
