@@ -1,6 +1,6 @@
 /*
  *
- *  Copyright (C) 2001-2014, OFFIS e.V.
+ *  Copyright (C) 2001-2013, OFFIS e.V.
  *  All rights reserved.  See COPYRIGHT file for details.
  *
  *  This software and supporting documentation were developed by
@@ -337,8 +337,20 @@ int main(int argc, char *argv[])
       cmd.endOptionBlock();
 
       cmd.beginOptionBlock();
-      if (cmd.findOption("--enable-new-vr")) dcmEnableGenerationOfNewVRs();
-      if (cmd.findOption("--disable-new-vr")) dcmDisableGenerationOfNewVRs();
+      if (cmd.findOption("--enable-new-vr"))
+      {
+          dcmEnableUnknownVRGeneration.set(OFTrue);
+          dcmEnableUnlimitedTextVRGeneration.set(OFTrue);
+          dcmEnableOtherFloatStringVRGeneration.set(OFTrue);
+          dcmEnableOtherDoubleStringVRGeneration.set(OFTrue);
+      }
+      if (cmd.findOption("--disable-new-vr"))
+      {
+          dcmEnableUnknownVRGeneration.set(OFFalse);
+          dcmEnableUnlimitedTextVRGeneration.set(OFFalse);
+          dcmEnableOtherFloatStringVRGeneration.set(OFFalse);
+          dcmEnableOtherDoubleStringVRGeneration.set(OFFalse);
+      }
       cmd.endOptionBlock();
 
       cmd.beginOptionBlock();
