@@ -1,6 +1,6 @@
 /*
  *
- *  Copyright (C) 1996-2010, OFFIS e.V.
+ *  Copyright (C) 1996-2011, OFFIS e.V.
  *  All rights reserved.  See COPYRIGHT file for details.
  *
  *  This software and supporting documentation were developed by
@@ -17,13 +17,6 @@
  *
  *  Purpose: DicomDisplayFunction (Header)
  *
- *  Last Update:      $Author: joergr $
- *  Update Date:      $Date: 2010-10-14 13:16:26 $
- *  CVS/RCS Revision: $Revision: 1.25 $
- *  Status:           $State: Exp $
- *
- *  CVS/RCS Log at end of file
- *
  */
 
 
@@ -34,6 +27,8 @@
 
 #include "dcmtk/ofstd/oftypes.h"
 
+#include "dcmtk/dcmimgle/didefine.h"
+
 /*------------------------*
  *  forward declarations  *
  *------------------------*/
@@ -57,7 +52,7 @@ class DiDisplayLUT;
 /** Class to handle hardcopy and softcopy device characteristics file
  *  and manage display LUTs (for calibration)
  */
-class DiDisplayFunction
+class DCMTK_DCMIMGLE_EXPORT DiDisplayFunction
 {
 
  public:
@@ -490,96 +485,3 @@ class DiDisplayFunction
 
 
 #endif
-
-
-/*
- *
- * CVS/RCS Log:
- * $Log: didispfn.h,v $
- * Revision 1.25  2010-10-14 13:16:26  joergr
- * Updated copyright header. Added reference to COPYRIGHT file.
- *
- * Revision 1.24  2010-03-01 09:08:46  uli
- * Removed some unnecessary include directives in the headers.
- *
- * Revision 1.23  2005-12-08 16:47:37  meichel
- * Changed include path schema for all DCMTK header files
- *
- * Revision 1.22  2003/12/08 18:18:35  joergr
- * Removed leading underscore characters from preprocessor symbols (reserved
- * symbols). Updated CVS header.
- *
- * Revision 1.21  2003/03/12 14:56:14  joergr
- * Removed default value from parameter "useAmb" in method convertODtoLumTable.
- *
- * Revision 1.20  2003/02/12 11:35:16  joergr
- * Added Dmin/max support to CIELAB calibration routines.
- *
- * Revision 1.19  2003/02/11 16:32:02  joergr
- * Added two new functions to determine the luminance/OD value of a particular
- * DDL according to the device's characteristic curve and vice versa.
- *
- * Revision 1.18  2003/02/11 10:01:14  joergr
- * Added support for Dmin/max to calibration routines (required for printers).
- *
- * Revision 1.17  2002/07/19 08:24:21  joergr
- * Enhanced/corrected comments.
- *
- * Revision 1.16  2002/07/18 12:29:08  joergr
- * Added support for hardcopy and softcopy input devices (camera and scanner).
- * Added polygonal curve fitting algorithm as an alternate interpolation
- * method.
- *
- * Revision 1.15  2002/07/03 13:50:24  joergr
- * Fixed inconsistencies regarding the handling of ambient light.
- *
- * Revision 1.14  2002/07/02 16:23:42  joergr
- * Added support for hardcopy devices to the calibrated output routines.
- *
- * Revision 1.13  2001/06/01 15:49:40  meichel
- * Updated copyright header
- *
- * Revision 1.12  2000/03/08 16:24:15  meichel
- * Updated copyright header.
- *
- * Revision 1.11  2000/03/06 18:19:35  joergr
- * Moved get-method to base class, renamed method and made method virtual to
- * avoid hiding of methods (reported by Sun CC 4.2).
- *
- * Revision 1.10  1999/10/18 15:05:51  joergr
- * Enhanced command line tool dcmdspfn (added new options).
- *
- * Revision 1.9  1999/10/18 10:15:50  joergr
- * Moved min/max value determination to display function base class. Now the
- * actual min/max values are also used for GSDFunction (instead of first and
- * last luminance value).
- *
- * Revision 1.8  1999/09/17 12:08:24  joergr
- * Added/changed/completed DOC++ style comments in the header files.
- *
- * Revision 1.7  1999/09/10 08:45:18  joergr
- * Added support for CIELAB display function.
- *
- * Revision 1.6  1999/03/24 17:19:20  joergr
- * Added/Modified comments and formatting.
- * Added support for Barten transformation from 2 to 7 bits input (now: 2-16).
- *
- * Revision 1.5  1999/03/03 11:47:42  joergr
- * Added support to specify ambient light value (re: Barten transformation).
- *
- * Revision 1.4  1999/02/23 16:55:32  joergr
- * Added tool to export display curves to a text file.
- *
- * Revision 1.3  1999/02/11 15:44:22  joergr
- * Removed unused parameter / member variable.
- *
- * Revision 1.2  1999/02/05 16:43:12  joergr
- * Added optional parameter to method convertPValueToDDL to specify width
- * of output data (number of bits).
- *
- * Revision 1.1  1999/02/03 17:46:37  joergr
- * Added support for calibration according to Barten transformation (incl.
- * a DISPLAY file describing the monitor characteristic).
- *
- *
- */
