@@ -383,15 +383,7 @@ class DiInputPixelTemplate
             /* use a non-throwing new here (if available) because the allocated buffer can be huge */
             pixel = new (std::nothrow) T1[count_T1 + extraByte];
 #else
-            /* make sure that the pointer is set to NULL in case of error */
-            try
-            {
-                pixel = new T1[count_T1 + extraByte];
-            }
-            catch (STD_NAMESPACE bad_alloc const &)
-            {
-                pixel = NULL;
-            }
+            pixel = new T1[count_T1 + extraByte];
 #endif
             if (pixel != NULL)
             {
@@ -459,15 +451,7 @@ class DiInputPixelTemplate
             /* use a non-throwing new here (if available) because the allocated buffer can be huge */
             Data = new (std::nothrow) T2[Count];
 #else
-            /* make sure that the pointer is set to NULL in case of error */
-            try
-            {
-                Data = new T2[Count];
-            }
-            catch (STD_NAMESPACE bad_alloc const &)
-            {
-                Data = NULL;
-            }
+            Data = new T2[Count];
 #endif
             if (Data != NULL)
             {
