@@ -1,6 +1,6 @@
 /*
  *
- *  Copyright (C) 1996-2015, OFFIS e.V.
+ *  Copyright (C) 1996-2012, OFFIS e.V.
  *  All rights reserved.  See COPYRIGHT file for details.
  *
  *  This software and supporting documentation were developed by
@@ -228,7 +228,7 @@ class DiScaleTemplate
             else if ((this->Dest_X % this->Src_X == 0) && (this->Dest_Y % this->Src_Y == 0))
                 replicatePixel(src, dest);                                            // replication
             else if ((this->Src_X % this->Dest_X == 0) && (this->Src_Y % this->Dest_Y == 0))
-                suppressPixel(src, dest);                                             // suppression
+                suppressPixel(src, dest);                                             // supression
             else
                 scalePixel(src, dest);                                                // general scaling
         }
@@ -727,23 +727,10 @@ class DiScaleTemplate
                 {
                     by = y_factor * OFstatic_cast(double, y);
                     ey = y_factor * (OFstatic_cast(double, y) + 1.0);
-                    if (ey > this->Src_Y)
-                    {
-#ifdef DEBUG            // this output is only useful for debugging purposes
-                        DCMIMGLE_TRACE("  limiting value of 'ey' to 'Src_Y': " << ey << " -> " << this->Src_Y);
-#endif
-                        // see reducePixel()
-                        ey = this->Src_Y;
-                    }
                     byi = OFstatic_cast(int, by);
                     eyi = OFstatic_cast(int, ey);
                     if (OFstatic_cast(double, eyi) == ey)
-                    {
-#ifdef DEBUG            // this output is only useful for debugging purposes
-                        DCMIMGLE_TRACE("  decreasing value of 'eyi' by 1: " << eyi << " -> " << (eyi - 1));
-#endif
                         --eyi;
-                    }
                     y_part = OFstatic_cast(double, eyi) / y_factor;
                     b_factor = y_part - OFstatic_cast(double, y);
                     t_factor = (OFstatic_cast(double, y) + 1.0) - y_part;
@@ -752,23 +739,10 @@ class DiScaleTemplate
                         value = 0;
                         bx = x_factor * OFstatic_cast(double, x);
                         ex = x_factor * (OFstatic_cast(double, x) + 1.0);
-                        if (ex > this->Src_X)
-                        {
-#ifdef DEBUG                // this output is only useful for debugging purposes
-                            DCMIMGLE_TRACE("  limiting value of 'ex' to 'Src_X': " << ex << " -> " << this->Src_X);
-#endif
-                            // see reducePixel()
-                            ex = this->Src_X;
-                        }
                         bxi = OFstatic_cast(int, bx);
                         exi = OFstatic_cast(int, ex);
                         if (OFstatic_cast(double, exi) == ex)
-                        {
-#ifdef DEBUG                // this output is only useful for debugging purposes
-                            DCMIMGLE_TRACE("  decreasing value of 'exi' by 1: " << exi << " -> " << (exi - 1));
-#endif
                             --exi;
-                        }
                         x_part = OFstatic_cast(double, exi) / x_factor;
                         l_factor = x_part - OFstatic_cast(double, x);
                         r_factor = (OFstatic_cast(double, x) + 1.0) - x_part;
@@ -851,21 +825,11 @@ class DiScaleTemplate
                 {
                     by = y_factor * OFstatic_cast(double, y);
                     ey = y_factor * (OFstatic_cast(double, y) + 1.0);
-                    if (ey > this->Src_Y)
-                    {
-#ifdef DEBUG            // this output is only useful for debugging purposes
-                        DCMIMGLE_TRACE("  limiting value of 'ey' to 'Src_Y': " << ey << " -> " << this->Src_Y);
-#endif
-                        // yes, this can happen due to rounding, e.g. double(943) / double(471) * double(471)
-                        // is something like 943.00000000000011368683772161602974 and then, the eyi == ey check
-                        // fails to bring eyi back into range!
-                        ey = this->Src_Y;
-                    }
                     byi = OFstatic_cast(int, by);
                     eyi = OFstatic_cast(int, ey);
-                    if (OFstatic_cast(double, eyi) == ey)
+                    if (ey - OFstatic_cast(double, eyi) < 0.00001)      // check whether difference falls below a threshold
                     {
-#ifdef DEBUG            // this output is only useful for debugging purposes
+#ifdef DEBUG                                                            // this output is only useful for debugging purposes
                         DCMIMGLE_TRACE("  decreasing value of 'eyi' by 1: " << eyi << " -> " << (eyi - 1));
 #endif
                         --eyi;
@@ -877,19 +841,11 @@ class DiScaleTemplate
                         value = 0;
                         bx = x_factor * OFstatic_cast(double, x);
                         ex = x_factor * (OFstatic_cast(double, x) + 1.0);
-                        if (ex > this->Src_X)
-                        {
-#ifdef DEBUG                // this output is only useful for debugging purposes
-                            DCMIMGLE_TRACE("  limiting value of 'ex' to 'Src_X': " << ex << " -> " << this->Src_X);
-#endif
-                            // see above comment
-                            ex = this->Src_X;
-                        }
                         bxi = OFstatic_cast(int, bx);
                         exi = OFstatic_cast(int, ex);
-                        if (OFstatic_cast(double, exi) == ex)
+                        if (ex - OFstatic_cast(double, exi) < 0.00001)  // check whether difference falls below a threshold
                         {
-#ifdef DEBUG                // this output is only useful for debugging purposes
+#ifdef DEBUG                                                            // this output is only useful for debugging purposes
                             DCMIMGLE_TRACE("  decreasing value of 'exi' by 1: " << exi << " -> " << (exi - 1));
 #endif
                             --exi;
@@ -987,10 +943,7 @@ class DiScaleTemplate
                         dOff = (1.0 < dOff) ? 1.0 : dOff;
                         for (y = 0; y < this->Src_Y; ++y)
                         {
-                            // use floating points in order to avoid possible integer overflow
-                            const double v1 = OFstatic_cast(double, *(pCurrSrc));
-                            const double v2 = OFstatic_cast(double, *(pCurrSrc + 1));
-                            *(pCurrTemp) = OFstatic_cast(T, v1 + (v2 - v1) * dOff);
+                            *(pCurrTemp) = OFstatic_cast(T, *(pCurrSrc) + (*(pCurrSrc + 1) - *(pCurrSrc)) * dOff);
                             pCurrSrc += Columns;
                             pCurrTemp += this->Dest_X;
                         }
@@ -1023,10 +976,7 @@ class DiScaleTemplate
                         dOff = (1.0 < dOff) ? 1.0 : dOff;
                         for (x = this->Dest_X; x != 0; --x)
                         {
-                            // use floating points in order to avoid possible integer overflow
-                            const double v1 = OFstatic_cast(double, *(pCurrTemp));
-                            const double v2 = OFstatic_cast(double, *(pCurrTemp + this->Dest_X));
-                            *(pD++) = OFstatic_cast(T, v1 + (v2 - v1) * dOff);
+                            *(pD++) = OFstatic_cast(T, *(pCurrTemp) + (*(pCurrTemp + this->Dest_X) - *(pCurrTemp)) * dOff);
                             pCurrTemp++;
                         }
                         // don't go beyond the source data
