@@ -1,6 +1,6 @@
 /*
  *
- *  Copyright (C) 2012-2015, OFFIS e.V.
+ *  Copyright (C) 2012-2013, OFFIS e.V.
  *  All rights reserved.  See COPYRIGHT file for details.
  *
  *  This software and supporting documentation were developed by
@@ -29,7 +29,7 @@
 #include "dcmtk/ofstd/ofmem.h"      /* For OFshared_ptr */
 
 /** Class that encapsulates an SCP configuration that is needed in order to
- *  configure the service negotiation behavior (presentation contexts, AE
+ *  configure the service negotiation behaviour (presentation contexts, AE
  *  title, listening port, etc) as well as some runtime configuration like
  *  the DIMSE timeout. The configuration, however, is not updated to reflect
  *  any runtime connection information, e.g. information about the current
@@ -65,7 +65,7 @@ public:
   OFCondition evaluateIncomingAssociation(T_ASC_Association &assoc) const;
 
   /* ************************************************************* */
-  /*             Set methods for configuring SCP behavior          */
+  /*             Set methods for configuring SCP behaviour         */
   /* ************************************************************* */
 
   /** Add abstract syntax to presentation contexts the SCP is able to negotiate with SCUs.
@@ -79,7 +79,7 @@ public:
    *  @return EC_Normal if adding was successful, an error code otherwise
    */
   OFCondition addPresentationContext(const OFString &abstractSyntax,
-                                     const OFList<OFString> &xferSyntaxes,
+                                     const OFList<OFString> xferSyntaxes,
                                      const T_ASC_SC_ROLE role = ASC_SC_ROLE_DEFAULT,
                                      const OFString &profile = "DEFAULT");
 
@@ -91,7 +91,7 @@ public:
 
   /** Set AE title of the server
    *  @param aetitle [in] The AE title of the server. By default, all SCU association requests
-   *                      calling another AE title will be rejected. This behavior can be
+   *                      calling another AE title will be rejected. This behaviour can be
    *                      changed by using the setRespondWithCalledAETitle() method.
    */
   void setAETitle(const OFString &aetitle);
@@ -112,8 +112,8 @@ public:
   OFCondition loadAssociationCfgFile(const OFString &assocFile);
 
   /** If an association profile should be selected, either by loading an association
-   *  configuration file or using the addPresentationContext() function, one of those can
-   *  be selected and checked for validity using this method.
+   *  configuration file or using the addAbstractSyntax() function, one of those can be
+   *  selected and checked for validity using this method.
    *  @param profileName [in] The name of the association profile which must be configured
    *                          before being selected here
    *  @return EC_Normal if selecting/checking was successful, an error code otherwise
@@ -179,7 +179,7 @@ public:
   void setVerbosePCMode(const OFBool mode);
 
   /** Enables or disables looking up the host name from a connecting system.
-   *  Note that this sets a GLOBAL flag in DCMTK, i.e. the behavior changes
+   *  Note that this sets a GLOBAL flag in DCMTK, i.e. the behaviour changes
    *  for all servers. This should be changed in the future.
    *  @param mode [in] OFTrue, if hostname lookup should be enabled,
    *              OFFalse for disabling it.
@@ -246,7 +246,7 @@ public:
   /** Returns connection timeout
    *  @return TCP/IP connection timeout in seconds
    */
-  Uint32 getConnectionTimeout() const;
+  Uint32 getConnnectionTimeout() const;
 
   /** Returns the verbose presentation context mode configured specifying whether details on
    *  the presentation contexts (negotiated during association setup) should be shown in
@@ -268,40 +268,8 @@ public:
    */
   OFBool getProgressNotificationMode() const;
 
-  /** Dump presentation contexts to given output stream, useful for debugging.
-   *  @param out [out] The output stream
-   *  @param profileName [in] The profile to dump. If empty (default), the currently
-   *                     selected profile is dumped.
-   */
-  void dumpPresentationContexts(STD_NAMESPACE ostream &out,
-                                OFString profileName = "");
-
 protected:
 
-  /** Mangles a given string into valid profile name.
-   *  Removes all spaces, and converts lower case to upper case
-   *  characters.
-   *  @param profile [in] The unmangled profile name
-   *  @return The mangled profile name
-   */
-  OFString mangleProfileName(const OFString& profile) const;
-
-  /** Convert number to string
-   *  @param num [in] The integer number to convert
-   *  @return The string representing the given number
-   */
-  OFString numToString(const size_t num) const;
-
-  /** Add given list of transfers syntaxes under given name to SCP's
-   *  association configuration.
-   *  @param tsListName [in] The name of the transfer syntax list
-   *                    to create
-   *  @param ts [in] The list of transfer snytaxes to add
-   *  @return EC_Normal if adding was successful, error otherwise
-   */
-  OFCondition addNewTSList(const OFString& tsListName,
-                           const OFList<OFString>& ts);
-
   /// Association configuration. May be filled from association configuration file or by
   /// adding presentation contexts by calling addPresentationContext() (or both)
   DcmAssociationConfiguration m_assocConfig;
@@ -315,7 +283,7 @@ protected:
 
   /// AE title to be used for responding to SCU (default: DCMTK_SCP). This value is not
   /// evaluated if the the SCP is configured to respond to any association requests with the
-  /// name the SCU used as called AE title (which is the SCP's default behavior); see
+  /// name the SCU used as called AE title (which is the SCP's default behaviour); see
   /// setRespondWithCalledAETitle().
   OFString m_aetitle;
 
