@@ -1,6 +1,6 @@
 /*
  *
- *  Copyright (C) 1994-2015, OFFIS e.V.
+ *  Copyright (C) 1994-2013, OFFIS e.V.
  *  All rights reserved.  See COPYRIGHT file for details.
  *
  *  This software and supporting documentation were partly developed by
@@ -582,8 +582,8 @@ ascRole2dulRole(T_ASC_SC_ROLE role)
     return dr;
 }
 
-const char*
-ASC_role2String(T_ASC_SC_ROLE role)
+static const char*
+ascRole2String(T_ASC_SC_ROLE role)
 {
     const char* s = NULL;
     switch (role) {
@@ -698,11 +698,7 @@ ASC_addPresentationContext(
     lst = params->DULparams.requestedPresentationContext;
     if (lst == NULL) {
         lst = LST_Create();
-        if (lst == NULL)
-        {
-            free(pc);
-            return EC_MemoryExhausted;
-        }
+        if (lst == NULL) return EC_MemoryExhausted;
     }
 
     LST_Enqueue(&lst, (LST_NODE*)pc);
@@ -873,8 +869,8 @@ ASC_acceptPresentationContext(
             {
                 proposedContext->result = ASC_P_NOREASON;
                 DCMNET_ERROR("ASSOC: SCP/SCU role selection failed, proposed ("
-                    << ASC_role2String(dulRole2ascRole(proposedContext->proposedSCRole))
-                    << ") and accepted role (" << ASC_role2String(acceptedRole) << ") are incompatible");
+                    << ascRole2String(dulRole2ascRole(proposedContext->proposedSCRole))
+                    << ") and accepted role (" << ascRole2String(acceptedRole) << ") are incompatible");
                 return ASC_SCPSCUROLESELECTIONFAILED;
             }
         }
@@ -1164,12 +1160,6 @@ ASC_acceptContextsWithTransferSyntax(
     OFBool abstractOK = OFFalse;
 
     n = ASC_countPresentationContexts(params);
-    // No presentation context proposed at all? Return error.
-    if (n == 0)
-    {
-      return ASC_NOPRESENTATIONCONTEXTPROPOSED;
-    }
-
     for (i = 0; i < n; i++) {
         cond = ASC_getPresentationContext(params, i, &pc);
         if (cond.bad()) return cond;
@@ -1460,11 +1450,11 @@ ASC_dumpPresentationContext(T_ASC_PresentationContext * p)
     }
 
     outstream << "    Proposed SCP/SCU Role: "
-        << ASC_role2String(p->proposedRole) << OFendl;
+        << ascRole2String(p->proposedRole) << OFendl;
 
     if (p->resultReason != ASC_P_NOTYETNEGOTIATED) {
         outstream << "    Accepted SCP/SCU Role: "
-            << ASC_role2String(p->acceptedRole) << OFendl;
+            << ascRole2String(p->acceptedRole) << OFendl;
     }
 
     if (p->resultReason == ASC_P_ACCEPTANCE) {
@@ -1684,10 +1674,6 @@ ASC_associationWaiting(T_ASC_Network * network, int timeout)
 #else
     nfound = select(s + 1, &fdset, NULL, NULL, &t);
 #endif
-    if (DCM_dcmnetLogger.isEnabledFor(OFLogger::DEBUG_LOG_LEVEL))
-    {
-      DU_logSelectResult(nfound);
-    }
     return nfound > 0;
 }
 
