@@ -1,6 +1,6 @@
 /*
  *
- *  Copyright (C) 2009-2016, OFFIS e.V.
+ *  Copyright (C) 2009-2014, OFFIS e.V.
  *  All rights reserved.  See COPYRIGHT file for details.
  *
  *  This software and supporting documentation were developed by
@@ -22,6 +22,7 @@
 #include "dcmtk/config/osconfig.h" /* make sure OS specific configuration is included first */
 
 #include "dcmtk/dcmnet/scp.h"
+#include "dcmtk/dcmnet/diutil.h"
 #include "dcmtk/dcmnet/assoc.h"
 #include "dcmtk/dcmdata/dcostrmf.h" /* for class DcmOutputFileStream */
 
@@ -308,7 +309,7 @@ OFCondition DcmSCP::waitForAssociationRQ(T_ASC_Network *network)
   if (m_assoc != NULL)
     return DIMSE_ILLEGALASSOCIATION;
 
-  Uint32 timeout = m_cfg->getConnectionTimeout();
+  Uint32 timeout = m_cfg->getConnnectionTimeout();
 
   // Listen to a socket for timeout seconds and wait for an association request
   OFCondition cond = ASC_receiveAssociation( network, &m_assoc, m_cfg->getMaxReceivePDULength(), NULL, NULL, OFFalse,
@@ -800,9 +801,9 @@ Uint16 DcmSCP::checkSTORERequest(T_DIMSE_C_StoreRQ & /*reqMessage*/,
 
 // -- C-FIND --
 
-OFCondition DcmSCP::receiveFINDRequest(T_DIMSE_C_FindRQ &reqMessage,
-                                       const T_ASC_PresentationContextID presID,
-                                       DcmDataset *&reqDataset)
+OFCondition DcmSCP::handleFINDRequest(T_DIMSE_C_FindRQ &reqMessage,
+                                      const T_ASC_PresentationContextID presID,
+                                      DcmDataset *&reqDataset)
 {
   // Do some basic validity checks
   if (m_assoc == NULL)
@@ -915,10 +916,10 @@ OFCondition DcmSCP::checkForCANCEL(T_ASC_PresentationContextID presID,
 
 // -- C-MOVE --
 
-OFCondition DcmSCP::receiveMOVERequest(T_DIMSE_C_MoveRQ &reqMessage,
-                                       const T_ASC_PresentationContextID presID,
-                                       DcmDataset *&reqDataset,
-                                       OFString &moveDest)
+OFCondition DcmSCP::handleMOVERequest(T_DIMSE_C_MoveRQ &reqMessage,
+                                      const T_ASC_PresentationContextID presID,
+                                      DcmDataset *&reqDataset,
+                                      OFString &moveDest)
 {
   // Do some basic validity checks
   if (m_assoc == NULL)
@@ -1039,10 +1040,10 @@ OFCondition DcmSCP::sendMOVEResponse(const T_ASC_PresentationContextID presID,
 
 // -- N-ACTION --
 
-OFCondition DcmSCP::receiveACTIONRequest(T_DIMSE_N_ActionRQ &reqMessage,
-                                         const T_ASC_PresentationContextID presID,
-                                         DcmDataset *&reqDataset,
-                                         Uint16 &actionTypeID)
+OFCondition DcmSCP::handleACTIONRequest(T_DIMSE_N_ActionRQ &reqMessage,
+                                        const T_ASC_PresentationContextID presID,
+                                        DcmDataset *&reqDataset,
+                                        Uint16 &actionTypeID)
 {
   // Do some basic validity checks
   if (m_assoc == NULL)
@@ -1624,11 +1625,11 @@ void DcmSCP::setMaxReceivePDULength(const Uint32 maxRecPDU)
 // ----------------------------------------------------------------------------
 
 OFCondition DcmSCP::addPresentationContext(const OFString &abstractSyntax,
-                                           const OFList<OFString> &xferSyntaxes,
+                                           const OFList<OFString> xferSyntaxes,
                                            const T_ASC_SC_ROLE role,
                                            const OFString &profile)
 {
-  return m_cfg->addPresentationContext(abstractSyntax, xferSyntaxes, role, profile);
+  return m_cfg->addPresentationContext(abstractSyntax,xferSyntaxes,role,profile);
 }
 
 // ----------------------------------------------------------------------------
@@ -1782,9 +1783,9 @@ Uint32 DcmSCP::getDIMSETimeout() const
 
 // ----------------------------------------------------------------------------
 
-Uint32 DcmSCP::getConnectionTimeout() const
+Uint32 DcmSCP::getConnnectionTimeout() const
 {
-  return m_cfg->getConnectionTimeout();
+  return m_cfg->getConnnectionTimeout();
 }
 
 // ----------------------------------------------------------------------------
@@ -1894,21 +1895,21 @@ void DcmSCP::notifyAssociationRequest(const T_ASC_Parameters &params,
 
 // ----------------------------------------------------------------------------
 
-OFBool DcmSCP::checkCalledAETitleAccepted(const OFString& /*calledAETitle*/)
+OFBool DcmSCP::checkCalledAETitleAccepted(const OFString& calledAETitle)
 {
   return OFTrue;
 }
 
 // ----------------------------------------------------------------------------
 
-OFBool DcmSCP::checkCallingAETitleAccepted(const OFString& /*callingAETitle*/)
+OFBool DcmSCP::checkCallingAETitleAccepted(const OFString& callingAETitle)
 {
   return OFTrue;
 }
 
 // ----------------------------------------------------------------------------
 
-OFBool DcmSCP::checkCallingHostAccepted(const OFString& /*hostOrIP*/)
+OFBool DcmSCP::checkCallingHostAccepted(const OFString& hostOrIP)
 {
   return OFTrue;
 }
