@@ -2296,12 +2296,6 @@ void DcmSCU::setACSETimeout(const Uint32 acseTimeout)
 }
 
 
-void DcmSCU::setConnectionTimeout(const Sint32 connectionTimeout)
-{
-  dcmConnectionTimeout.set(connectionTimeout);
-}
-
-
 void DcmSCU::setAssocConfigFileAndProfile(const OFString &filename,
                                           const OFString &profile)
 {
@@ -2401,12 +2395,6 @@ Uint32 DcmSCU::getACSETimeout() const
 }
 
 
-Sint32 DcmSCU::getConnectionTimeout() const
-{
-  return dcmConnectionTimeout.get();
-}
-
-
 OFString DcmSCU::getStorageDir() const
 {
   return m_storageDir;
