@@ -288,7 +288,10 @@ int main(int argc, char *argv[])
 
     if (targetDisableNewVRs)
     {
-      dcmDisableGenerationOfNewVRs();
+      dcmEnableUnknownVRGeneration.set(OFFalse);
+      dcmEnableUnlimitedTextVRGeneration.set(OFFalse);
+      dcmEnableOtherFloatStringVRGeneration.set(OFFalse);
+      dcmEnableOtherDoubleStringVRGeneration.set(OFFalse);
     }
 
     T_ASC_Network *net = NULL; /* the DICOM network and listen port */
