@@ -1,5 +1,5 @@
 /*
- *  Copyright (C) 1999-2014, OFFIS e.V.
+ *  Copyright (C) 1999-2013, OFFIS e.V.
  *  All rights reserved.  See COPYRIGHT file for details.
  *
  *  This software and supporting documentation were developed by
@@ -995,7 +995,10 @@ int main(int argc, char *argv[])
     }
     if (targetDisableNewVRs)
     {
-        dcmDisableGenerationOfNewVRs();
+        dcmEnableUnknownVRGeneration.set(OFFalse);
+        dcmEnableUnlimitedTextVRGeneration.set(OFFalse);
+        dcmEnableOtherFloatStringVRGeneration.set(OFFalse);
+        dcmEnableOtherDoubleStringVRGeneration.set(OFFalse);
     }
 
     OFLOG_INFO(dcmprscuLogger, "Printer parameters for '" <<  opt_printer << "':");
