@@ -1111,7 +1111,10 @@ int main(int argc, char *argv[])
 
     if (networkDisableNewVRs)
     {
-      dcmDisableGenerationOfNewVRs();
+      dcmEnableUnknownVRGeneration.set(OFFalse);
+      dcmEnableUnlimitedTextVRGeneration.set(OFFalse);
+      dcmEnableOtherFloatStringVRGeneration.set(OFFalse);
+      dcmEnableOtherDoubleStringVRGeneration.set(OFFalse);
     }
 
     OFOStringStream verboseParameters;
