@@ -1,6 +1,6 @@
 /*
  *
- *  Copyright (C) 2000-2015, OFFIS e.V.
+ *  Copyright (C) 2000-2014, OFFIS e.V.
  *  All rights reserved.  See COPYRIGHT file for details.
  *
  *  This software and supporting documentation were developed by
@@ -11,12 +11,12 @@
  *    D-26121 Oldenburg, Germany
  *
  *
- *  Module: dcmsr
+ *  Module:  dcmsr
  *
- *  Author: Joerg Riesmeier
+ *  Author:  Joerg Riesmeier
  *
- *  Purpose:
- *    convert the contents of a DICOM structured reporting file to XML format
+ *  Purpose: Convert the contents of a DICOM structured reporting file to
+ *           XML format
  *
  */
 
@@ -78,19 +78,33 @@ static OFCondition writeFile(STD_NAMESPACE ostream &out,
                         OFLOG_DEBUG(dsr2xmlLogger, "use option --charset-assume to manually specify an appropriate character set");
                         result = EC_IllegalCall;
                     } else {
+                        OFString charsetStr(defaultCharset);
                         // use the default character set specified by the user
-                        result = dsrdoc->setSpecificCharacterSet(defaultCharset);
-                        if (dsrdoc->getSpecificCharacterSetType() == DSRTypes::CS_unknown)
-                        {
+                        if (charsetStr == "ISO_IR 192")
+                            dsrdoc->setSpecificCharacterSetType(DSRTypes::CS_UTF8);
+                        else if (charsetStr == "ISO_IR 100")
+                            dsrdoc->setSpecificCharacterSetType(DSRTypes::CS_Latin1);
+                        else if (charsetStr == "ISO_IR 101")
+                            dsrdoc->setSpecificCharacterSetType(DSRTypes::CS_Latin2);
+                        else if (charsetStr == "ISO_IR 109")
+                            dsrdoc->setSpecificCharacterSetType(DSRTypes::CS_Latin3);
+                        else if (charsetStr == "ISO_IR 110")
+                            dsrdoc->setSpecificCharacterSetType(DSRTypes::CS_Latin4);
+                        else if (charsetStr == "ISO_IR 148")
+                            dsrdoc->setSpecificCharacterSetType(DSRTypes::CS_Latin5);
+                        else if (charsetStr == "ISO_IR 144")
+                            dsrdoc->setSpecificCharacterSetType(DSRTypes::CS_Cyrillic);
+                        else if (charsetStr == "ISO_IR 127")
+                            dsrdoc->setSpecificCharacterSetType(DSRTypes::CS_Arabic);
+                        else if (charsetStr == "ISO_IR 126")
+                            dsrdoc->setSpecificCharacterSetType(DSRTypes::CS_Greek);
+                        else if (charsetStr == "ISO_IR 138")
+                            dsrdoc->setSpecificCharacterSetType(DSRTypes::CS_Hebrew);
+                        else {
                             OFLOG_FATAL(dsr2xmlLogger, OFFIS_CONSOLE_APPLICATION << ": Character set '"
                                 << defaultCharset << "' specified with option --charset-assume not supported");
                             result = EC_IllegalCall;
                         }
-                        else if (result.bad())
-                        {
-                            OFLOG_FATAL(dsr2xmlLogger, OFFIS_CONSOLE_APPLICATION << ": Cannot use character set '"
-                                << defaultCharset << "' specified with option --charset-assume: " << result.text());
-                        }
                     }
                 }
                 if (result.good())
@@ -160,7 +174,7 @@ int main(int argc, char *argv[])
         cmd.addOption("--charset-require",      "+Cr",    "require declaration of ext. charset (default)");
         cmd.addOption("--charset-assume",       "+Ca", 1, "[c]harset: string",
                                                           "assume charset c if no extended charset declared");
-        cmd.addOption("--charset-check-all",    "+Cc",    "check all data elements with string values\n(default: only PN, LO, LT, SH, ST, UC and UT)");
+        cmd.addOption("--charset-check-all",    "+Cc",    "check all data elements with string values\n(default: only PN, LO, LT, SH, ST and UT)");
 #ifdef WITH_LIBICONV
         cmd.addOption("--convert-to-utf8",      "+U8",    "convert all element values that are affected\nby Specific Character Set (0008,0005) to UTF-8");
 #endif
@@ -301,8 +315,6 @@ int main(int argc, char *argv[])
             app.checkConflict("--add-schema-reference", "--template-envelope", (opt_writeFlags & DSRTypes::XF_templateElementEnclosesItems) > 0);
             app.checkConflict("--add-schema-reference", "--write-empty-tags", (opt_writeFlags & DSRTypes::XF_writeEmptyTags) > 0);
         }
-        if (opt_writeFlags & DSRTypes::XF_templateIdentifierAsAttribute)
-            app.checkDependence("--attr-template-id", "--write-template-id", (opt_writeFlags & DSRTypes::XF_writeTemplateIdentification) > 0);
         if (opt_writeFlags & DSRTypes::XF_templateElementEnclosesItems)
             app.checkDependence("--template-envelope", "--write-template-id", (opt_writeFlags & DSRTypes::XF_writeTemplateIdentification) > 0);
     }
@@ -399,12 +411,9 @@ int main(int argc, char *argv[])
         } else {
             OFLOG_FATAL(dsr2xmlLogger, OFFIS_CONSOLE_APPLICATION << ": error (" << status.text()
                 << ") reading file: " << ifname);
-            result = 5;
         }
-    } else {
+    } else
         OFLOG_FATAL(dsr2xmlLogger, OFFIS_CONSOLE_APPLICATION << ": invalid filename: <empty string>");
-        result = 6;
-    }
 
     return result;
 }
