@@ -1,6 +1,6 @@
 /*
  *
- *  Copyright (C) 2000-2016, OFFIS e.V.
+ *  Copyright (C) 2000-2013, OFFIS e.V.
  *  All rights reserved.  See COPYRIGHT file for details.
  *
  *  This software and supporting documentation were developed by
@@ -11,12 +11,11 @@
  *    D-26121 Oldenburg, Germany
  *
  *
- *  Module: dcmsr
+ *  Module:  dcmsr
  *
- *  Author: Joerg Riesmeier
+ *  Author:  Joerg Riesmeier
  *
- *  Purpose:
- *    list the contents of a DICOM structured reporting file
+ *  Purpose: List the contents of a dicom structured reporting file
  *
  */
 
@@ -95,9 +94,6 @@ static OFCondition dumpFile(STD_NAMESPACE ostream &out,
             }
         }
     }
-#else
-    // avoid compiler warning on unused variable
-    (void)convertToUTF8;
 #endif
     if (result.good())
     {
@@ -194,9 +190,6 @@ int main(int argc, char *argv[])
         cmd.addOption("--print-invalid-codes",  "+Pi",  "print invalid codes (for debugging purposes)");
         cmd.addOption("--no-invalid-codes",     "-Pi",  "print text \"invalid code\" instead (default)");
         cmd.addOption("--print-template-id",    "+Pt",  "print template identification information");
-      cmd.addSubGroup("enhanced encoding mode:");
-        cmd.addOption("--indicate-enhanced",    "+Pe",  "indicate that enhanced mode is used for codes");
-        cmd.addOption("--no-enhanced-mode",     "-Pe",  "do not indicate enhanced mode (default)");
 #ifdef ANSI_ESCAPE_CODES_AVAILABLE
       cmd.addSubGroup("color:");
         cmd.addOption("--print-color",          "+C",   "use ANSI escape codes for colored output");
@@ -328,13 +321,6 @@ int main(int argc, char *argv[])
         if (cmd.findOption("--print-template-id"))
             opt_printFlags |= DSRTypes::PF_printTemplateIdentification;
 
-        cmd.beginOptionBlock();
-        if (cmd.findOption("--indicate-enhanced"))
-            opt_printFlags |= DSRTypes::PF_indicateEnhancedEncodingMode;
-        if (cmd.findOption("--no-enhanced-mode"))
-            opt_printFlags &= ~DSRTypes::PF_indicateEnhancedEncodingMode;
-        cmd.endOptionBlock();
-
 #ifdef ANSI_ESCAPE_CODES_AVAILABLE
         cmd.beginOptionBlock();
         if (cmd.findOption("--print-color"))
