@@ -1,6 +1,6 @@
 /*
  *
- *  Copyright (C) 2000-2016, OFFIS e.V.
+ *  Copyright (C) 2000-2013, OFFIS e.V.
  *  All rights reserved.  See COPYRIGHT file for details.
  *
  *  This software and supporting documentation were developed by
@@ -89,19 +89,11 @@ class DCMTK_DCMSR_EXPORT DSRCompositeReferenceValue
     virtual OFBool isValid() const;
 
     /** check whether the current reference value is empty.
-     *  Checks whether both mandatory UIDs of the reference value are empty.
+     *  Checks whether both UIDs of the reference value are empty.
      ** @return OFTrue if value is empty, OFFalse otherwise
      */
     virtual OFBool isEmpty() const;
 
-    /** check whether the current reference value is complete, i.e.\ whether both
-     *  mandatory UIDs are non-empty.  This is just a basic check that might be useful
-     *  for "validating" input data.  See isValid() for a more sophisticated way of
-     *  checking the current reference value.
-     ** @return OFTrue if value is complete, OFFalse otherwise
-     */
-    virtual OFBool isComplete() const;
-
     /** print reference value.
      *  The output of a typical composite reference value looks like this: (BasicTextSR,"1.2.3").
      *  If the SOP class UID is unknown, the UID is printed instead of the related name.
@@ -115,12 +107,10 @@ class DCMTK_DCMSR_EXPORT DSRCompositeReferenceValue
     /** read reference value from XML document
      ** @param  doc     document containing the XML file content
      *  @param  cursor  cursor pointing to the starting node
-     *  @param  flags   flag used to customize the reading process (see DSRTypes::XF_xxx)
      ** @return status, EC_Normal if successful, an error code otherwise
      */
     virtual OFCondition readXML(const DSRXMLDocument &doc,
-                                DSRXMLCursor cursor,
-                                const size_t flags);
+                                DSRXMLCursor cursor);
 
     /** write reference value in XML format
      ** @param  stream  output stream to which the XML document is written
@@ -138,13 +128,11 @@ class DCMTK_DCMSR_EXPORT DSRCompositeReferenceValue
      *  @param  tagKey   DICOM tag specifying the attribute (= sequence) which should be read
      *  @param  type     value type of the sequence (valid value: "1", "2", something else)
      *                   This parameter is used for checking purpose, any difference is reported.
-     *  @param  flags    flag used to customize the reading process (see DSRTypes::RF_xxx)
      ** @return status, EC_Normal if successful, an error code otherwise
      */
     virtual OFCondition readSequence(DcmItem &dataset,
                                      const DcmTagKey &tagKey,
-                                     const OFString &type,
-                                     const size_t flags);
+                                     const OFString &type);
 
     /** write referenced SOP sequence to dataset.
      *  If the value is empty an empty sequence (without any items) is written.
@@ -176,13 +164,6 @@ class DCMTK_DCMSR_EXPORT DSRCompositeReferenceValue
         return SOPClassUID;
     }
 
-    /** get name associated with the SOP class UID (if any)
-     ** @param  defaultName  string value that is returned if the SOP class UID is unknown
-     ** @return name associated with the current SOP class UID (might be empty, e.g. in case
-     *          the SOP class UID is empty or 'defaultName' is an empty string)
-     */
-    const OFString getSOPClassName(const OFString &defaultName = "unknown SOP Class UID") const;
-
     /** get SOP instance UID
      ** @return current SOP instance UID (might be invalid or an empty string)
      */
@@ -230,100 +211,30 @@ class DCMTK_DCMSR_EXPORT DSRCompositeReferenceValue
                              const OFString &sopInstanceUID,
                              const OFBool check = OFTrue);
 
-    /** set SOP class UID and SOP instance UID value from dataset.
-     *  Internally, the methods setSOPClassUID() and setSOPInstanceUID() are called with the
-     *  given 'dataset' and the tags DCM_SOPClassUID and DCM_SOPInstanceUID, respectively.
-     *  I.e., the SOP class UID might be set even if the SOP instance UID value is invalid.
-     ** @param  dataset  DICOM dataset from which the UID values should be retrieved
-     *  @param  check    if enabled, check retrieved UID values for validity before setting
-     *                   them.  See checkXXX() for details. Empty values are never accepted.
-     ** @return status, EC_Normal if successful, an error code otherwise
-     */
-    OFCondition setReference(DcmItem &dataset,
-                             const OFBool check = OFTrue);
-
     /** set SOP class UID value.
      *  Before setting the value, it is usually checked.  If the value is invalid, the current
      *  value is not replaced and remains unchanged.
      ** @param  sopClassUID  SOP class UID to be set
      *  @param  check        if enabled, check 'sopClassUID' for validity before setting it.
-     *                       See checkSOPClassUID() for details.  Am empty value is never
+     *                       See checkSOPClassUID() for details.  Empty values are never
      *                       accepted.
      ** @return status, EC_Normal if successful, an error code otherwise
      */
     OFCondition setSOPClassUID(const OFString &sopClassUID,
                                const OFBool check = OFTrue);
 
-    /** set SOP class UID value from element.
-     *  Before setting the value, it is usually checked.  If the value is invalid, the current
-     *  value is not replaced and remains unchanged.
-     ** @param  delem  DICOM element from which the UID value should be retrieved
-     *  @param  pos    index of the value in case of multi-valued elements (0..vm-1)
-     *  @param  check  if enabled, check UID value for validity before setting it.  See
-     *                 checkSOPClassUID() for details.  An empty value is never accepted.
-     ** @return status, EC_Normal if successful, an error code otherwise
-     */
-    OFCondition setSOPClassUID(const DcmElement &delem,
-                               const unsigned long pos = 0,
-                               const OFBool check = OFTrue);
-
-    /** set SOP class UID value from dataset.
-     *  Before setting the value, it is usually checked.  If the value is invalid, the current
-     *  value is not replaced and remains unchanged.
-     ** @param  dataset  DICOM dataset from which the UID value should be retrieved
-     *  @param  tagKey   DICOM tag specifying the attribute from which the value should be
-     *                   retrieved.  The search is limited to the top-level of the dataset.
-     *  @param  pos      index of the value in case of multi-valued elements (0..vm-1)
-     *  @param  check    if enabled, check UID value for validity before setting it.  See
-     *                   checkSOPClassUID() for details.  An empty value is never accepted.
-     ** @return status, EC_Normal if successful, an error code otherwise
-     */
-    OFCondition setSOPClassUID(DcmItem &dataset,
-                               const DcmTagKey &tagKey,
-                               const unsigned long pos = 0,
-                               const OFBool check = OFTrue);
-
     /** set SOP instance UID value.
      *  Before setting the value, it is usually checked.  If the value is invalid, the current
      *  value is not replaced and remains unchanged.
      ** @param  sopInstanceUID  SOP instance UID to be set
      *  @param  check           if enabled, check 'sopInstanceUID' for validity before setting
-     *                          it.  See checkSOPInstanceUID() for details.  An empty value is
+     *                          it.  See checkSOPInstanceUID() for details.  Empty values are
      *                          never accepted.
      ** @return status, EC_Normal if successful, an error code otherwise
      */
     OFCondition setSOPInstanceUID(const OFString &sopInstanceUID,
                                   const OFBool check = OFTrue);
 
-    /** set SOP instance UID value from element.
-     *  Before setting the value, it is usually checked.  If the value is invalid, the current
-     *  value is not replaced and remains unchanged.
-     ** @param  delem  DICOM element from which the UID value should be retrieved
-     *  @param  pos    index of the value in case of multi-valued elements (0..vm-1)
-     *  @param  check  if enabled, check UID value for validity before setting it.  See
-     *                 checkSOPInstanceUID() for details.  An empty value is never accepted.
-     ** @return status, EC_Normal if successful, an error code otherwise
-     */
-    OFCondition setSOPInstanceUID(const DcmElement &delem,
-                                  const unsigned long pos = 0,
-                                  const OFBool check = OFTrue);
-
-    /** set SOP instance UID value from dataset.
-     *  Before setting the value, it is usually checked.  If the value is invalid, the current
-     *  value is not replaced and remains unchanged.
-     ** @param  dataset  DICOM dataset from which the UID value should be retrieved
-     *  @param  tagKey   DICOM tag specifying the attribute from which the value should be
-     *                   retrieved.  The search is limited to the top-level of the dataset.
-     *  @param  pos      index of the value in case of multi-valued elements (0..vm-1)
-     *  @param  check    if enabled, check UID value for validity before setting it.  See
-     *                   checkSOPInstanceUID() for details.  An empty value is never accepted.
-     ** @return status, EC_Normal if successful, an error code otherwise
-     */
-    OFCondition setSOPInstanceUID(DcmItem &dataset,
-                                  const DcmTagKey &tagKey,
-                                  const unsigned long pos = 0,
-                                  const OFBool check = OFTrue);
-
 
   protected:
 
@@ -336,15 +247,13 @@ class DCMTK_DCMSR_EXPORT DSRCompositeReferenceValue
     }
 
     /** read reference value from dataset
-     ** @param  dataset  DICOM dataset from which the value should be read
-     *  @param  flags    flag used to customize the reading process (see DSRTypes::RF_xxx)
+     ** @param  dataset    DICOM dataset from which the value should be read
      ** @return status, EC_Normal if successful, an error code otherwise
      */
-    virtual OFCondition readItem(DcmItem &dataset,
-                                 const size_t flags);
+    virtual OFCondition readItem(DcmItem &dataset);
 
     /** write reference value to dataset
-     ** @param  dataset  DICOM dataset to which the value should be written
+     ** @param  dataset    DICOM dataset to which the value should be written
      ** @return status, EC_Normal if successful, an error code otherwise
      */
     virtual OFCondition writeItem(DcmItem &dataset) const;
