@@ -1,6 +1,6 @@
 /*
  *
- *  Copyright (C) 2000-2016, OFFIS e.V.
+ *  Copyright (C) 2000-2014, OFFIS e.V.
  *  All rights reserved.  See COPYRIGHT file for details.
  *
  *  This software and supporting documentation were developed by
@@ -27,7 +27,6 @@
 #include "dcmtk/config/osconfig.h"   /* make sure OS specific configuration is included first */
 
 #include "dcmtk/dcmsr/dsrdoctr.h"
-#include "dcmtk/dcmsr/dsrrtpl.h"
 #include "dcmtk/dcmsr/dsrsoprf.h"
 #include "dcmtk/dcmsr/dsrrefin.h"
 #include "dcmtk/dcmsr/dsrcsidl.h"
@@ -100,8 +99,8 @@ class DCMTK_DCMSR_EXPORT DSRDocument
 
     /** read SR document from DICOM dataset.
      *  Please note that the current document is also deleted if the reading process fails.
-     *  If logging is enabled, the reason for any error might be obtained from the log output.
-     *  Also warning and debug messages are reported if the respective logger is enabled.
+     *  If logging is enabled, the reason for any error might be obtained from the error/warning
+     *  output.
      ** @param  dataset  reference to DICOM dataset from which the document should be read
      *  @param  flags    optional flag used to customize the reading process (see DSRTypes::RF_xxx).
      *                   E.g. RF_readDigitalSignatures indicates whether to read the digital
@@ -109,8 +108,8 @@ class DCMTK_DCMSR_EXPORT DSRDocument
      *                   and the DigitalSignaturesSequence are read for the general document
      *                   header (equivalent to top-level content item) and each content item
      *                   of the document tree.
-     *                   If not removed manually (with DSRDocumentTree::removeSignatures())
-     *                   the signatures are written back to the dataset when the write() method
+     *                   If not removed manually (with 'DSRDocumentTree::removeSignatures')
+     *                   the signatures are written back to the dataset when the method 'write'
      *                   is called.
      *                   Please note that the two signature sequences for any other sequence
      *                   (e.g. VerifyingObserver or PredecessorDocuments) are never read.
@@ -124,22 +123,18 @@ class DCMTK_DCMSR_EXPORT DSRDocument
      *  member variable section of this class.  Other data is not changed, so be careful
      *  when using this method.
      *  @param  dataset  reference to DICOM dataset from which the data should be read
-     *  @param  flags    optional flag used to customize the reading process (see DSRTypes::RF_xxx)
-     ** @return status, EC_Normal if successful, an error code otherwise
+     *  @return status, EC_Normal if successful, an error code otherwise
      */
-    virtual OFCondition readPatientData(DcmItem &dataset,
-                                        const size_t flags = 0);
+    virtual OFCondition readPatientData(DcmItem &dataset);
 
     /** read study data from DICOM dataset. Also reads patient data.
      *  The list of data elements that are read can be found under "Patient Module" and
      *  "General Study Module" in the member variable section of this class.  Other data
      *  is not changed, so be careful when using this method.
      *  @param  dataset  reference to DICOM dataset from which the data should be read
-     *  @param  flags    optional flag used to customize the reading process (see DSRTypes::RF_xxx)
-     ** @return status, EC_Normal if successful, an error code otherwise
+     *  @return status, EC_Normal if successful, an error code otherwise
      */
-    virtual OFCondition readStudyData(DcmItem &dataset,
-                                      const size_t flags = 0);
+    virtual OFCondition readStudyData(DcmItem &dataset);
 
     /** write current SR document to DICOM dataset.
      *  Please note that the ContentTemplateSequence for the root content item is not written
@@ -147,7 +142,6 @@ class DCMTK_DCMSR_EXPORT DSRDocument
      *  Instead, the template identification has to be set manually for the root CONTAINER
      *  (see DSRDocumentTreeNode::setTemplateIdentification()).  This is because the template
      *  constraints cannot be checked yet.
-     *  If logging is enabled, warning and debug messages are reported to the log output.
      ** @param  dataset      reference to DICOM dataset to which the current document should be
      *                       written.  The 'dataset' is not cleared before writing to it!
      *  @param  markedItems  optional stack where pointers to all 'marked' content items
@@ -208,39 +202,11 @@ class DCMTK_DCMSR_EXPORT DSRDocument
         return DocumentTree;
     }
 
-    /** set document tree.
-     *  Replace the currently stored document tree with the given one.  Please note that the
-     *  given 'tree' is checked before setting it, i.e. only a valid document tree is accepted.
-     *  However, a new SOP instance is never created.  If needed, this has to be done with
-     *  createNewSOPInstance() in addition to or with createNewDocument() before this method
-     *  is called.
-     ** @param  tree  document tree to be set (content will be copied)
-     ** @return status, EC_Normal if successful, an error code otherwise
-     */
-    virtual OFCondition setTree(const DSRDocumentTree &tree);
-
-    /** set document tree from root template.
-     *  Replace the currently stored document tree with the one from the given root template.
-     *  By default, this method expands the tree, i.e. instances of DSRIncludedTemplateTreeNode
-     *  that were added to the tree with DSRDocumentSubTree::includeTemplate() are replaced by
-     *  their content, i.e. by the internally managed subtree.
-     *  Please note that the additional comments on the above setTree() method also apply.
-     ** @param  rootTemplate  template specifying the document tree to be set (content will be
-     *                        copied).  This parameter cannot be "const" because of
-     *                        DSRRootTemplate::getTree(), which is called internally and which
-     *                        modifies the tree.
-     *  @param  expandTree    optional flag that allows for disabling the expanding of the
-     *                        document tree before setting it.  Please note that various
-     *                        output methods like write() or renderHTML() do not yet work on
-     *                        such trees.
-     ** @return status, EC_Normal if successful, an error code otherwise
-     */
-    virtual OFCondition setTreeFromRootTemplate(DSRRootTemplate &rootTemplate,
-                                                const OFBool expandTree = OFTrue);
-
     /** get specific character set type.
-     *  If the type is unknown, the original DICOM defined term can be retrieved
-     *  with the method getSpecificCharacterSet().
+     *  If the type is unknown the original DICOM defined term can be retrieved
+     *  with the method getSpecificCharacterSet().  Please note that only the
+     *  first of possibly multiple values is used to determine the type from the
+     *  given DICOM code string (multiple character sets are not yet supported).
      ** @return character set (might be CS_invalid/unknown if not supported)
      */
     virtual E_CharacterSet getSpecificCharacterSetType() const;
@@ -252,7 +218,7 @@ class DCMTK_DCMSR_EXPORT DSRDocument
     virtual OFCondition setSpecificCharacterSetType(const E_CharacterSet characterSet);
 
     /** get document preliminary flag.
-     *  @note Not applicable to Key Object Selection Documents.
+     *  Not applicable to Key Object Selection Documents.
      ** @return preliminary flag (might be PF_invalid if not specified)
      */
     virtual E_PreliminaryFlag getPreliminaryFlag() const;
@@ -260,7 +226,6 @@ class DCMTK_DCMSR_EXPORT DSRDocument
     /** set document preliminary flag.
      *  According to the DICOM standard, the concept of "completeness" is independent of the
      *  concept of "preliminary" or "final".  Therefore, this flag can be specified separately.
-     *  @note Not applicable to Key Object Selection Documents.
      ** @param  flag  preliminary flag to be set (use PF_invalid to omit this optional value)
      ** @return status, EC_Normal if successful, an error code otherwise
      */
@@ -269,13 +234,13 @@ class DCMTK_DCMSR_EXPORT DSRDocument
     /** get document completion flag.
      *  According to the DICOM standard, this flag describes the estimated degree of completeness
      *  of an SR Document.  See DICOM standard for details.
-     *  @note Not applicable to Key Object Selection Documents.
+     *  Not applicable to Key Object Selection Documents.
      ** @return completion flag (might be CF_invalid if read from dataset)
      */
     virtual E_CompletionFlag getCompletionFlag() const;
 
     /** get document verification flag.
-     *  @note Not applicable to Key Object Selection Documents.
+     *  Not applicable to Key Object Selection Documents.
      ** @return verification flag (might be VF_invalid if read from dataset)
      */
     virtual E_VerificationFlag getVerificationFlag() const;
@@ -284,7 +249,7 @@ class DCMTK_DCMSR_EXPORT DSRDocument
      *  A document can be verified more than once.  The verification flag should be VERIFIED
      *  if any verifying observer is specified.  The details on the observer can be retrieved
      *  using the getVerifyingObserver() methods.
-     *  @note Not applicable to Key Object Selection Documents.
+     *  Not applicable to Key Object Selection Documents.
      ** @return number of verifying observers (if any), 0 otherwise
      */
     virtual size_t getNumberOfVerifyingObservers();
@@ -292,7 +257,7 @@ class DCMTK_DCMSR_EXPORT DSRDocument
     /** get information about a verifying observer.
      *  All reference variables are cleared before the information is retrieved, i.e. if an error
      *  occurs (return value != EC_Normal) non-empty variables do contain valid (empty) data.
-     *  @note Not applicable to Key Object Selection Documents.
+     *  Not applicable to Key Object Selection Documents.
      ** @param  idx           index of the verifying observer to be retrieved (starting with 1).
      *                        Use getNumberOfVerifyingObservers() to get the maximum value.
      *  @param  dateTime      reference to variable where the date and time when this document
@@ -311,7 +276,7 @@ class DCMTK_DCMSR_EXPORT DSRDocument
     /** get information about a verifying observer.
      *  All reference variables are cleared before the information is retrieved, i.e. if an error
      *  occurs (return value != EC_Normal) non-empty variables do contain valid (empty) data.
-     *  @note Not applicable to Key Object Selection Documents.
+     *  Not applicable to Key Object Selection Documents.
      ** @param  idx           index of the verifying observer to be retrieved (starting with 1).
      *                        Use getNumberOfVerifyingObservers() to get the maximum value.
      *  @param  dateTime      reference to variable where the date and time when this document
@@ -339,7 +304,7 @@ class DCMTK_DCMSR_EXPORT DSRDocument
      *  included in this document with or without modification." and "[...] the use of the
      *  Predecessor Document Sequence allows tracing back to the input SR Document, which in this
      *  case is the previous version."
-     *  @note Not applicable to Key Object Selection Documents.
+     *  Not applicable to Key Object Selection Documents.
      ** @return reference to list object
      */
     virtual DSRSOPInstanceReferenceList &getPredecessorDocuments();
@@ -380,7 +345,7 @@ class DCMTK_DCMSR_EXPORT DSRDocument
      *  reference all other evidence considered pertinent for this SR Document that is not listed
      *  in the Current Requested Procedure Evidence Sequence.  This requires that the same SOP
      *  Instance shall not be referenced in both of these Sequences."
-     *  @note Not applicable to Key Object Selection Documents.
+     *  Not applicable to Key Object Selection Documents.
      ** @return reference to list object
      */
     virtual DSRSOPInstanceReferenceList &getPertinentOtherEvidence();
@@ -391,15 +356,15 @@ class DCMTK_DCMSR_EXPORT DSRDocument
      *  to the current SOP Instance is known at the time of creation of this SOP instance. May be
      *  present otherwise."  Note: An equivalent rendering of the document might be provided as an
      *  "Encapsulated PDF" DICOM object.
-     *  @note Not applicable to Key Object Selection Documents.
-     ** @return reference to list object
+     *  Not applicable to Key Object Selection Documents.
+     *  @return reference to list object
      */
     virtual DSRReferencedInstanceList &getReferencedInstances();
 
     /** get list of coding schemes used (Coding Scheme Identification).
      *  The Coding Scheme Identification Sequence maps Coding Scheme Designators to an external coding
      *  system registration, or to a private or local coding scheme.  See DICOM standard for details.
-     ** @return reference to list object
+     *  @return reference to list object
      */
     virtual DSRCodingSchemeIdentificationList &getCodingSchemeIdentification();
 
@@ -415,7 +380,7 @@ class DCMTK_DCMSR_EXPORT DSRDocument
                                                 const signed long pos = 0) const;
 
     /** get completion flag description.
-     *  @note Not applicable to Key Object Selection Documents.
+     *  Not applicable to Key Object Selection Documents.
      ** @param  value  reference to variable in which the value should be stored
      *  @param  pos    index of the value to get (0..vm-1), -1 for all components
      ** @return status, EC_Normal if successful, an error code otherwise
@@ -519,14 +484,6 @@ class DCMTK_DCMSR_EXPORT DSRDocument
     virtual OFCondition getSeriesDescription(OFString &value,
                                              const signed long pos = 0) const;
 
-    /** get protocol name
-     ** @param  value  reference to variable in which the value should be stored
-     *  @param  pos    index of the value to get (0..vm-1), -1 for all components
-     ** @return status, EC_Normal if successful, an error code otherwise
-     */
-    virtual OFCondition getProtocolName(OFString &value,
-                                        const signed long pos = 0) const;
-
     /** get manufacturer
      ** @param  value  reference to variable in which the value should be stored
      *  @param  pos    index of the value to get (0..vm-1), -1 for all components
@@ -667,20 +624,17 @@ class DCMTK_DCMSR_EXPORT DSRDocument
   // --- set DICOM string attributes ---
 
     /** set specific character set.  The internal enumerated value is set accordingly.
-     *  Please note that this method does not return an error if the given 'value' is not
-     *  defined by the DICOM standard or not supported by this class, e.g. when no mapping
-     *  to the character set names needed for HTML/XHTML or XML output is defined.
-     *  If needed, check the return value of the method getSpecificCharacterSetType() for
-     *  DSRTypes::CS_unknown after calling this method.
-     ** @param  value  value to be set (single or multiple values) or "" for no value
-     *  @param  check  check 'value' for conformance with VR (CS) and VM (1-n) if enabled
+     *  Please note that code extensions techniques are not supported.  Therefore, only
+     *  a single value can be passed.
+     ** @param  value  value to be set (single value only) or "" for no value
+     *  @param  check  check 'value' for conformance with VR (CS) and VM (1) if enabled
      ** @return status, EC_Normal if successful, an error code otherwise
      */
     virtual OFCondition setSpecificCharacterSet(const OFString &value,
                                                 const OFBool check = OFTrue);
 
     /** set completion flag description.
-     *  @note Not applicable to Key Object Selection Documents.
+     *  Not applicable to Key Object Selection Documents.
      ** @param  value  explanation of the value that is set for completion flag.  If an empty
      *                 string is passed, the description is removed from the dataset (type 3).
      *  @param  check  check 'value' for conformance with VR (LO) and VM (1) if enabled
@@ -737,14 +691,6 @@ class DCMTK_DCMSR_EXPORT DSRDocument
     virtual OFCondition setSeriesDescription(const OFString &value,
                                              const OFBool check = OFTrue);
 
-    /** set protocol name
-     ** @param  value  value to be set (single value only) or "" for no value
-     *  @param  check  check 'value' for conformance with VR (LO) and VM (1) if enabled
-     ** @return status, EC_Normal if successful, an error code otherwise
-     */
-    virtual OFCondition setProtocolName(const OFString &value,
-                                        const OFBool check = OFTrue);
-
     /** set manufacturer
      ** @param  value  value to be set (single value only) or "" for no value
      *  @param  check  check 'value' for conformance with VR (LO) and VM (1) if enabled
@@ -914,9 +860,7 @@ class DCMTK_DCMSR_EXPORT DSRDocument
      *  be created (this is the case if the study instance UID or series instance UID has
      *  changed as well as any other attribute within the SR Document General Module or
      *  SR Document Content Module, see DICOM standard for details).
-     *  This method also updates other DICOM header attributes (by calling updateAttributes()).
-     *  However, instance-level attributes other than the SOP instance UID are usually not
-     *  changed (if already set), e.g. the current instance number or content date/time.
+     *  This method also updates the other DICOM header attributes (calling updateAttributes()).
      */
     virtual void createNewSOPInstance();
 
@@ -930,22 +874,11 @@ class DCMTK_DCMSR_EXPORT DSRDocument
     /** create a new document of the specified type.
      *  A new SOP instance is only created if the current document type was valid/supported.
      *  Please note that the current document is deleted by this method.
-     ** @param  documentType  type of the new SR document (see DSRTypes::E_DocumentType)
+     ** @param  documentType  type of the SR document (see DSRTypes::E_DocumentType)
      ** @return status, EC_Normal if successful, an error code otherwise
      */
     virtual OFCondition createNewDocument(const E_DocumentType documentType);
 
-    /** change the type of the current document.
-     *  Please note that only the type of the SR document is changed (if possible) but no new
-     *  SOP instance is created.  If needed, this has to be done with createNewSOPInstance()
-     *  in addition to this method or by calling createNewDocument() instead of this method.
-     *  Before changing the document type, it is checked whether the currently stored document
-     *  tree complies with the relationship content constraints of the new SR IOD.
-     ** @param  documentType  new type of the SR document (see DSRTypes::E_DocumentType)
-     ** @return status, EC_Normal if successful, an error code otherwise
-     */
-    virtual OFCondition changeDocumentType(const E_DocumentType documentType);
-
     /** create a revised version of the current document.
      *  A revised version can only be created if the current document is already completed
      *  (see completion flag).  If so, a reference to the current document is added to the
@@ -960,10 +893,9 @@ class DCMTK_DCMSR_EXPORT DSRDocument
      *  reset (OFFalse).  The preliminary flag is not modified by this method.  Also the
      *  various lists of referenced instances remain unchanged, i.e. they have to be
      *  adapted manually if needed.
-     *  @note Not applicable to Key Object Selection Documents.
-     *  @param  clearList  clear list of predecessor documents before adding the current
-     *                     document if OFTrue.  Append current document to existing list
-     *                     otherwise.
+     *  Not applicable to Key Object Selection Documents.
+     *  @param clearList clear list of predecessor documents before adding the current
+     *    document if OFTrue. Append current document to existing list otherwise.
      ** @return status, EC_Normal if successful, an error code otherwise
      */
     virtual OFCondition createRevisedVersion(const OFBool clearList = OFTrue);
@@ -973,7 +905,7 @@ class DCMTK_DCMSR_EXPORT DSRDocument
      *  describes the estimated degree of completeness of an SR Document (see DICOM standard
      *  for details).  The completion flag description is set to an empty string (i.e. absent
      *  in DICOM dataset).
-     *  @note Not applicable to Key Object Selection Documents.
+     *  Not applicable to Key Object Selection Documents.
      ** @return status, EC_Normal if successful, an error code otherwise
      */
     virtual OFCondition completeDocument();
@@ -983,7 +915,7 @@ class DCMTK_DCMSR_EXPORT DSRDocument
      *  describes the estimated degree of completeness of an SR Document (see DICOM standard
      *  for details).  The completion flag description can be modified independently from the
      *  flag by means of the method setCompletionFlagDescription() - see above.
-     *  @note Not applicable to Key Object Selection Documents.
+     *  Not applicable to Key Object Selection Documents.
      ** @param  description  explanation of the value set for completion flag.
      *                       (optional, see previous method, VR=LO)
      *  @param  check        check 'description' for conformance with VR and VM if enabled
@@ -999,7 +931,7 @@ class DCMTK_DCMSR_EXPORT DSRDocument
      *  Please note that only completed documents (see completion flag) can be verified and that
      *  a new SOP instance UID has to be generated (manually) according to the DICOM standard when
      *  creating a dataset/file from this document.
-     *  @note Not applicable to Key Object Selection Documents.
+     *  Not applicable to Key Object Selection Documents.
      ** @param  observerName  name of the person who has verified this document (required, VR=PN)
      *  @param  organization  name of the organization to which the observer belongs (required, VR=LO)
      *  @param  dateTime      verification date time (optional). If empty/absent the current date and
@@ -1020,7 +952,7 @@ class DCMTK_DCMSR_EXPORT DSRDocument
      *  Please note that only completed documents (see completion flag) can be verified and that
      *  a new SOP instance UID has to be generated (manually) according to the DICOM standard when
      *  creating a dataset/file from this document.
-     *  @note Not applicable to Key Object Selection Documents.
+     *  Not applicable to Key Object Selection Documents.
      ** @param  observerName  name of the person who has verified this document (required, VR=PN)
      *  @param  observerCode  code identifying the verifying observer (optional, see previous method)
      *  @param  organization  name of the organization to which the observer belongs (required, VR=LO)
@@ -1053,9 +985,9 @@ class DCMTK_DCMSR_EXPORT DSRDocument
      *      document management functions do reset the flag (i.e. set the FinalizedFlag to OFFalse),
      *      other methods (e.g. setXXX) do not change the flag though the state of the document is
      *      not finalized any more after they have been called.
-     *  @note Not applicable to Key Object Selection Documents since there's no completion flag in
-     *        this type of SR document.  Please note that this method has nothing to do with the
-     *        preliminary flag.
+     *  Not applicable to Key Object Selection Documents since there's no completion flag in this
+     *  type of SR document.  Please note that this method has nothing to do with the preliminary
+     *  flag.
      ** @return status, EC_Normal if successful, an error code otherwise
      */
     virtual OFCondition finalizeDocument();
@@ -1066,7 +998,7 @@ class DCMTK_DCMSR_EXPORT DSRDocument
     /** read XML document header
      ** @param  doc     document containing the XML file content
      *  @param  cursor  cursor pointing to the starting node
-     *  @param  flags   flag used to customize the reading process (see DSRTypes::XF_xxx)
+     *  @param  flags   optional flag used to customize the reading process (see DSRTypes::XF_xxx)
      ** @return status, EC_Normal if successful, an error code otherwise
      */
     OFCondition readXMLDocumentHeader(DSRXMLDocument &doc,
@@ -1076,7 +1008,7 @@ class DCMTK_DCMSR_EXPORT DSRDocument
     /** read XML "patient" data
      ** @param  doc     document containing the XML file content
      *  @param  cursor  cursor pointing to the starting node
-     *  @param  flags   flag used to customize the reading process (see DSRTypes::XF_xxx)
+     *  @param  flags   optional flag used to customize the reading process (see DSRTypes::XF_xxx)
      ** @return status, EC_Normal if successful, an error code otherwise
      */
     OFCondition readXMLPatientData(const DSRXMLDocument &doc,
@@ -1086,7 +1018,7 @@ class DCMTK_DCMSR_EXPORT DSRDocument
     /** read XML "study" data
      ** @param  doc     document containing the XML file content
      *  @param  cursor  cursor pointing to the starting node
-     *  @param  flags   flag used to customize the reading process (see DSRTypes::XF_xxx)
+     *  @param  flags   optional flag used to customize the reading process (see DSRTypes::XF_xxx)
      ** @return status, EC_Normal if successful, an error code otherwise
      */
     OFCondition readXMLStudyData(const DSRXMLDocument &doc,
@@ -1096,7 +1028,7 @@ class DCMTK_DCMSR_EXPORT DSRDocument
     /** read XML "series" data
      ** @param  doc     document containing the XML file content
      *  @param  cursor  cursor pointing to the starting node
-     *  @param  flags   flag used to customize the reading process (see DSRTypes::XF_xxx)
+     *  @param  flags   optional flag used to customize the reading process (see DSRTypes::XF_xxx)
      ** @return status, EC_Normal if successful, an error code otherwise
      */
     OFCondition readXMLSeriesData(const DSRXMLDocument &doc,
@@ -1106,7 +1038,7 @@ class DCMTK_DCMSR_EXPORT DSRDocument
     /** read XML "instance" data
      ** @param  doc     document containing the XML file content
      *  @param  cursor  cursor pointing to the starting node
-     *  @param  flags   flag used to customize the reading process (see DSRTypes::XF_xxx)
+     *  @param  flags   optional flag used to customize the reading process (see DSRTypes::XF_xxx)
      ** @return status, EC_Normal if successful, an error code otherwise
      */
     OFCondition readXMLInstanceData(const DSRXMLDocument &doc,
@@ -1116,7 +1048,7 @@ class DCMTK_DCMSR_EXPORT DSRDocument
     /** read XML "document" data
      ** @param  doc     document containing the XML file content
      *  @param  cursor  cursor pointing to the starting node
-     *  @param  flags   flag used to customize the reading process (see DSRTypes::XF_xxx)
+     *  @param  flags   optional flag used to customize the reading process (see DSRTypes::XF_xxx)
      ** @return status, EC_Normal if successful, an error code otherwise
      */
     OFCondition readXMLDocumentData(const DSRXMLDocument &doc,
@@ -1126,7 +1058,7 @@ class DCMTK_DCMSR_EXPORT DSRDocument
     /** read XML verifying observer data
      ** @param  doc     document containing the XML file content
      *  @param  cursor  cursor pointing to the starting node
-     *  @param  flags   flag used to customize the reading process (see DSRTypes::XF_xxx)
+     *  @param  flags   optional flag used to customize the reading process (see DSRTypes::XF_xxx)
      ** @return status, EC_Normal if successful, an error code otherwise
      */
     OFCondition readXMLVerifyingObserverData(const DSRXMLDocument &doc,
@@ -1169,11 +1101,10 @@ class DCMTK_DCMSR_EXPORT DSRDocument
     OFCondition checkDatasetForReading(DcmItem &dataset,
                                        E_DocumentType &documentType);
 
-    /** update various DICOM attributes.
-     *  (e.g. set the modality and SOP class UID, generate a new Study, Series and SOP instance UID
-     *  if required, set date/time values, etc.)
-     ** @param  updateAll  flag indicating whether all DICOM attributes should be updated or only
-     *                     the IOD-specific ones. (e.g. set DICOM defined terms from enum values)
+    /** update several DICOM attributes.
+     *  (e.g. set the modality attribute, generate a new SOP instance UID if required, set date/time, etc.)
+     ** @param  updateAll  flag indicating whether all DICOM attributes should be updated or only the
+     *                     completion and verification flag. (set DICOM defined terms from enum values)
      */
     void updateAttributes(const OFBool updateAll = OFTrue);
 
@@ -1194,7 +1125,7 @@ class DCMTK_DCMSR_EXPORT DSRDocument
     /// defined term: see class DSRTypes
     E_CharacterSet     SpecificCharacterSetEnum;
 
-    // DICOM attributes are listed ordered by Module.
+    // DICOM attributes are listed ordered by module.
     // The comments for each attribute describe "Name: (VR, VM, Type)".
     // Please note that for particular SR documents (e.g. Key Object Selection)
     // other rules might apply.  See DICOM standard for further reference.
@@ -1214,7 +1145,7 @@ class DCMTK_DCMSR_EXPORT DSRDocument
     DcmTime             InstanceCreationTime;
     /// Instance Creator UID: (UI, 1, 3)
     DcmUniqueIdentifier InstanceCreatorUID;
-    /// Coding Scheme Identification Sequence: (SQ, 1-n, 3)
+    /// Coding Scheme Identification Sequence: (SQ, 1, 3)
     DSRCodingSchemeIdentificationList CodingSchemeIdentification;
 
     // --- General Study Module (M) ---
@@ -1267,11 +1198,11 @@ class DCMTK_DCMSR_EXPORT DSRDocument
     // Software Version(s): (LO, 1-n, 1)
     // - see 'General Equipment Module'
 
-    // --- Synchronization Module (C/U - for some IODs) ---
+    // --- Frame of Reference (C) ---
 
-    // tbd: conditional/optional module not yet supported
+    // tbd: conditional module for X-Ray Radiation Dose SR not yet supported
 
-    // --- SR Document Series / Key Object Document Series Module (M) ---
+    // --- SR Document Series Module (M) ---
 
     /// Modality: (CS, 1, 1)
     DcmCodeString       Modality;
@@ -1283,12 +1214,8 @@ class DCMTK_DCMSR_EXPORT DSRDocument
     DcmDate             SeriesDate;
     /// Series Time: (TM, 1, 3)
     DcmTime             SeriesTime;
-    /// Protocol Name: (LO, 1, 3)
-    DcmLongString       ProtocolName;
     /// Series Description: (LO, 1, 3)
     DcmLongString       SeriesDescription;
-    /// Series Description Code Sequence: (SQ, 1, 3)
-     // - tbd: optional attribute not yet supported
     /// Referenced Performed Procedure Step Sequence: (SQ, 1, 2)
     DcmSequenceOfItems  ReferencedPerformedProcedureStep;
 
@@ -1308,27 +1235,21 @@ class DCMTK_DCMSR_EXPORT DSRDocument
     DcmDate             ContentDate;
     /// Content Time: (TM, 1, 1)
     DcmTime             ContentTime;
-    /// Verifying Observer Sequence: (SQ, 1-n, 1C)
+    /// Verifying Observer Sequence: (SQ, 1, 1C)
     DcmSequenceOfItems  VerifyingObserver;
-    /// Author Observer Sequence: (SQ, 1-n, 3)
-     // - tbd: optional attribute not yet supported
-    /// Participant Sequence: (SQ, 1-n, 3)
-     // - tbd: optional attribute not yet supported
-    /// Custodial Organization Sequence: (SQ, 1, 3)
-     // - tbd: optional attribute not yet supported
-    /// Predecessor Documents Sequence: (SQ, 1-n, 1C)
+    /// Predecessor Documents Sequence: (SQ, 1, 1C)
     DSRSOPInstanceReferenceList PredecessorDocuments;
-    /// Identical Documents Sequence: (SQ, 1-n, 1C)
+    /// Identical Documents Sequence: (SQ, 1, 1C)
     DSRSOPInstanceReferenceList IdenticalDocuments;
-    // Referenced Request Sequence: (SQ, 1-n, 1C)
-     // - tbd: conditional attribute not yet supported
-    /// Performed Procedure Code Sequence: (SQ, 1-n, 2)
+    // Referenced Request Sequence: (SQ, 1, 1C)
+    // - tbd: conditional attribute not yet supported
+    /// Performed Procedure Code Sequence: (SQ, 1, 2)
     DcmSequenceOfItems  PerformedProcedureCode;
-    /// Current Requested Procedure Evidence Sequence: (SQ, 1-n, 1C)
+    /// Current Requested Procedure Evidence Sequence: (SQ, 1, 1C)
     DSRSOPInstanceReferenceList CurrentRequestedProcedureEvidence;
-    /// Pertinent Other Evidence Sequence: (SQ, 1-n, 1C)
+    /// Pertinent Other Evidence Sequence: (SQ, 1, 1C)
     DSRSOPInstanceReferenceList PertinentOtherEvidence;
-    /// Referenced Instance Sequence: (SQ, 1-n, 1C)
+    /// Referenced Instance Sequence: (SQ, 1, 1C)
     DSRReferencedInstanceList ReferencedInstances;
 
  // --- declaration of copy constructor and assignment operator ---
