@@ -1,6 +1,6 @@
 /*
  *
- *  Copyright (C) 2000-2015, OFFIS e.V.
+ *  Copyright (C) 2000-2012, OFFIS e.V.
  *  All rights reserved.  See COPYRIGHT file for details.
  *
  *  This software and supporting documentation were developed by
@@ -44,14 +44,14 @@ class DCMTK_DCMSR_EXPORT DSRDateTimeTreeNode
   public:
 
     /** constructor
-     ** @param  relationshipType  type of relationship to the parent tree node.  Should
-     *                            not be DSRTypes::RT_invalid or DSRTypes::RT_isRoot.
+     ** @param  relationshipType  type of relationship to the parent tree node.
+     *                            Should not be RT_invalid or RT_isRoot.
      */
     DSRDateTimeTreeNode(const E_RelationshipType relationshipType);
 
     /** constructor
      ** @param  relationshipType  type of relationship to the parent tree node.
-     *                            Should not be DSRTypes::RT_invalid or DSRTypes::RT_isRoot.
+     *                            Should not be RT_invalid or RT_isRoot.
      *  @param  dateTimeValue     initial value to be set (VR=DT, mandatory)
      *  @param  check             if enabled, check 'dateTimeValue' for validity before setting
      *                            it.  See checkValue() for details.  An empty value is never
@@ -61,40 +61,22 @@ class DCMTK_DCMSR_EXPORT DSRDateTimeTreeNode
                         const OFString &dateTimeValue,
                         const OFBool check = OFTrue);
 
-    /** copy constructor.
-     *  Please note that the comments on the copy constructor of the base class
-     *  DSRDocumentTreeNode apply.
-     ** @param  node  tree node to be copied
-     */
-    DSRDateTimeTreeNode(const DSRDateTimeTreeNode &node);
-
     /** destructor
      */
     virtual ~DSRDateTimeTreeNode();
 
-    /** clone this tree node.
-     *  Internally, the copy constructor is used, so the corresponding comments apply.
-     ** @return copy of this tree node
-     */
-    virtual DSRDateTimeTreeNode *clone() const;
-
     /** clear all member variables.
      *  Please note that the content item might become invalid afterwards.
      */
     virtual void clear();
 
     /** check whether the content item is valid.
-     *  The content item is valid if the base classes, the concept name and the currently stored
-     *  value (see hasValidValue()) are valid.
+     *  The content item is valid if the base classes, the concept name and the currently
+     *  stored date/time value are valid.
      ** @return OFTrue if tree node is valid, OFFalse otherwise
      */
     virtual OFBool isValid() const;
 
-    /** check whether the value of the content item, i.e.\ the stored date/time value, is valid
-     ** @return OFTrue if the value is valid, OFFalse otherwise
-     */
-    virtual OFBool hasValidValue() const;
-
     /** print content item.
      *  A typical output looks like this: contains DATETIME:(,,"Code")="2000101012000000"
      ** @param  stream  output stream to which the content item should be printed
@@ -133,11 +115,9 @@ class DCMTK_DCMSR_EXPORT DSRDateTimeTreeNode
 
     /** read content item (value) from dataset
      ** @param  dataset  DICOM dataset from which the content item should be read
-     *  @param  flags    flag used to customize the reading process (see DSRTypes::RF_xxx)
      ** @return status, EC_Normal if successful, an error code otherwise
      */
-    virtual OFCondition readContentItem(DcmItem &dataset,
-                                        const size_t flags);
+    virtual OFCondition readContentItem(DcmItem &dataset);
 
     /** write content item (value) to dataset
      ** @param  dataset  DICOM dataset to which the content item should be written
@@ -148,12 +128,10 @@ class DCMTK_DCMSR_EXPORT DSRDateTimeTreeNode
     /** read content item specific XML data
      ** @param  doc     document containing the XML file content
      *  @param  cursor  cursor pointing to the starting node
-     *  @param  flags   flag used to customize the reading process (see DSRTypes::XF_xxx)
      ** @return status, EC_Normal if successful, an error code otherwise
      */
     virtual OFCondition readXMLContentItem(const DSRXMLDocument &doc,
-                                           DSRXMLCursor cursor,
-                                           const size_t flags);
+                                           DSRXMLCursor cursor);
 
     /** render content item (value) in HTML/XHTML format
      ** @param  docStream     output stream to which the main HTML/XHTML document is written
@@ -181,9 +159,10 @@ class DCMTK_DCMSR_EXPORT DSRDateTimeTreeNode
 
   private:
 
- // --- declaration of default constructor and assignment operator
+ // --- declaration of default/copy constructor and assignment operator
 
     DSRDateTimeTreeNode();
+    DSRDateTimeTreeNode(const DSRDateTimeTreeNode &);
     DSRDateTimeTreeNode &operator=(const DSRDateTimeTreeNode &);
 };
 
