@@ -1,6 +1,6 @@
 /*
  *
- *  Copyright (C) 2000-2015, OFFIS e.V.
+ *  Copyright (C) 2000-2013, OFFIS e.V.
  *  All rights reserved.  See COPYRIGHT file for details.
  *
  *  This software and supporting documentation were developed by
@@ -44,45 +44,27 @@ class DCMTK_DCMSR_EXPORT DSRImageTreeNode
   public:
 
     /** constructor
-     ** @param  relationshipType  type of relationship to the parent tree node.  Should
-     *                            not be DSRTypes::RT_invalid or DSRTypes::RT_isRoot.
+     ** @param  relationshipType  type of relationship to the parent tree node.
+     *                            Should not be RT_invalid or RT_isRoot.
      */
     DSRImageTreeNode(const E_RelationshipType relationshipType);
 
-    /** copy constructor.
-     *  Please note that the comments on the copy constructor of the base class
-     *  DSRDocumentTreeNode apply.
-     ** @param node tree node to be copied
-     */
-    DSRImageTreeNode(const DSRImageTreeNode &node);
-
     /** destructor
      */
     virtual ~DSRImageTreeNode();
 
-    /** clone this tree node.
-     *  Internally, the copy constructor is used, so the corresponding comments apply.
-     ** @return copy of this tree node
-     */
-    virtual DSRImageTreeNode *clone() const;
-
     /** clear all member variables.
      *  Please note that the content item might become invalid afterwards.
      */
     virtual void clear();
 
     /** check whether the content item is valid.
-     *  The content item is valid if the two base classes are valid.  This check includes the value
-     *  of the content item, which can also be checked separately with hasValidValue().
+     *  The content item is valid if the two base classes are valid.  See
+     *  DSRDocumentTreeNode::isValid() and DSRImageReferenceValue::isValid().
      ** @return OFTrue if tree node is valid, OFFalse otherwise
      */
     virtual OFBool isValid() const;
 
-    /** check whether the value of the content item, i.e.\ the image reference value, is valid
-     ** @return OFTrue if the value is valid, OFFalse otherwise
-     */
-    virtual OFBool hasValidValue() const;
-
     /** check whether the content is short.
      *  The method isShort() from the base class DSRImageReferenceValue is called.
      ** @param  flags  flag used to customize the output (see DSRTypes::HF_xxx)
@@ -116,11 +98,9 @@ class DCMTK_DCMSR_EXPORT DSRImageTreeNode
 
     /** read content item (value) from dataset
      ** @param  dataset  DICOM dataset from which the content item should be read
-     *  @param  flags    flag used to customize the reading process (see DSRTypes::RF_xxx)
      ** @return status, EC_Normal if successful, an error code otherwise
      */
-    virtual OFCondition readContentItem(DcmItem &dataset,
-                                        const size_t flags);
+    virtual OFCondition readContentItem(DcmItem &dataset);
 
     /** write content item (value) to dataset
      ** @param  dataset  DICOM dataset to which the content item should be written
@@ -131,12 +111,10 @@ class DCMTK_DCMSR_EXPORT DSRImageTreeNode
     /** read content item specific XML data
      ** @param  doc     document containing the XML file content
      *  @param  cursor  cursor pointing to the starting node
-     *  @param  flags   flag used to customize the reading process (see DSRTypes::XF_xxx)
      ** @return status, EC_Normal if successful, an error code otherwise
      */
     virtual OFCondition readXMLContentItem(const DSRXMLDocument &doc,
-                                           DSRXMLCursor cursor,
-                                           const size_t flags);
+                                           DSRXMLCursor cursor);
 
     /** render content item (value) in HTML/XHTML format
      ** @param  docStream     output stream to which the main HTML/XHTML document is written
@@ -156,9 +134,10 @@ class DCMTK_DCMSR_EXPORT DSRImageTreeNode
 
   private:
 
- // --- declaration of default constructor and assignment operator
+ // --- declaration of default/copy constructor and assignment operator
 
     DSRImageTreeNode();
+    DSRImageTreeNode(const DSRImageTreeNode &);
     DSRImageTreeNode &operator=(const DSRImageTreeNode &);
 };
 
