@@ -1,6 +1,6 @@
 /*
  *
- *  Copyright (C) 2000-2015, OFFIS e.V.
+ *  Copyright (C) 2000-2013, OFFIS e.V.
  *  All rights reserved.  See COPYRIGHT file for details.
  *
  *  This software and supporting documentation were developed by
@@ -151,12 +151,10 @@ class DCMTK_DCMSR_EXPORT DSRImageReferenceValue
     /** read image reference from XML document
      ** @param  doc     document containing the XML file content
      *  @param  cursor  cursor pointing to the starting node
-     *  @param  flags   flag used to customize the reading process (see DSRTypes::XF_xxx)
      ** @return status, EC_Normal if successful, an error code otherwise
      */
     virtual OFCondition readXML(const DSRXMLDocument &doc,
-                                DSRXMLCursor cursor,
-                                const size_t flags);
+                                DSRXMLCursor cursor);
 
     /** write image reference in XML format
      ** @param  stream  output stream to which the XML document is written
@@ -385,11 +383,9 @@ class DCMTK_DCMSR_EXPORT DSRImageReferenceValue
 
     /** read image reference value from dataset
      ** @param  dataset  DICOM dataset from which the value should be read
-     *  @param  flags    flag used to customize the reading process (see DSRTypes::RF_xxx)
      ** @return status, EC_Normal if successful, an error code otherwise
      */
-    virtual OFCondition readItem(DcmItem &dataset,
-                                 const size_t flags);
+    virtual OFCondition readItem(DcmItem &dataset);
 
     /** write image reference value to dataset
      ** @param  dataset  DICOM dataset to which the value should be written
@@ -398,9 +394,9 @@ class DCMTK_DCMSR_EXPORT DSRImageReferenceValue
     virtual OFCondition writeItem(DcmItem &dataset) const;
 
     /** check the specified SOP class UID for validity.
-     *  This method further specializes the checks performed in the base class
-     *  DSRCompositeReferenceValue.  All image SOP classes that are defined in
-     *  DICOM PS 3.6-2014a and the "Segmentation Storage SOP Class" are allowed.
+     *  Currently, this method does not further specialize the checks performed in the base
+     *  class DSRCompositeReferenceValue.  Later on, this method might be extended to also
+     *  check whether the specified SOP class is really an image storage SOP class.
      ** @param  sopClassUID  SOP class UID to be checked
      ** @return status, EC_Normal if value is valid, an error code otherwise
      */
