@@ -1,6 +1,6 @@
 /*
  *
- *  Copyright (C) 2000-2015, OFFIS e.V.
+ *  Copyright (C) 2000-2012, OFFIS e.V.
  *  All rights reserved.  See COPYRIGHT file for details.
  *
  *  This software and supporting documentation were developed by
@@ -52,8 +52,8 @@ class DCMTK_DCMSR_EXPORT DSRNumericMeasurementValue
      ** @param  numericValue     numeric measurement value (VR=DS, mandatory)
      *  @param  measurementUnit  code representing the units of measurement (mandatory)
      *  @param  check            if enabled, check 'numericValue' and 'measurementUnit' for
-     *                           validity before setting them.  See corresponding setValue()
-     *                           method for details.
+     *                           validity before setting them.  See checkXXX() methods for
+     *                           details.  Empty values are never accepted.
      */
     DSRNumericMeasurementValue(const OFString &numericValue,
                                const DSRCodedEntryValue &measurementUnit,
@@ -64,10 +64,10 @@ class DCMTK_DCMSR_EXPORT DSRNumericMeasurementValue
      *  @param  measurementUnit  code representing the units of measurement (mandatory)
      *  @param  valueQualifier   code representing the numeric value qualifier (optional).
      *                           Can also be used to specify the reason for the absence of
-     *                           the measured value sequence (where 'numericValue' and
-     *                           'measurementUnit' are stored).
+     *                           the measured value sequence.
      *  @param  check            if enabled, check values for validity before setting them.
-     *                           See corresponding setValue() method for details.
+     *                           See checkXXX() for details.  Empty values are only accepted
+     *                           for non-mandatory attributes.
      */
     DSRNumericMeasurementValue(const OFString &numericValue,
                                const DSRCodedEntryValue &measurementUnit,
@@ -95,10 +95,9 @@ class DCMTK_DCMSR_EXPORT DSRNumericMeasurementValue
     virtual void clear();
 
     /** check whether the current numeric measurement value is valid.
-     *  The value is valid if isEmpty() is true or both the numeric value and the measurement
-     *  unit contain a valid value, and the value qualifier is valid (see checkXXX() methods).
-     *  The possibly available additional representations of the numeric value are never
-     *  checked.
+     *  The value is valid if isEmpty() is true or all three values (numeric value, measurement
+     *  unit and value qualifier) do contain valid values (see checkXXX() methods).  The
+     *  possibly available additional representations of the numeric value are never checked.
      ** @return OFTrue if value is valid, OFFalse otherwise
      */
     virtual OFBool isValid() const;
@@ -126,12 +125,10 @@ class DCMTK_DCMSR_EXPORT DSRNumericMeasurementValue
     /** read numeric measurement value from XML document
      ** @param  doc     document containing the XML file content
      *  @param  cursor  cursor pointing to the starting node
-     *  @param  flags   flag used to customize the reading process (see DSRTypes::XF_xxx)
      ** @return status, EC_Normal if successful, an error code otherwise
      */
     virtual OFCondition readXML(const DSRXMLDocument &doc,
-                                DSRXMLCursor cursor,
-                                const size_t flags);
+                                DSRXMLCursor cursor);
 
     /** write numeric measurement value in XML format
      ** @param  stream  output stream to which the XML document is written
@@ -146,11 +143,9 @@ class DCMTK_DCMSR_EXPORT DSRNumericMeasurementValue
      *  enabled, a warning message is printed if a sequence is absent or contains more than
      *  one item.
      ** @param  dataset  DICOM dataset from which the sequences should be read
-     *  @param  flags    flag used to customize the reading process (see DSRTypes::RF_xxx)
      ** @return status, EC_Normal if successful, an error code otherwise
      */
-    virtual OFCondition readSequence(DcmItem &dataset,
-                                     const size_t flags);
+    virtual OFCondition readSequence(DcmItem &dataset);
 
     /** write measured value sequence and numeric value qualifier code sequence to dataset.
      *  The measured value sequence is always written (might be empty, though).  The numeric
@@ -256,11 +251,10 @@ class DCMTK_DCMSR_EXPORT DSRNumericMeasurementValue
                          const OFBool check = OFTrue);
 
     /** set numeric value and measurement unit.
-     *  Before setting the values, they are usually checked.  Please note that both values
-     *  (i.e. 'numericValue' and 'measurementUnit') either have to be empty or non-empty.
-     *  If the value pair is invalid, the current value pair is not replaced and remains
-     *  unchanged.  If the value pair is replaced, the optional floating point and rational
-     *  representations are cleared, i.e. they have to be set manually if needed.
+     *  Before setting the values, they are usually checked.  If the value pair is invalid,
+     *  the current value pair is not replaced and remains unchanged.  If the value pair is
+     *  replaced, the optional floating point and rational representations are cleared, i.e.
+     *  they have to be set manually if needed.
      ** @param  numericValue     numeric value to be set (VR=DS, mandatory)
      *  @param  measurementUnit  measurement unit to be set (mandatory)
      *  @param  check            if enabled, check values for validity before setting them.
@@ -272,20 +266,19 @@ class DCMTK_DCMSR_EXPORT DSRNumericMeasurementValue
                          const OFBool check = OFTrue);
 
     /** set numeric value, measurement unit and numeric value qualifier.
-     *  Before setting the values, they are usually checked.  Please note that both
-     *  'numericValue' and 'measurementUnit' either have to be empty or non-empty.
-     *  If one of the three values is invalid, the current numeric measurement value is not
-     *  replaced and remains unchanged.  If the values are replaced, the optional floating
-     *  point and rational representations are cleared, i.e. they have to be set manually if
-     *  needed.
+     *  Before setting the values, they are usually checked.  If one of the three values is
+     *  invalid, the current numeric measurement value is not replaced and remains unchanged.
+     *  If the values are replaced, the optional floating point and rational representations
+     *  are cleared, i.e. they have to be set manually if needed.
      ** @param  numericValue     numeric value to be set (VR=DS, mandatory)
      *  @param  measurementUnit  measurement unit to be set (mandatory)
      *  @param  valueQualifier   numeric value qualifier to be set (optional).  Can also be
      *                           used to specify the reason for the absence of the measured
-     *                           value sequence (where 'numericValue' and 'measurementUnit'
-     *                           are stored).  Use an empty code to remove the current value.
+     *                           value sequence.  Use an empty code to remove the current
+     *                           value.
      *  @param  check            if enabled, check values for validity before setting them.
-     *                           See checkXXX() methods for details.
+     *                           See checkXXX() methods for details.  Empty values are only
+     *                           accepted for non-mandatory attributes.
      ** @return status, EC_Normal if successful, an error code otherwise
      */
     OFCondition setValue(const OFString &numericValue,
@@ -301,54 +294,19 @@ class DCMTK_DCMSR_EXPORT DSRNumericMeasurementValue
      ** @param  numericValue  numeric value to be set (VR=DS, mandatory)
      *  @param  check         if enabled, check value for validity before setting it.
      *                        See checkNumericValue() method for details.  An empty value is
-     *                        never accepted, use the clear() method instead.
+     *                        never accepted.
      ** @return status, EC_Normal if successful, an error code otherwise
      */
     OFCondition setNumericValue(const OFString &numericValue,
                                 const OFBool check = OFTrue);
 
-    /** set numeric value from element.
-     *  Before setting the value, it is usually checked.  If the value is invalid, the current
-     *  value is not replaced and remains unchanged.  If the value is replaced, the optional
-     *  floating point and rational representations are cleared, i.e. they have to be set
-     *  manually if needed.
-     ** @param  delem  DICOM element from which the numeric value should be retrieved
-     *  @param  pos    index of the value in case of multi-valued elements (0..vm-1)
-     *  @param  check  if enabled, check numeric value for validity before setting it.  See
-     *                 checkNumericValue() method for details.  An empty value is never
-     *                 accepted.
-     ** @return status, EC_Normal if successful, an error code otherwise
-     */
-    OFCondition setNumericValue(const DcmElement &delem,
-                                const unsigned long pos = 0,
-                                const OFBool check = OFTrue);
-
-    /** set numeric value from dataset.
-     *  Before setting the value, it is usually checked.  If the value is invalid, the current
-     *  value is not replaced and remains unchanged.  If the value is replaced, the optional
-     *  floating point and rational representations are cleared, i.e. they have to be set
-     *  manually if needed.
-     ** @param  dataset  DICOM dataset from which the numeric value should be retrieved
-     *  @param  tagKey   DICOM tag specifying the attribute from which the value should be
-     *                   retrieved.  The search is limited to the top-level of the dataset.
-     *  @param  pos      index of the value in case of multi-valued elements (0..vm-1)
-     *  @param  check    if enabled, check numeric value for validity before setting it.
-     *                   See checkNumericValue() method for details.  An empty value is
-     *                   never accepted.
-     ** @return status, EC_Normal if successful, an error code otherwise
-     */
-    OFCondition setNumericValue(DcmItem &dataset,
-                                const DcmTagKey &tagKey,
-                                const unsigned long pos = 0,
-                                const OFBool check = OFTrue);
-
     /** set measurement unit.
      *  Before setting the code, it is usually checked.  If the code is invalid the current
      *  code is not replaced and remains unchanged.
      ** @param  measurementUnit  measurement unit to be set (mandatory)
      *  @param  check            if enabled, check value for validity before setting it.
      *                           See checkMeasurementUnit() method for details.  An empty
-     *                           value is never accepted, use the clear() method instead.
+     *                           value is never accepted.
      ** @return status, EC_Normal if successful, an error code otherwise
      */
     OFCondition setMeasurementUnit(const DSRCodedEntryValue &measurementUnit,
@@ -420,15 +378,13 @@ class DCMTK_DCMSR_EXPORT DSRNumericMeasurementValue
     }
 
     /** read numeric measurement value from dataset
-     ** @param  dataset  DICOM dataset from which the value should be read
-     *  @param  flags    flag used to customize the reading process (see DSRTypes::RF_xxx)
+     ** @param  dataset    DICOM dataset from which the value should be read
      ** @return status, EC_Normal if successful, an error code otherwise
      */
-    virtual OFCondition readItem(DcmItem &dataset,
-                                 const size_t flags);
+    virtual OFCondition readItem(DcmItem &dataset);
 
     /** write numeric measurement value to dataset
-     ** @param  dataset  DICOM dataset to which the value should be written
+     ** @param  dataset    DICOM dataset to which the value should be written
      ** @return status, EC_Normal if successful, an error code otherwise
      */
     virtual OFCondition writeItem(DcmItem &dataset) const;
@@ -439,7 +395,7 @@ class DCMTK_DCMSR_EXPORT DSRNumericMeasurementValue
      ** @param  numericValue  numeric value to be checked
      ** @return status, EC_Normal if numeric value is valid, an error code otherwise
      */
-    virtual OFCondition checkNumericValue(const OFString &numericValue) const;
+    OFCondition checkNumericValue(const OFString &numericValue) const;
 
     /** check the specified measurement unit for validity.
      *  Internally, the methods DSRCodedEntryValue::isEmpty() and
@@ -448,17 +404,16 @@ class DCMTK_DCMSR_EXPORT DSRNumericMeasurementValue
      ** @param  measurementUnit  measurement unit to be checked
      ** @return status, EC_Normal if measurement unit is valid, an error code otherwise
      */
-    virtual OFCondition checkMeasurementUnit(const DSRCodedEntryValue &measurementUnit) const;
+    OFCondition checkMeasurementUnit(const DSRCodedEntryValue &measurementUnit) const;
 
     /** check the specified numeric value qualifier for validity.
-     *  Internally, DSRCodedEntryValue::isEmpty() and DSRCodedEntryValue::checkCurrentValue()
-     *  are used for this purpose.  Conformance with the Context Group 42 (as defined in the
-     *  DICOM standard) is not checked; see class CMR_SRNumericMeasurementValue if needed,
-     *  which supports such additional checks.
+     *  Internally, the methods DSRCodedEntryValue::isEmpty() and
+     *  DSRCodedEntryValue::checkCurrentValue() are used for this purpose.  Conformance
+     *  with the Context Group 42 (as defined in the DICOM standard) is not yet checked.
      ** @param  valueQualifier  numeric value qualifier to be checked
      ** @return status, EC_Normal if value qualifier is valid, an error code otherwise
      */
-    virtual OFCondition checkNumericValueQualifier(const DSRCodedEntryValue &valueQualifier) const;
+    OFCondition checkNumericValueQualifier(const DSRCodedEntryValue &valueQualifier) const;
 
     /** check the specified rational representation for validity.
      *  The only check that is performed is that the 'rationalDenominator' is not zero, i.e.
@@ -468,21 +423,21 @@ class DCMTK_DCMSR_EXPORT DSRNumericMeasurementValue
      *  @param  rationalDenominator  denominator of a rational representation to be checked
      ** @return status, EC_Normal if rational representation is valid, an error code otherwise
      */
-    virtual OFCondition checkRationalRepresentation(const Sint32 rationalNumerator,
-                                                    const Uint32 rationalDenominator) const;
+    OFCondition checkRationalRepresentation(const Sint32 rationalNumerator,
+                                            const Uint32 rationalDenominator) const;
 
     /** check the currently stored numeric measurement value for validity.
      *  See above checkXXX() methods for details.
      ** @return status, EC_Normal if current value is valid, an error code otherwise
      */
-    virtual OFCondition checkCurrentValue() const;
+    OFCondition checkCurrentValue() const;
 
 
   private:
 
-    /// Numeric Value (VR=DS, type 1 within a type 2 sequence)
+    /// Numeric Value (VR=DS, type 1)
     OFString               NumericValue;
-    /// Measurement Unit (type 1 within a type 2 sequence)
+    /// Measurement Unit (type 2)
     DSRCodedEntryValue     MeasurementUnit;
     /// Numeric Value Qualifier (type 3)
     DSRCodedEntryValue     ValueQualifier;
