@@ -1,6 +1,6 @@
 /*
  *
- *  Copyright (C) 2000-2010, OFFIS e.V.
+ *  Copyright (C) 2000-2012, OFFIS e.V.
  *  All rights reserved.  See COPYRIGHT file for details.
  *
  *  This software and supporting documentation were developed by
@@ -18,13 +18,6 @@
  *  Purpose:
  *    classes: DSRSCoordTreeNode
  *
- *  Last Update:      $Author: joergr $
- *  Update Date:      $Date: 2010-10-14 13:16:33 $
- *  CVS/RCS Revision: $Revision: 1.14 $
- *  Status:           $State: Exp $
- *
- *  CVS/RCS Log at end of file
- *
  */
 
 
@@ -43,7 +36,7 @@
 
 /** Class for content item SCOORD
  */
-class DSRSCoordTreeNode
+class DCMTK_DCMSR_EXPORT DSRSCoordTreeNode
   : public DSRDocumentTreeNode,
     public DSRSpatialCoordinatesValue
 {
@@ -89,8 +82,8 @@ class DSRSCoordTreeNode
                               const size_t flags) const;
 
     /** write content item in XML format
-     ** @param  stream     output stream to which the XML document is written
-     *  @param  flags      flag used to customize the output (see DSRTypes::XF_xxx)
+     ** @param  stream  output stream to which the XML document is written
+     *  @param  flags   flag used to customize the output (see DSRTypes::XF_xxx)
      ** @return status, EC_Normal if successful, an error code otherwise
      */
     virtual OFCondition writeXML(STD_NAMESPACE ostream &stream,
@@ -100,13 +93,13 @@ class DSRSCoordTreeNode
   protected:
 
     /** read content item (value) from dataset
-     ** @param  dataset    DICOM dataset from which the content item should be read
+     ** @param  dataset  DICOM dataset from which the content item should be read
      ** @return status, EC_Normal if successful, an error code otherwise
      */
     virtual OFCondition readContentItem(DcmItem &dataset);
 
     /** write content item (value) to dataset
-     ** @param  dataset    DICOM dataset to which the content item should be written
+     ** @param  dataset  DICOM dataset to which the content item should be written
      ** @return status, EC_Normal if successful, an error code otherwise
      */
     virtual OFCondition writeContentItem(DcmItem &dataset) const;
@@ -146,55 +139,3 @@ class DSRSCoordTreeNode
 
 
 #endif
-
-
-/*
- *  CVS/RCS Log:
- *  $Log: dsrscotn.h,v $
- *  Revision 1.14  2010-10-14 13:16:33  joergr
- *  Updated copyright header. Added reference to COPYRIGHT file.
- *
- *  Revision 1.13  2009-10-13 14:57:50  uli
- *  Switched to logging mechanism provided by the "new" oflog module.
- *
- *  Revision 1.12  2007-11-15 16:33:30  joergr
- *  Added support for output in XHTML 1.1 format.
- *
- *  Revision 1.11  2006/08/15 16:40:03  meichel
- *  Updated the code in module dcmsr to correctly compile when
- *    all standard C++ classes remain in namespace std.
- *
- *  Revision 1.10  2005/12/08 16:05:16  meichel
- *  Changed include path schema for all DCMTK header files
- *
- *  Revision 1.9  2003/09/15 14:18:54  joergr
- *  Introduced new class to facilitate checking of SR IOD relationship content
- *  constraints. Replaced old implementation distributed over numerous classes.
- *
- *  Revision 1.8  2003/08/07 12:46:22  joergr
- *  Added readXML functionality. Added support for Chest CAD SR.
- *
- *  Revision 1.7  2001/11/09 16:10:52  joergr
- *  Added preliminary support for Mammography CAD SR.
- *
- *  Revision 1.6  2001/09/26 13:04:10  meichel
- *  Adapted dcmsr to class OFCondition
- *
- *  Revision 1.5  2001/06/01 15:51:03  meichel
- *  Updated copyright header
- *
- *  Revision 1.4  2000/11/07 18:14:30  joergr
- *  Enhanced support for by-reference relationships.
- *
- *  Revision 1.3  2000/11/01 16:23:24  joergr
- *  Added support for conversion to XML.
- *
- *  Revision 1.2  2000/10/23 15:12:55  joergr
- *  Added/updated doc++ comments.
- *
- *  Revision 1.1  2000/10/13 07:49:31  joergr
- *  Added new module 'dcmsr' providing access to DICOM structured reporting
- *  documents (supplement 23).  Doc++ documentation not yet completed.
- *
- *
- */
