@@ -1,6 +1,6 @@
 /*
  *
- *  Copyright (C) 2002-2016, OFFIS e.V.
+ *  Copyright (C) 2002-2012, OFFIS e.V.
  *  All rights reserved.  See COPYRIGHT file for details.
  *
  *  This software and supporting documentation were developed by
@@ -79,11 +79,9 @@ class DCMTK_DCMSR_EXPORT DSRSOPInstanceReferenceList
      *  i.e. the structure might look different when written back to a dataset.  However,
      *  the content is identical and this way of storing information saves storage space.
      ** @param  dataset  DICOM dataset from which the data should be read
-     *  @param  flags    flag used to customize the reading process (see DSRTypes::RF_xxx)
      ** @return status, EC_Normal if successful, an error code otherwise
      */
-    OFCondition read(DcmItem &dataset,
-                     const size_t flags);
+    OFCondition read(DcmItem &dataset);
 
     /** write list of referenced SOP instances.
      *  Does nothing if list is empty.
@@ -99,7 +97,7 @@ class DCMTK_DCMSR_EXPORT DSRSOPInstanceReferenceList
      *  the content is identical and this way of storing information saves storage space.
      ** @param  doc     document containing the XML file content
      *  @param  cursor  cursor pointing to the starting node
-     *  @param  flags   flag used to customize the reading process (see DSRTypes::XF_xxx)
+     *  @param  flags   optional flag used to customize the reading process (see DSRTypes::XF_xxx)
      ** @return status, EC_Normal if successful, an error code otherwise
      */
     OFCondition readXML(const DSRXMLDocument &doc,
@@ -108,11 +106,11 @@ class DCMTK_DCMSR_EXPORT DSRSOPInstanceReferenceList
 
     /** write current list of references in XML format
      ** @param  stream  output stream to which the XML data is written
-     *  @param  flags   flag used to customize the output (see DSRTypes::XF_xxx)
+     *  @param  flags   optional flag used to customize the output (see DSRTypes::XF_xxx)
      ** @return status, EC_Normal if successful, an error code otherwise
      */
     OFCondition writeXML(STD_NAMESPACE ostream &stream,
-                         const size_t flags) const;
+                         const size_t flags = 0) const;
 
     /** add the specified item to the list of references.
      *  Before adding the item, the given UID values are usually checked.  If one of the
@@ -234,15 +232,6 @@ class DCMTK_DCMSR_EXPORT DSRSOPInstanceReferenceList
      */
     const OFString &getSOPClassUID(OFString &stringValue) const;
 
-    /** get name associated with the SOP class UID of the currently selected entry
-     ** @param  stringValue  reference to string variable in which the result is stored
-     *  @param  defaultName  string value that is returned if the SOP class UID is unknown
-     ** @return reference to the resulting string (might be empty even if 'defaultName' is
-     *          non-empty, e.g. in case no entry is currently selected)
-     */
-    const OFString &getSOPClassName(OFString &stringValue,
-                                    const OFString &defaultName = "unknown SOP Class UID") const;
-
     /** get the retrieve application entity title of the currently selected entry (optional).
      *  The resulting string may contain multiple values separated by a backslash ("\").
      ** @param  stringValue  reference to string variable in which the result is stored
@@ -367,11 +356,9 @@ class DCMTK_DCMSR_EXPORT DSRSOPInstanceReferenceList
 
         /** read instance level attributes from dataset
          ** @param  dataset  DICOM dataset from which the list should be read
-         *  @param  flags    flag used to customize the reading process (see DSRTypes::RF_xxx)
          ** @return status, EC_Normal if successful, an error code otherwise
          */
-        OFCondition read(DcmItem &dataset,
-                         const size_t flags);
+        OFCondition read(DcmItem &dataset);
 
         /** write series and instance level attributes to dataset
          ** @param  dataset  DICOM dataset to which the list should be written
@@ -382,20 +369,18 @@ class DCMTK_DCMSR_EXPORT DSRSOPInstanceReferenceList
         /** read series and instance level attributes from XML document
          ** @param  doc     document containing the XML file content
          *  @param  cursor  cursor pointing to the starting node
-         *  @param  flags   flag used to customize the reading process (see DSRTypes::XF_xxx)
          ** @return status, EC_Normal if successful, an error code otherwise
          */
         OFCondition readXML(const DSRXMLDocument &doc,
-                            DSRXMLCursor cursor,
-                            const size_t flags);
+                            DSRXMLCursor cursor);
 
         /** write series and instance level attributes in XML format
          ** @param  stream  output stream to which the XML document is written
-         *  @param  flags   flag used to customize the output (see DSRTypes::XF_xxx)
+         *  @param  flags   optional flag used to customize the output (see DSRTypes::XF_xxx)
          ** @return status, EC_Normal if successful, an error code otherwise
          */
         OFCondition writeXML(STD_NAMESPACE ostream &stream,
-                             const size_t flags) const;
+                             const size_t flags = 0) const;
 
         /** set cursor to the specified instance (if existent)
          ** @param  instanceUID  SOP instance UID of the entry to be searched for
@@ -471,11 +456,9 @@ class DCMTK_DCMSR_EXPORT DSRSOPInstanceReferenceList
 
         /** read series and instance level from dataset
          ** @param  dataset  DICOM dataset from which the list should be read
-         *  @param  flags    flag used to customize the reading process (see DSRTypes::RF_xxx)
          ** @return status, EC_Normal if successful, an error code otherwise
          */
-        OFCondition read(DcmItem &dataset,
-                         const size_t flags);
+        OFCondition read(DcmItem &dataset);
 
         /** write study, series and instance level attributes to dataset
          ** @param  dataset  DICOM dataset to which the list should be written
@@ -486,20 +469,18 @@ class DCMTK_DCMSR_EXPORT DSRSOPInstanceReferenceList
         /** read study, series and instance level attributes from XML document
          ** @param  doc     document containing the XML file content
          *  @param  cursor  cursor pointing to the starting node
-         *  @param  flags   flag used to customize the reading process (see DSRTypes::XF_xxx)
          ** @return status, EC_Normal if successful, an error code otherwise
          */
         OFCondition readXML(const DSRXMLDocument &doc,
-                            DSRXMLCursor cursor,
-                            const size_t flags);
+                            DSRXMLCursor cursor);
 
         /** write study, series and instance level attributes in XML format
          ** @param  stream  output stream to which the XML document is written
-         *  @param  flags   flag used to customize the output (see DSRTypes::XF_xxx)
+         *  @param  flags   optional flag used to customize the output (see DSRTypes::XF_xxx)
          ** @return status, EC_Normal if successful, an error code otherwise
          */
         OFCondition writeXML(STD_NAMESPACE ostream &stream,
-                             const size_t flags) const;
+                             const size_t flags = 0) const;
 
         /** set cursor to the specified series entry (if existent)
          ** @param  seriesUID  series instance UID of the entry to be searched for
