@@ -1,6 +1,6 @@
 /*
  *
- *  Copyright (C) 2000-2015, OFFIS e.V.
+ *  Copyright (C) 2000-2013, OFFIS e.V.
  *  All rights reserved.  See COPYRIGHT file for details.
  *
  *  This software and supporting documentation were developed by
@@ -98,12 +98,10 @@ class DCMTK_DCMSR_EXPORT DSRStringValue
      *  does not conform with the type (1), value multiplicity (1) and/or value representation.
      ** @param  dataset  DICOM dataset from which the string value should be read
      *  @param  tagKey   DICOM tag specifying the attribute which should be read
-     *  @param  flags    flag used to customize the reading process (see DSRTypes::RF_xxx)
      ** @return status, EC_Normal if successful, an error code otherwise
      */
     OFCondition read(DcmItem &dataset,
-                     const DcmTagKey &tagKey,
-                     const size_t flags);
+                     const DcmTagKey &tagKey);
 
     /** write string value to dataset
      ** @param  dataset  DICOM dataset to which the string value should be written
@@ -116,13 +114,11 @@ class DCMTK_DCMSR_EXPORT DSRStringValue
     /** read string value from XML document
      ** @param  doc       document containing the XML file content
      *  @param  cursor    cursor pointing to the starting node
-     *  @param  flags     flag used to customize the reading process (see DSRTypes::XF_xxx)
      *  @param  encoding  use encoding handler if OFTrue, ignore character set otherwise
      ** @return status, EC_Normal if successful, an error code otherwise
      */
     OFCondition readXML(const DSRXMLDocument &doc,
                         DSRXMLCursor cursor,
-                        const size_t flags,
                         const OFBool encoding = OFFalse);
 
     /** render string value in HTML/XHTML format
@@ -146,42 +142,13 @@ class DCMTK_DCMSR_EXPORT DSRStringValue
      *  current value is not replaced and remains unchanged.  Use the clear() method to empty
      *  the string value (which becomes invalid afterwards).
      ** @param  stringValue  value to be set (various VRs, mandatory)
-     *  @param  check        if enabled, check value for validity before setting it.  See
-     *                       checkValue() method for details.  An empty value is never accepted.
+     *  @param  check        check 'stringValue' for conformance with VR and VM if enabled.
+     *                       An empty value is never accepted.
      ** @return status, EC_Normal if successful, an error code otherwise
      */
     OFCondition setValue(const OFString &stringValue,
                          const OFBool check = OFTrue);
 
-    /** set string value from element.
-     *  Before setting the string value, it is usually checked.  If the value is invalid, the
-     *  current value is not replaced and remains unchanged.
-     ** @param  delem  DICOM element from which the string value should be retrieved
-     *  @param  pos    index of the value in case of multi-valued elements (0..vm-1)
-     *  @param  check  if enabled, check string value for validity before setting it.  See
-     *                 checkValue() method for details.  An empty value is never accepted.
-     ** @return status, EC_Normal if successful, an error code otherwise
-     */
-    OFCondition setValue(const DcmElement &delem,
-                         const unsigned long pos = 0,
-                         const OFBool check = OFTrue);
-
-    /** set string value from dataset.
-     *  Before setting the string value, it is usually checked.  If the value is invalid, the
-     *  current value is not replaced and remains unchanged.
-     ** @param  dataset  DICOM dataset from which the string value should be retrieved
-     *  @param  tagKey   DICOM tag specifying the attribute from which the value should be
-     *                   retrieved.  The search is limited to the top-level of the dataset.
-     *  @param  pos      index of the value in case of multi-valued elements (0..vm-1)
-     *  @param  check    if enabled, check string value for validity before setting it.  See
-     *                   checkValue() method for details.  An empty value is never accepted.
-     ** @return status, EC_Normal if successful, an error code otherwise
-     */
-    OFCondition setValue(DcmItem &dataset,
-                         const DcmTagKey &tagKey,
-                         const unsigned long pos = 0,
-                         const OFBool check = OFTrue);
-
 
   protected:
 
