@@ -1,6 +1,6 @@
 /*
  *
- *  Copyright (C) 2000-2015, OFFIS e.V.
+ *  Copyright (C) 2000-2012, OFFIS e.V.
  *  All rights reserved.  See COPYRIGHT file for details.
  *
  *  This software and supporting documentation were developed by
@@ -26,7 +26,7 @@
 
 #include "dcmtk/config/osconfig.h"   /* make sure OS specific configuration is included first */
 
-#include "dcmtk/dcmsr/dsrdoctn.h"
+#include "dcmtk/dcmsr/dsrdoctr.h"
 #include "dcmtk/dcmsr/dsrtcovl.h"
 
 
@@ -44,45 +44,26 @@ class DCMTK_DCMSR_EXPORT DSRTCoordTreeNode
   public:
 
     /** constructor
-     ** @param  relationshipType  type of relationship to the parent tree node.  Should
-     *                            not be DSRTypes::RT_invalid or DSRTypes::RT_isRoot.
+     ** @param  relationshipType  type of relationship to the parent tree node.
+     *                            Should not be RT_invalid or RT_isRoot.
      */
     DSRTCoordTreeNode(const E_RelationshipType relationshipType);
 
-    /** copy constructor.
-     *  Please note that the comments on the copy constructor of the base class
-     *  DSRDocumentTreeNode apply.
-     ** @param  node  tree node to be copied
-     */
-    DSRTCoordTreeNode(const DSRTCoordTreeNode &node);
-
     /** destructor
      */
     virtual ~DSRTCoordTreeNode();
 
-    /** clone this tree node.
-     *  Internally, the copy constructor is used, so the corresponding comments apply.
-     ** @return copy of this tree node
-     */
-    virtual DSRTCoordTreeNode *clone() const;
-
     /** clear all member variables.
      *  Please note that the content item might become invalid afterwards.
      */
     virtual void clear();
 
     /** check whether the content item is valid.
-     *  The content item is valid if the two base classes are valid.  This check includes the value
-     *  of the content item, which can also be checked separately with hasValidValue().
+     *  The content item is valid if the two base classes are valid.
      ** @return OFTrue if tree node is valid, OFFalse otherwise
      */
     virtual OFBool isValid() const;
 
-    /** check whether the value of the content item, i.e.\ the temporal coordinates value, is valid
-     ** @return OFTrue if the value is valid, OFFalse otherwise
-     */
-    virtual OFBool hasValidValue() const;
-
     /** check whether the content is short.
      *  The method isShort() from the base class DSRTemporalCoordinatesValue is called.
      ** @param  flags  flag used to customize the output (see DSRTypes::HF_xxx)
@@ -113,11 +94,9 @@ class DCMTK_DCMSR_EXPORT DSRTCoordTreeNode
 
     /** read content item (value) from dataset
      ** @param  dataset  DICOM dataset from which the content item should be read
-     *  @param  flags    flag used to customize the reading process (see DSRTypes::RF_xxx)
      ** @return status, EC_Normal if successful, an error code otherwise
      */
-    virtual OFCondition readContentItem(DcmItem &dataset,
-                                        const size_t flags);
+    virtual OFCondition readContentItem(DcmItem &dataset);
 
     /** write content item (value) to dataset
      ** @param  dataset  DICOM dataset to which the content item should be written
@@ -128,12 +107,10 @@ class DCMTK_DCMSR_EXPORT DSRTCoordTreeNode
     /** read content item specific XML data
      ** @param  doc     document containing the XML file content
      *  @param  cursor  cursor pointing to the starting node
-     *  @param  flags   flag used to customize the reading process (see DSRTypes::XF_xxx)
      ** @return status, EC_Normal if successful, an error code otherwise
      */
     virtual OFCondition readXMLContentItem(const DSRXMLDocument &doc,
-                                           DSRXMLCursor cursor,
-                                           const size_t flags);
+                                           DSRXMLCursor cursor);
 
    /** render content item (value) in HTML/XHTML format
      ** @param  docStream     output stream to which the main HTML/XHTML document is written
@@ -153,9 +130,10 @@ class DCMTK_DCMSR_EXPORT DSRTCoordTreeNode
 
   private:
 
-// --- declaration of default constructor and assignment operator
+// --- declaration of default/copy constructor and assignment operator
 
     DSRTCoordTreeNode();
+    DSRTCoordTreeNode(const DSRTCoordTreeNode &);
     DSRTCoordTreeNode &operator=(const DSRTCoordTreeNode &);
 };
 
