@@ -1,6 +1,6 @@
 /*
  *
- *  Copyright (C) 2000-2015, OFFIS e.V.
+ *  Copyright (C) 2000-2012, OFFIS e.V.
  *  All rights reserved.  See COPYRIGHT file for details.
  *
  *  This software and supporting documentation were developed by
@@ -44,14 +44,14 @@ class DCMTK_DCMSR_EXPORT DSRTextTreeNode
   public:
 
     /** constructor
-     ** @param  relationshipType  type of relationship to the parent tree node.  Should
-     *                            not be DSRTypes::RT_invalid or DSRTypes::RT_isRoot.
+     ** @param  relationshipType  type of relationship to the parent tree node.
+     *                            Should not be RT_invalid or RT_isRoot.
      */
     DSRTextTreeNode(const E_RelationshipType relationshipType);
 
     /** constructor
      ** @param  relationshipType  type of relationship to the parent tree node.
-     *                            Should not be DSRTypes::RT_invalid or DSRTypes::RT_isRoot.
+     *                            Should not be RT_invalid or RT_isRoot.
      *  @param  textValue         initial value to be set (VR=UT, mandatory)
      *  @param  check             if enabled, check 'textValue' for validity before setting
      *                            it.  See checkValue() for details.  An empty value is never
@@ -61,23 +61,10 @@ class DCMTK_DCMSR_EXPORT DSRTextTreeNode
                     const OFString &textValue,
                     const OFBool check = OFTrue);
 
-    /** copy constructor.
-     *  Please note that the comments on the copy constructor of the base class
-     *  DSRDocumentTreeNode apply.
-     ** @param  node  tree node to be copied
-     */
-    DSRTextTreeNode(const DSRTextTreeNode &node);
-
     /** destructor
      */
     virtual ~DSRTextTreeNode();
 
-    /** clone this tree node.
-     *  Internally, the copy constructor is used, so the corresponding comments apply.
-     ** @return copy of this tree node
-     */
-    virtual DSRTextTreeNode *clone() const;
-
     /** clear all member variables.
      *  Please note that the content item might become invalid afterwards.
      */
@@ -85,16 +72,11 @@ class DCMTK_DCMSR_EXPORT DSRTextTreeNode
 
     /** check whether the content item is valid.
      *  The content item is valid if the base classes, the concept name and the currently
-     *  stored value (see hasValidValue()) are valid.
+     *  stored date value are valid.
      ** @return OFTrue if tree node is valid, OFFalse otherwise
      */
     virtual OFBool isValid() const;
 
-    /** check whether the value of the content item, i.e.\ the stored text value, is valid
-     ** @return OFTrue if the value is valid, OFFalse otherwise
-     */
-    virtual OFBool hasValidValue() const;
-
     /** check whether the content is short.
      *  A text is short if the length is <= 40 characters.
      ** @param  flags  flag used to customize the output (see DSRTypes::HF_xxx)
@@ -104,8 +86,8 @@ class DCMTK_DCMSR_EXPORT DSRTextTreeNode
 
     /** print content item.
      *  A typical output looks like this: contains TEXT:(,,"Text Code")="This is a Text."
-     *  If the 'flag' DSRTypes::PF_shortenLongItemValues is set, the text is limited to
-     *  40 characters (incl. trailing "...").
+     *  If the 'flag' PF_shortenLongItemValues is set the text is limited to 40 characters
+     *  (incl. trailing "...").
      ** @param  stream  output stream to which the content item should be printed
      *  @param  flags   flag used to customize the output (see DSRTypes::PF_xxx)
      ** @return status, EC_Normal if successful, an error code otherwise
@@ -126,11 +108,9 @@ class DCMTK_DCMSR_EXPORT DSRTextTreeNode
 
     /** read content item (value) from dataset
      ** @param  dataset  DICOM dataset from which the content item should be read
-     *  @param  flags    flag used to customize the reading process (see DSRTypes::RF_xxx)
      ** @return status, EC_Normal if successful, an error code otherwise
      */
-    virtual OFCondition readContentItem(DcmItem &dataset,
-                                        const size_t flags);
+    virtual OFCondition readContentItem(DcmItem &dataset);
 
     /** write content item (value) to dataset
      ** @param  dataset  DICOM dataset to which the content item should be written
@@ -141,12 +121,10 @@ class DCMTK_DCMSR_EXPORT DSRTextTreeNode
     /** read content item specific XML data
      ** @param  doc     document containing the XML file content
      *  @param  cursor  cursor pointing to the starting node
-     *  @param  flags   flag used to customize the reading process (see DSRTypes::XF_xxx)
      ** @return status, EC_Normal if successful, an error code otherwise
      */
     virtual OFCondition readXMLContentItem(const DSRXMLDocument &doc,
-                                           DSRXMLCursor cursor,
-                                           const size_t flags);
+                                           DSRXMLCursor cursor);
 
     /** render content item (value) in HTML/XHTML format
      ** @param  docStream     output stream to which the main HTML/XHTML document is written
@@ -174,9 +152,10 @@ class DCMTK_DCMSR_EXPORT DSRTextTreeNode
 
   private:
 
- // --- declaration of default constructor and assignment operator
+ // --- declaration of default/copy constructor and assignment operator
 
     DSRTextTreeNode();
+    DSRTextTreeNode(const DSRTextTreeNode &);
     DSRTextTreeNode &operator=(const DSRTextTreeNode &);
 };
 
