@@ -1,6 +1,6 @@
 /*
  *
- *  Copyright (C) 2000-2015, OFFIS e.V.
+ *  Copyright (C) 2000-2013, OFFIS e.V.
  *  All rights reserved.  See COPYRIGHT file for details.
  *
  *  This software and supporting documentation were developed by
@@ -104,12 +104,10 @@ class DCMTK_DCMSR_EXPORT DSRWaveformReferenceValue
     /** read waveform reference from XML document
      ** @param  doc     document containing the XML file content
      *  @param  cursor  cursor pointing to the starting node
-     *  @param  flags   flag used to customize the reading process (see DSRTypes::XF_xxx)
      ** @return status, EC_Normal if successful, an error code otherwise
      */
     virtual OFCondition readXML(const DSRXMLDocument &doc,
-                                DSRXMLCursor cursor,
-                                const size_t flags);
+                                DSRXMLCursor cursor);
 
     /** write waveform reference in XML format
      ** @param  stream  output stream to which the XML document is written
@@ -189,11 +187,9 @@ class DCMTK_DCMSR_EXPORT DSRWaveformReferenceValue
 
     /** read waveform reference value from dataset
      ** @param  dataset  DICOM dataset from which the value should be read
-     *  @param  flags    flag used to customize the reading process (see DSRTypes::RF_xxx)
      ** @return status, EC_Normal if successful, an error code otherwise
      */
-    virtual OFCondition readItem(DcmItem &dataset,
-                                 const size_t flags);
+    virtual OFCondition readItem(DcmItem &dataset);
 
     /** write waveform reference value to dataset
      ** @param  dataset  DICOM dataset to which the value should be written
@@ -203,8 +199,8 @@ class DCMTK_DCMSR_EXPORT DSRWaveformReferenceValue
 
     /** check the specified SOP class UID for validity.
      *  This method further specializes the checks performed in the base class
-     *  DSRCompositeReferenceValue.  All waveform SOP classes that are defined
-     *  in DICOM PS 3.6-2014a are allowed.
+     *  DSRCompositeReferenceValue.  Currently, all waveform SOP classes that are defined
+     *  in DICOM PS 3.6-2011 are allowed.
      ** @param  sopClassUID  SOP class UID to be checked
      ** @return status, EC_Normal if value is valid, an error code otherwise
      */
