@@ -1,6 +1,6 @@
 /*
  *
- *  Copyright (C) 2000-2015, OFFIS e.V.
+ *  Copyright (C) 2000-2013, OFFIS e.V.
  *  All rights reserved.  See COPYRIGHT file for details.
  *
  *  This software and supporting documentation were developed by
@@ -11,9 +11,9 @@
  *    D-26121 Oldenburg, Germany
  *
  *
- *  Module: dcmsr
+ *  Module:  dcmsr
  *
- *  Author: Joerg Riesmeier
+ *  Author:  Joerg Riesmeier
  *
  *  Purpose:
  *    classes: DSRCompositeTreeNode
@@ -37,24 +37,11 @@ DSRCompositeTreeNode::DSRCompositeTreeNode(const E_RelationshipType relationship
 }
 
 
-DSRCompositeTreeNode::DSRCompositeTreeNode(const DSRCompositeTreeNode &node)
-  : DSRDocumentTreeNode(node),
-    DSRCompositeReferenceValue(node)
-{
-}
-
-
 DSRCompositeTreeNode::~DSRCompositeTreeNode()
 {
 }
 
 
-DSRCompositeTreeNode *DSRCompositeTreeNode::clone() const
-{
-    return new DSRCompositeTreeNode(*this);
-}
-
-
 void DSRCompositeTreeNode::clear()
 {
     DSRDocumentTreeNode::clear();
@@ -64,13 +51,7 @@ void DSRCompositeTreeNode::clear()
 
 OFBool DSRCompositeTreeNode::isValid() const
 {
-    return DSRDocumentTreeNode::isValid() && hasValidValue();
-}
-
-
-OFBool DSRCompositeTreeNode::hasValidValue() const
-{
-    return DSRCompositeReferenceValue::isValid();
+    return DSRDocumentTreeNode::isValid() && DSRCompositeReferenceValue::isValid();
 }
 
 
@@ -103,11 +84,10 @@ OFCondition DSRCompositeTreeNode::writeXML(STD_NAMESPACE ostream &stream,
 }
 
 
-OFCondition DSRCompositeTreeNode::readContentItem(DcmItem &dataset,
-                                                  const size_t flags)
+OFCondition DSRCompositeTreeNode::readContentItem(DcmItem &dataset)
 {
     /* read ReferencedSOPSequence */
-    return DSRCompositeReferenceValue::readSequence(dataset, DCM_ReferencedSOPSequence, "1" /* type */, flags);
+    return DSRCompositeReferenceValue::readSequence(dataset, DCM_ReferencedSOPSequence, "1" /* type */);
 }
 
 
@@ -119,11 +99,10 @@ OFCondition DSRCompositeTreeNode::writeContentItem(DcmItem &dataset) const
 
 
 OFCondition DSRCompositeTreeNode::readXMLContentItem(const DSRXMLDocument &doc,
-                                                     DSRXMLCursor cursor,
-                                                     const size_t flags)
+                                                     DSRXMLCursor cursor)
 {
     /* retrieve value from XML element "value" */
-    return DSRCompositeReferenceValue::readXML(doc, doc.getNamedNode(cursor.gotoChild(), "value"), flags);
+    return DSRCompositeReferenceValue::readXML(doc, doc.getNamedNode(cursor.gotoChild(), "value"));
 }
 
 
