@@ -1,6 +1,6 @@
 /*
  *
- *  Copyright (C) 2000-2015, OFFIS e.V.
+ *  Copyright (C) 2000-2012, OFFIS e.V.
  *  All rights reserved.  See COPYRIGHT file for details.
  *
  *  This software and supporting documentation were developed by
@@ -11,9 +11,9 @@
  *    D-26121 Oldenburg, Germany
  *
  *
- *  Module: dcmsr
+ *  Module:  dcmsr
  *
- *  Author: Joerg Riesmeier
+ *  Author:  Joerg Riesmeier
  *
  *  Purpose:
  *    classes: DSRContainerTreeNode
@@ -30,15 +30,8 @@
 
 DSRContainerTreeNode::DSRContainerTreeNode(const E_RelationshipType relationshipType,
                                            const E_ContinuityOfContent continuityOfContent)
-  : DSRDocumentTreeNode(relationshipType, VT_Container),
-    ContinuityOfContent(continuityOfContent)
-{
-}
-
-
-DSRContainerTreeNode::DSRContainerTreeNode(const DSRContainerTreeNode &node)
-  : DSRDocumentTreeNode(node),
-    ContinuityOfContent(node.ContinuityOfContent)
+ : DSRDocumentTreeNode(relationshipType, VT_Container),
+   ContinuityOfContent(continuityOfContent)
 {
 }
 
@@ -48,12 +41,6 @@ DSRContainerTreeNode::~DSRContainerTreeNode()
 }
 
 
-DSRContainerTreeNode *DSRContainerTreeNode::clone() const
-{
-    return new DSRContainerTreeNode(*this);
-}
-
-
 void DSRContainerTreeNode::clear()
 {
     ContinuityOfContent = COC_Separate;      // this is more useful that COC_invalid
@@ -63,17 +50,11 @@ void DSRContainerTreeNode::clear()
 OFBool DSRContainerTreeNode::isValid() const
 {
     /* ConceptNameCodeSequence required for root node container */
-    return DSRDocumentTreeNode::isValid() && hasValidValue() &&
+    return DSRDocumentTreeNode::isValid() && (ContinuityOfContent != COC_invalid) &&
         ((getRelationshipType() != RT_isRoot) || getConceptName().isValid());
 }
 
 
-OFBool DSRContainerTreeNode::hasValidValue() const
-{
-    return (ContinuityOfContent != COC_invalid);
-}
-
-
 OFBool DSRContainerTreeNode::isShort(const size_t /*flags*/) const
 {
     return OFFalse;
@@ -95,8 +76,7 @@ OFCondition DSRContainerTreeNode::print(STD_NAMESPACE ostream &stream,
 }
 
 
-OFCondition DSRContainerTreeNode::readContentItem(DcmItem &dataset,
-                                                  const size_t /*flags*/)
+OFCondition DSRContainerTreeNode::readContentItem(DcmItem &dataset)
 {
     OFString tmpString;
     /* read ContinuityOfContent */
@@ -123,8 +103,7 @@ OFCondition DSRContainerTreeNode::writeContentItem(DcmItem &dataset) const
 
 
 OFCondition DSRContainerTreeNode::readXMLContentItem(const DSRXMLDocument &doc,
-                                                     DSRXMLCursor cursor,
-                                                     const size_t /*flags*/)
+                                                     DSRXMLCursor cursor)
 {
     OFCondition result = SR_EC_CorruptedXMLStructure;
     if (cursor.valid())
