@@ -1,6 +1,6 @@
 /*
  *
- *  Copyright (C) 2000-2015, OFFIS e.V.
+ *  Copyright (C) 2000-2012, OFFIS e.V.
  *  All rights reserved.  See COPYRIGHT file for details.
  *
  *  This software and supporting documentation were developed by
@@ -11,9 +11,9 @@
  *    D-26121 Oldenburg, Germany
  *
  *
- *  Module: dcmsr
+ *  Module:  dcmsr
  *
- *  Author: Joerg Riesmeier
+ *  Author:  Joerg Riesmeier
  *
  *  Purpose:
  *    classes: DSRDateTreeNode
@@ -45,24 +45,11 @@ DSRDateTreeNode::DSRDateTreeNode(const E_RelationshipType relationshipType,
 }
 
 
-DSRDateTreeNode::DSRDateTreeNode(const DSRDateTreeNode &node)
-  : DSRDocumentTreeNode(node),
-    DSRStringValue(node)
-{
-}
-
-
 DSRDateTreeNode::~DSRDateTreeNode()
 {
 }
 
 
-DSRDateTreeNode *DSRDateTreeNode::clone() const
-{
-    return new DSRDateTreeNode(*this);
-}
-
-
 void DSRDateTreeNode::clear()
 {
     DSRDocumentTreeNode::clear();
@@ -73,13 +60,7 @@ void DSRDateTreeNode::clear()
 OFBool DSRDateTreeNode::isValid() const
 {
     /* ConceptNameCodeSequence required */
-    return DSRDocumentTreeNode::isValid() && getConceptName().isValid() && hasValidValue();
-}
-
-
-OFBool DSRDateTreeNode::hasValidValue() const
-{
-    return checkCurrentValue().good();
+    return DSRDocumentTreeNode::isValid() && getConceptName().isValid() && checkCurrentValue().good();
 }
 
 
@@ -113,11 +94,10 @@ OFCondition DSRDateTreeNode::writeXML(STD_NAMESPACE ostream &stream,
 }
 
 
-OFCondition DSRDateTreeNode::readContentItem(DcmItem &dataset,
-                                             const size_t flags)
+OFCondition DSRDateTreeNode::readContentItem(DcmItem &dataset)
 {
     /* read Date */
-    return DSRStringValue::read(dataset, DCM_Date, flags);
+    return DSRStringValue::read(dataset, DCM_Date);
 }
 
 
@@ -129,8 +109,7 @@ OFCondition DSRDateTreeNode::writeContentItem(DcmItem &dataset) const
 
 
 OFCondition DSRDateTreeNode::readXMLContentItem(const DSRXMLDocument &doc,
-                                                DSRXMLCursor cursor,
-                                                const size_t /*flags*/)
+                                                DSRXMLCursor cursor)
 {
     OFString tmpString;
     /* retrieve value from XML element "value" */
