@@ -1,6 +1,6 @@
 /*
  *
- *  Copyright (C) 2000-2015, OFFIS e.V.
+ *  Copyright (C) 2000-2012, OFFIS e.V.
  *  All rights reserved.  See COPYRIGHT file for details.
  *
  *  This software and supporting documentation were developed by
@@ -11,9 +11,9 @@
  *    D-26121 Oldenburg, Germany
  *
  *
- *  Module: dcmsr
+ *  Module:  dcmsr
  *
- *  Author: Joerg Riesmeier
+ *  Author:  Joerg Riesmeier
  *
  *  Purpose:
  *    classes: DSRDateTimeTreeNode
@@ -44,24 +44,11 @@ DSRDateTimeTreeNode::DSRDateTimeTreeNode(const E_RelationshipType relationshipTy
 }
 
 
-DSRDateTimeTreeNode::DSRDateTimeTreeNode(const DSRDateTimeTreeNode &node)
-  : DSRDocumentTreeNode(node),
-    DSRStringValue(node)
-{
-}
-
-
 DSRDateTimeTreeNode::~DSRDateTimeTreeNode()
 {
 }
 
 
-DSRDateTimeTreeNode *DSRDateTimeTreeNode::clone() const
-{
-    return new DSRDateTimeTreeNode(*this);
-}
-
-
 void DSRDateTimeTreeNode::clear()
 {
     DSRDocumentTreeNode::clear();
@@ -72,13 +59,7 @@ void DSRDateTimeTreeNode::clear()
 OFBool DSRDateTimeTreeNode::isValid() const
 {
     /* ConceptNameCodeSequence required */
-    return DSRDocumentTreeNode::isValid() && getConceptName().isValid() && hasValidValue();
-}
-
-
-OFBool DSRDateTimeTreeNode::hasValidValue() const
-{
-    return checkCurrentValue().good();
+    return DSRDocumentTreeNode::isValid() && getConceptName().isValid() && checkCurrentValue().good();
 }
 
 
@@ -113,11 +94,10 @@ OFCondition DSRDateTimeTreeNode::writeXML(STD_NAMESPACE ostream &stream,
 }
 
 
-OFCondition DSRDateTimeTreeNode::readContentItem(DcmItem &dataset,
-                                                 const size_t flags)
+OFCondition DSRDateTimeTreeNode::readContentItem(DcmItem &dataset)
 {
     /* read DateTime */
-    return DSRStringValue::read(dataset, DCM_DateTime, flags);
+    return DSRStringValue::read(dataset, DCM_DateTime);
 }
 
 
@@ -129,8 +109,7 @@ OFCondition DSRDateTimeTreeNode::writeContentItem(DcmItem &dataset) const
 
 
 OFCondition DSRDateTimeTreeNode::readXMLContentItem(const DSRXMLDocument &doc,
-                                                    DSRXMLCursor cursor,
-                                                    const size_t /*flags*/)
+                                                    DSRXMLCursor cursor)
 {
     OFString tmpString;
     /* retrieve value from XML element "value" */
