@@ -1,6 +1,6 @@
 /*
  *
- *  Copyright (C) 2000-2016, OFFIS e.V.
+ *  Copyright (C) 2000-2013, OFFIS e.V.
  *  All rights reserved.  See COPYRIGHT file for details.
  *
  *  This software and supporting documentation were developed by
@@ -11,9 +11,9 @@
  *    D-26121 Oldenburg, Germany
  *
  *
- *  Module: dcmsr
+ *  Module:  dcmsr
  *
- *  Author: Joerg Riesmeier
+ *  Author:  Joerg Riesmeier
  *
  *  Purpose:
  *    classes: DSRImageFrameList
@@ -28,9 +28,14 @@
 #define INCLUDE_CSTDIO
 #include "dcmtk/ofstd/ofstdinc.h"
 
+#ifdef HAVE_EXPLICIT_TEMPLATE_SPECIALIZATION
+#define EXPLICIT_SPECIALIZATION template<>
+#else
+#define EXPLICIT_SPECIALIZATION
+#endif
+
 /* declared in class DSRListOfItems<T> */
-DCMTK_EXPLICIT_SPECIALIZATION
-const Sint32 DSRListOfItems<Sint32>::EmptyItem = 0;
+EXPLICIT_SPECIALIZATION const Sint32 DSRListOfItems<Sint32>::EmptyItem = 0;
 
 
 DSRImageFrameList::DSRImageFrameList()
@@ -82,8 +87,7 @@ OFCondition DSRImageFrameList::print(STD_NAMESPACE ostream &stream,
 }
 
 
-OFCondition DSRImageFrameList::read(DcmItem &dataset,
-                                    const size_t /*flags*/)
+OFCondition DSRImageFrameList::read(DcmItem &dataset)
 {
     /* get integer string from dataset */
     DcmIntegerString delem(DCM_ReferencedFrameNumber);
