@@ -1,6 +1,6 @@
 /*
  *
- *  Copyright (C) 2000-2015, OFFIS e.V.
+ *  Copyright (C) 2000-2013, OFFIS e.V.
  *  All rights reserved.  See COPYRIGHT file for details.
  *
  *  This software and supporting documentation were developed by
@@ -11,9 +11,9 @@
  *    D-26121 Oldenburg, Germany
  *
  *
- *  Module: dcmsr
+ *  Module:  dcmsr
  *
- *  Author: Joerg Riesmeier
+ *  Author:  Joerg Riesmeier
  *
  *  Purpose:
  *    classes: DSRImageTreeNode
@@ -35,24 +35,11 @@ DSRImageTreeNode::DSRImageTreeNode(const E_RelationshipType relationshipType)
 }
 
 
-DSRImageTreeNode::DSRImageTreeNode(const DSRImageTreeNode &node)
-  : DSRDocumentTreeNode(node),
-    DSRImageReferenceValue(node)
-{
-}
-
-
 DSRImageTreeNode::~DSRImageTreeNode()
 {
 }
 
 
-DSRImageTreeNode *DSRImageTreeNode::clone() const
-{
-    return new DSRImageTreeNode(*this);
-}
-
-
 void DSRImageTreeNode::clear()
 {
     DSRDocumentTreeNode::clear();
@@ -62,13 +49,7 @@ void DSRImageTreeNode::clear()
 
 OFBool DSRImageTreeNode::isValid() const
 {
-    return DSRDocumentTreeNode::isValid() && hasValidValue();
-}
-
-
-OFBool DSRImageTreeNode::hasValidValue() const
-{
-    return DSRImageReferenceValue::isValid();
+    return DSRDocumentTreeNode::isValid() && DSRImageReferenceValue::isValid();
 }
 
 
@@ -107,11 +88,10 @@ OFCondition DSRImageTreeNode::writeXML(STD_NAMESPACE ostream &stream,
 }
 
 
-OFCondition DSRImageTreeNode::readContentItem(DcmItem &dataset,
-                                              const size_t flags)
+OFCondition DSRImageTreeNode::readContentItem(DcmItem &dataset)
 {
     /* read ReferencedSOPSequence */
-    return DSRImageReferenceValue::readSequence(dataset, DCM_ReferencedSOPSequence, "1" /*type*/, flags);
+    return DSRImageReferenceValue::readSequence(dataset, DCM_ReferencedSOPSequence, "1" /*type*/);
 }
 
 
@@ -123,11 +103,10 @@ OFCondition DSRImageTreeNode::writeContentItem(DcmItem &dataset) const
 
 
 OFCondition DSRImageTreeNode::readXMLContentItem(const DSRXMLDocument &doc,
-                                                 DSRXMLCursor cursor,
-                                                 const size_t flags)
+                                                 DSRXMLCursor cursor)
 {
     /* retrieve value from XML element "value" */
-    return DSRImageReferenceValue::readXML(doc, doc.getNamedNode(cursor.gotoChild(), "value"), flags);
+    return DSRImageReferenceValue::readXML(doc, doc.getNamedNode(cursor.gotoChild(), "value"));
 }
 
 
