@@ -1,6 +1,6 @@
 /*
  *
- *  Copyright (C) 2000-2016, OFFIS e.V.
+ *  Copyright (C) 2000-2013, OFFIS e.V.
  *  All rights reserved.  See COPYRIGHT file for details.
  *
  *  This software and supporting documentation were developed by
@@ -11,9 +11,9 @@
  *    D-26121 Oldenburg, Germany
  *
  *
- *  Module: dcmsr
+ *  Module:  dcmsr
  *
- *  Author: Joerg Riesmeier
+ *  Author:  Joerg Riesmeier
  *
  *  Purpose:
  *    classes: DSRImageReferenceValue
@@ -146,12 +146,6 @@ OFBool DSRImageReferenceValue::isShort(const size_t flags) const
 }
 
 
-OFBool DSRImageReferenceValue::isSegmentation() const
-{
-    return isSegmentationObject(SOPClassUID);
-}
-
-
 OFCondition DSRImageReferenceValue::print(STD_NAMESPACE ostream &stream,
                                           const size_t flags) const
 {
@@ -221,11 +215,10 @@ OFCondition DSRImageReferenceValue::print(STD_NAMESPACE ostream &stream,
 
 
 OFCondition DSRImageReferenceValue::readXML(const DSRXMLDocument &doc,
-                                            DSRXMLCursor cursor,
-                                            const size_t flags)
+                                            DSRXMLCursor cursor)
 {
     /* first read general composite reference information */
-    OFCondition result = DSRCompositeReferenceValue::readXML(doc, cursor, flags);
+    OFCondition result = DSRCompositeReferenceValue::readXML(doc, cursor);
     /* then read image related XML tags */
     if (result.good())
     {
@@ -251,14 +244,14 @@ OFCondition DSRImageReferenceValue::readXML(const DSRXMLDocument &doc,
             /* presentation state object (optional) */
             childCursor = doc.getNamedNode(cursor, "pstate", OFFalse /*required*/);
             if (childCursor.valid())
-                result = PresentationState.readXML(doc, childCursor, flags);
+                result = PresentationState.readXML(doc, childCursor);
         }
         if (result.good())
         {
             /* real world value mapping object (optional) */
             childCursor = doc.getNamedNode(cursor, "mapping", OFFalse /*required*/);
             if (childCursor.valid())
-                result = RealWorldValueMapping.readXML(doc, childCursor, flags);
+                result = RealWorldValueMapping.readXML(doc, childCursor);
         }
     }
     return result;
@@ -302,23 +295,22 @@ OFCondition DSRImageReferenceValue::writeXML(STD_NAMESPACE ostream &stream,
 }
 
 
-OFCondition DSRImageReferenceValue::readItem(DcmItem &dataset,
-                                             const size_t flags)
+OFCondition DSRImageReferenceValue::readItem(DcmItem &dataset)
 {
     /* be very careful, delete any previously created icon image (should never apply) */
     deleteIconImage();
     /* read ReferencedSOPClassUID and ReferencedSOPInstanceUID */
-    OFCondition result = DSRCompositeReferenceValue::readItem(dataset, flags);
+    OFCondition result = DSRCompositeReferenceValue::readItem(dataset);
     if (result.good())
     {
         /* read ReferencedFrameNumber (conditional) */
-        FrameList.read(dataset, flags);
+        FrameList.read(dataset);
         /* read ReferencedSegmentNumber (conditional) */
-        SegmentList.read(dataset, flags);
+        SegmentList.read(dataset);
         /* read ReferencedSOPSequence (Presentation State, optional) */
-        PresentationState.readSequence(dataset, DCM_ReferencedSOPSequence, "3" /*type*/, flags);
+        PresentationState.readSequence(dataset, DCM_ReferencedSOPSequence, "3" /*type*/);
         /* read ReferencedRealWorldValueMappingInstanceSequence (optional) */
-        RealWorldValueMapping.readSequence(dataset, DCM_ReferencedRealWorldValueMappingInstanceSequence, "3" /*type*/, flags);
+        RealWorldValueMapping.readSequence(dataset, DCM_ReferencedRealWorldValueMappingInstanceSequence, "3" /*type*/);
         /* read IconImageSequence (optional) */
         DcmSequenceOfItems *dseq = NULL;
         /* use local status variable since the sequence is optional */
@@ -346,7 +338,7 @@ OFCondition DSRImageReferenceValue::readItem(DcmItem &dataset,
             }
         }
         /* check data and report warnings if any */
-        checkListData(SOPClassUID, FrameList, SegmentList, OFTrue /*reportWarnings*/);
+        checkListData(FrameList, SegmentList, OFTrue /*reportWarnings*/);
     }
     return result;
 }
@@ -403,7 +395,7 @@ OFCondition DSRImageReferenceValue::writeItem(DcmItem &dataset) const
         }
     }
     /* check data and report warnings if any */
-    checkListData(SOPClassUID, FrameList, SegmentList, OFTrue /*reportWarnings*/);
+    checkListData(FrameList, SegmentList, OFTrue /*reportWarnings*/);
     return result;
 }
 
@@ -656,23 +648,12 @@ OFBool DSRImageReferenceValue::appliesToSegment(const Uint16 segmentNumber) cons
 }
 
 
-OFBool DSRImageReferenceValue::isSegmentationObject(const OFString &sopClassUID) const
-{
-    /* check for all segmentation SOP classes (according to DICOM PS 3.6-2015c) */
-    return (sopClassUID == UID_SegmentationStorage) || (sopClassUID == UID_SurfaceSegmentationStorage);
-}
-
-
 OFCondition DSRImageReferenceValue::checkSOPClassUID(const OFString &sopClassUID) const
 {
     OFCondition result = DSRCompositeReferenceValue::checkSOPClassUID(sopClassUID);
     if (result.good())
     {
-        /* check for all valid/known SOP classes (according to DICOM PS 3.6-2015c) */
-        if (!dcmIsImageStorageSOPClassUID(sopClassUID.c_str()) && !isSegmentationObject(sopClassUID))
-        {
-            result = SR_EC_InvalidValue;
-        }
+        /* tbd: might check for known IMAGE storage class later on */
     }
     return result;
 }
@@ -707,25 +688,17 @@ OFCondition DSRImageReferenceValue::checkRealWorldValueMapping(const DSRComposit
 // helper macro to avoid annoying check of boolean flag
 #define REPORT_WARNING(msg) { if (reportWarnings) DCMSR_WARN(msg); }
 
-OFCondition DSRImageReferenceValue::checkListData(const OFString &sopClassUID,
-                                                  const DSRImageFrameList &frameList,
+OFCondition DSRImageReferenceValue::checkListData(const DSRImageFrameList &frameList,
                                                   const DSRImageSegmentList &segmentList,
                                                   const OFBool reportWarnings) const
 {
     OFCondition result = EC_Normal;
-    /* check whether both lists of referenced frame and segment numbers are non-empty */
     if (!frameList.isEmpty() && !segmentList.isEmpty())
     {
-        /* this is just a warning since only one list will ever be written */
-        REPORT_WARNING("Both Referenced Frame Number and Referenced Segment Number present in IMAGE content item")
+        // this is just a warning since only one list will ever be written
+        REPORT_WARNING("Both ReferencedFrameNumber and ReferencedSegmentNumber present in IMAGE content item")
     }
-    /* check whether referenced image is a segmentation object (see "type 1C" condition) */
-    if (!segmentList.isEmpty() && !isSegmentationObject(sopClassUID))
-    {
-        REPORT_WARNING("Referenced Segment Number present in IMAGE content item for non-segmentation object")
-        result = SR_EC_InvalidValue;
-    }
-    /* tbd: check whether referenced image is a multi-frame image? (see "type 1C" condition) */
+    // tbd: check whether referenced image is a segmentation object? (see "type 1C" condition)
     return result;
 }
 
@@ -738,6 +711,6 @@ OFCondition DSRImageReferenceValue::checkCurrentValue() const
     if (result.good())
         result = checkRealWorldValueMapping(RealWorldValueMapping);
     if (result.good())
-        result = checkListData(SOPClassUID, FrameList, SegmentList);
+        result = checkListData(FrameList, SegmentList);
     return result;
 }
