@@ -1,6 +1,6 @@
 /*
  *
- *  Copyright (C) 2000-2016, OFFIS e.V.
+ *  Copyright (C) 2000-2013, OFFIS e.V.
  *  All rights reserved.  See COPYRIGHT file for details.
  *
  *  This software and supporting documentation were developed by
@@ -11,9 +11,9 @@
  *    D-26121 Oldenburg, Germany
  *
  *
- *  Module: dcmsr
+ *  Module:  dcmsr
  *
- *  Author: Joerg Riesmeier
+ *  Author:  Joerg Riesmeier
  *
  *  Purpose:
  *    classes: DSRNumericMeasurementValue
@@ -54,20 +54,6 @@ DSRNumericMeasurementValue::DSRNumericMeasurementValue(const OFString &numericVa
 }
 
 
-DSRNumericMeasurementValue::DSRNumericMeasurementValue(const DSRCodedEntryValue &valueQualifier,
-                                                       const OFBool check)
-  : NumericValue(),
-    MeasurementUnit(),
-    ValueQualifier(),
-    FloatingPointValue(DCM_FloatingPointValue),
-    RationalNumeratorValue(DCM_RationalNumeratorValue),
-    RationalDenominatorValue(DCM_RationalDenominatorValue)
-{
-    /* use the set method for checking purposes */
-    setValue(valueQualifier, check);
-}
-
-
 DSRNumericMeasurementValue::DSRNumericMeasurementValue(const OFString &numericValue,
                                                        const DSRCodedEntryValue &measurementUnit,
                                                        const DSRCodedEntryValue &valueQualifier,
@@ -128,25 +114,18 @@ void DSRNumericMeasurementValue::clear()
 OFBool DSRNumericMeasurementValue::isValid() const
 {
     /* the MeasuredValueSequence can be empty (type 2) */
-    return (isEmpty() || (checkNumericValue(NumericValue).good() && checkMeasurementUnit(MeasurementUnit).good()))
-        && checkNumericValueQualifier(ValueQualifier).good();
+    return isEmpty() || (checkNumericValue(NumericValue).good() &&
+                         checkMeasurementUnit(MeasurementUnit).good() &&
+                         checkNumericValueQualifier(ValueQualifier).good());
 }
 
 
 OFBool DSRNumericMeasurementValue::isEmpty() const
 {
-    /* the NumericValueQualifierCodeSequence is not checked */
     return NumericValue.empty() && MeasurementUnit.isEmpty();
 }
 
 
-OFBool DSRNumericMeasurementValue::isComplete() const
-{
-    /* officially, the NumericValueQualifierCodeSequence is optional (type 3) */
-    return (!NumericValue.empty() && MeasurementUnit.isComplete()) || ValueQualifier.isComplete();
-}
-
-
 OFCondition DSRNumericMeasurementValue::print(STD_NAMESPACE ostream &stream,
                                               const size_t flags) const
 {
@@ -154,24 +133,17 @@ OFCondition DSRNumericMeasurementValue::print(STD_NAMESPACE ostream &stream,
     {
         /* empty value */
         stream << "empty";
-        /* check for optional numeric value qualifier */
-        if (!ValueQualifier.isEmpty())
-        {
-            stream << " ";
-            ValueQualifier.print(stream, OFTrue /*printCodeValue*/, flags);
-        }
     } else {
         OFString printString;
         stream << "\"" << DSRTypes::convertToPrintString(NumericValue, printString) << "\" ";
-        MeasurementUnit.print(stream, OFTrue /*printCodeValue*/, flags);
+        MeasurementUnit.print(stream, OFTrue /*printCodeValue*/, (flags & DSRTypes::PF_printInvalidCodes) > 0 /*printInvalid*/);
     }
     return EC_Normal;
 }
 
 
 OFCondition DSRNumericMeasurementValue::readXML(const DSRXMLDocument &doc,
-                                                DSRXMLCursor cursor,
-                                                const size_t flags)
+                                                DSRXMLCursor cursor)
 {
     OFCondition result = SR_EC_CorruptedXMLStructure;
     if (cursor.valid())
@@ -189,13 +161,13 @@ OFCondition DSRNumericMeasurementValue::readXML(const DSRXMLDocument &doc,
                 doc.getElementFromNodeContent(doc.getNamedNode(childNode, "denominator"), RationalDenominatorValue);
             }
             /* get "unit" element (only if "value" present) */
-            result = MeasurementUnit.readXML(doc, doc.getNamedNode(cursor, "unit"), flags);
+            result = MeasurementUnit.readXML(doc, doc.getNamedNode(cursor, "unit"));
         } else
             result = EC_Normal;
         if (result.good())
         {
             /* get "qualifier" element (optional, do not report if absent or erroneous) */
-            ValueQualifier.readXML(doc, doc.getNamedNode(cursor, "qualifier", OFFalse /*required*/), flags);
+            ValueQualifier.readXML(doc, doc.getNamedNode(cursor, "qualifier", OFFalse /*required*/));
         }
         if (!isValid())
             result = SR_EC_InvalidValue;
@@ -263,12 +235,10 @@ OFCondition DSRNumericMeasurementValue::writeXML(STD_NAMESPACE ostream &stream,
 }
 
 
-OFCondition DSRNumericMeasurementValue::readItem(DcmItem &dataset,
-                                                 const size_t flags)
+OFCondition DSRNumericMeasurementValue::readItem(DcmItem &dataset)
 {
-    const OFBool acceptViolation = (flags & DSRTypes::RF_acceptInvalidContentItemValue) > 0;
     /* read NumericValue */
-    OFCondition result = DSRTypes::getAndCheckStringValueFromDataset(dataset, DCM_NumericValue, NumericValue, "1", "1", "MeasuredValueSequence", acceptViolation);
+    OFCondition result = DSRTypes::getAndCheckStringValueFromDataset(dataset, DCM_NumericValue, NumericValue, "1", "1", "MeasuredValueSequence");
     if (result.good())
     {
         /* read some optional attributes */
@@ -276,7 +246,7 @@ OFCondition DSRNumericMeasurementValue::readItem(DcmItem &dataset,
         if (DSRTypes::getAndCheckElementFromDataset(dataset, RationalNumeratorValue, "1", "1C", "MeasuredValueSequence").good())
             DSRTypes::getAndCheckElementFromDataset(dataset, RationalDenominatorValue, "1", "1" /* was 1C */, "MeasuredValueSequence");
         /* read MeasurementUnitsCodeSequence */
-        result = MeasurementUnit.readSequence(dataset, DCM_MeasurementUnitsCodeSequence, "1" /*type*/, flags);
+        result = MeasurementUnit.readSequence(dataset, DCM_MeasurementUnitsCodeSequence, "1" /*type*/);
     }
     return result;
 }
@@ -297,8 +267,7 @@ OFCondition DSRNumericMeasurementValue::writeItem(DcmItem &dataset) const
 }
 
 
-OFCondition DSRNumericMeasurementValue::readSequence(DcmItem &dataset,
-                                                     const size_t flags)
+OFCondition DSRNumericMeasurementValue::readSequence(DcmItem &dataset)
 {
     /* read MeasuredValueSequence */
     DcmSequenceOfItems *dseq = NULL;
@@ -312,7 +281,7 @@ OFCondition DSRNumericMeasurementValue::readSequence(DcmItem &dataset,
             /* read first item */
             DcmItem *ditem = dseq->getItem(0);
             if (ditem != NULL)
-                result = readItem(*ditem, flags);
+                result = readItem(*ditem);
             else
                 result = SR_EC_InvalidDocumentTree;
         }
@@ -320,7 +289,7 @@ OFCondition DSRNumericMeasurementValue::readSequence(DcmItem &dataset,
     if (result.good())
     {
         /* read NumericValueQualifierCodeSequence (optional) */
-        ValueQualifier.readSequence(dataset, DCM_NumericValueQualifierCodeSequence, "3" /*type*/, flags);
+        ValueQualifier.readSequence(dataset, DCM_NumericValueQualifierCodeSequence, "3" /*type*/);
     }
     return result;
 }
@@ -493,18 +462,28 @@ OFCondition DSRNumericMeasurementValue::setValue(const OFString &numericValue,
                                                  const DSRCodedEntryValue &measurementUnit,
                                                  const OFBool check)
 {
-    const DSRCodedEntryValue valueQualifier;
-    /* call the function doing the real work */
-    return setValue(numericValue, measurementUnit, valueQualifier, check);
-}
-
-
-OFCondition DSRNumericMeasurementValue::setValue(const DSRCodedEntryValue &valueQualifier,
-                                                 const OFBool check)
-{
-    const DSRCodedEntryValue measurementUnit;
-    /* call the function doing the real work */
-    return setValue("" /*numericValue*/, measurementUnit, valueQualifier, check);
+    OFCondition result = EC_Normal;
+    if (check)
+    {
+        /* check whether the passed values are valid */
+        result = checkNumericValue(numericValue);
+        if (result.good())
+            result = checkMeasurementUnit(measurementUnit);
+    } else {
+        /* make sure that the mandatory values are non-empty */
+        if (measurementUnit.isEmpty())
+            result = EC_IllegalParameter;
+    }
+    if (result.good())
+    {
+        NumericValue = numericValue;
+        MeasurementUnit = measurementUnit;
+        /* clear additional representations */
+        FloatingPointValue.clear();
+        RationalNumeratorValue.clear();
+        RationalDenominatorValue.clear();
+    }
+    return result;
 }
 
 
@@ -516,19 +495,15 @@ OFCondition DSRNumericMeasurementValue::setValue(const OFString &numericValue,
     OFCondition result = EC_Normal;
     if (check)
     {
-        /* only check if at least one of the two values is non-empty */
-        if (!numericValue.empty() || !measurementUnit.isEmpty())
-        {
-            /* check whether the passed values are valid */
-            result = checkNumericValue(numericValue);
-            if (result.good())
-                result = checkMeasurementUnit(measurementUnit);
-        }
+        /* check whether the passed values are valid */
+        result = checkNumericValue(numericValue);
+        if (result.good())
+            result = checkMeasurementUnit(measurementUnit);
         if (result.good())
             result = checkNumericValueQualifier(valueQualifier);
     } else {
-        /* make sure that both values are either empty or non-empty */
-        if (numericValue.empty() != measurementUnit.isEmpty())
+        /* make sure that the mandatory values are non-empty */
+        if (numericValue.empty() || measurementUnit.isEmpty())
             result = EC_IllegalParameter;
     }
     if (result.good())
@@ -570,39 +545,6 @@ OFCondition DSRNumericMeasurementValue::setNumericValue(const OFString &numericV
 }
 
 
-OFCondition DSRNumericMeasurementValue::setNumericValue(const DcmElement &delem,
-                                                        const unsigned long pos,
-                                                        const OFBool check)
-{
-    OFString numericValue;
-    /* first, get the value from the element (need to cast away "const") */
-    OFCondition result = OFconst_cast(DcmElement &, delem).getOFString(numericValue, pos);
-    if (result.good())
-    {
-        /* then, check and set the value */
-        result = setNumericValue(numericValue, check);
-    }
-    return result;
-}
-
-
-OFCondition DSRNumericMeasurementValue::setNumericValue(DcmItem &dataset,
-                                                        const DcmTagKey &tagKey,
-                                                        const unsigned long pos,
-                                                        const OFBool check)
-{
-    OFString numericValue;
-    /* first, get the element value from the dataset */
-    OFCondition result = DSRTypes::getStringValueFromDataset(dataset, tagKey, numericValue, pos);
-    if (result.good())
-    {
-        /* then, check and set the value */
-        result = setNumericValue(numericValue, check);
-    }
-    return result;
-}
-
-
 OFCondition DSRNumericMeasurementValue::setMeasurementUnit(const DSRCodedEntryValue &measurementUnit,
                                                            const OFBool check)
 {
@@ -676,7 +618,7 @@ void DSRNumericMeasurementValue::removeRationalRepresentation()
 
 OFCondition DSRNumericMeasurementValue::checkNumericValue(const OFString &numericValue) const
 {
-    /* numeric value should never be empty */
+    /* numeric measurement value should never be empty */
     return numericValue.empty() ? SR_EC_InvalidValue
                                 : DcmDecimalString::checkStringValue(numericValue, "1");
 }
@@ -726,13 +668,3 @@ OFCondition DSRNumericMeasurementValue::checkCurrentValue() const
     }
     return result;
 }
-
-
-// output operators
-
-STD_NAMESPACE ostream &operator<<(STD_NAMESPACE ostream &stream,
-                                  const DSRNumericMeasurementValue &numericMeasurement)
-{
-    numericMeasurement.print(stream, 0 /*flags*/);
-    return stream;
-}
