@@ -1,6 +1,6 @@
 /*
  *
- *  Copyright (C) 2000-2015, OFFIS e.V.
+ *  Copyright (C) 2000-2013, OFFIS e.V.
  *  All rights reserved.  See COPYRIGHT file for details.
  *
  *  This software and supporting documentation were developed by
@@ -11,9 +11,9 @@
  *    D-26121 Oldenburg, Germany
  *
  *
- *  Module: dcmsr
+ *  Module:  dcmsr
  *
- *  Author: Joerg Riesmeier
+ *  Author:  Joerg Riesmeier
  *
  *  Purpose:
  *    classes: DSRPNameTreeNode
@@ -44,24 +44,11 @@ DSRPNameTreeNode::DSRPNameTreeNode(const E_RelationshipType relationshipType,
 }
 
 
-DSRPNameTreeNode::DSRPNameTreeNode(const DSRPNameTreeNode &node)
-  : DSRDocumentTreeNode(node),
-    DSRStringValue(node)
-{
-}
-
-
 DSRPNameTreeNode::~DSRPNameTreeNode()
 {
 }
 
 
-DSRPNameTreeNode *DSRPNameTreeNode::clone() const
-{
-    return new DSRPNameTreeNode(*this);
-}
-
-
 void DSRPNameTreeNode::clear()
 {
     DSRDocumentTreeNode::clear();
@@ -72,13 +59,7 @@ void DSRPNameTreeNode::clear()
 OFBool DSRPNameTreeNode::isValid() const
 {
     /* ConceptNameCodeSequence required */
-    return DSRDocumentTreeNode::isValid() && getConceptName().isValid() && hasValidValue();
-}
-
-
-OFBool DSRPNameTreeNode::hasValidValue() const
-{
-    return checkCurrentValue().good();
+    return DSRDocumentTreeNode::isValid() && getConceptName().isValid() && checkCurrentValue().good();;
 }
 
 
@@ -113,11 +94,10 @@ OFCondition DSRPNameTreeNode::writeXML(STD_NAMESPACE ostream &stream,
 }
 
 
-OFCondition DSRPNameTreeNode::readContentItem(DcmItem &dataset,
-                                              const size_t flags)
+OFCondition DSRPNameTreeNode::readContentItem(DcmItem &dataset)
 {
     /* read PName */
-    return DSRStringValue::read(dataset, DCM_PersonName, flags);
+    return DSRStringValue::read(dataset, DCM_PersonName);
 }
 
 
@@ -129,8 +109,7 @@ OFCondition DSRPNameTreeNode::writeContentItem(DcmItem &dataset) const
 
 
 OFCondition DSRPNameTreeNode::readXMLContentItem(const DSRXMLDocument &doc,
-                                                 DSRXMLCursor cursor,
-                                                 const size_t /*flags*/)
+                                                 DSRXMLCursor cursor)
 {
     OFCondition result = SR_EC_CorruptedXMLStructure;
     if (cursor.valid())
