@@ -1,6 +1,6 @@
 /*
  *
- *  Copyright (C) 2010-2015, OFFIS e.V.
+ *  Copyright (C) 2010-2012, OFFIS e.V.
  *  All rights reserved.  See COPYRIGHT file for details.
  *
  *  This software and supporting documentation were developed by
@@ -11,9 +11,9 @@
  *    D-26121 Oldenburg, Germany
  *
  *
- *  Module: dcmsr
+ *  Module:  dcmsr
  *
- *  Author: Joerg Riesmeier
+ *  Author:  Joerg Riesmeier
  *
  *  Purpose:
  *    classes: DSRGraphicData3DList
@@ -92,8 +92,7 @@ OFCondition DSRGraphicData3DList::print(STD_NAMESPACE ostream &stream,
 }
 
 
-OFCondition DSRGraphicData3DList::read(DcmItem &dataset,
-                                       const size_t /*flags*/)
+OFCondition DSRGraphicData3DList::read(DcmItem &dataset)
 {
     /* get floating point string from dataset */
     DcmFloatingPointSingle delem(DCM_GraphicData);
