@@ -1,6 +1,6 @@
 /*
  *
- *  Copyright (C) 2002-2015, OFFIS e.V.
+ *  Copyright (C) 2002-2013, OFFIS e.V.
  *  All rights reserved.  See COPYRIGHT file for details.
  *
  *  This software and supporting documentation were developed by
@@ -11,9 +11,9 @@
  *    D-26121 Oldenburg, Germany
  *
  *
- *  Module: dcmsr
+ *  Module:  dcmsr
  *
- *  Author: Joerg Riesmeier
+ *  Author:  Joerg Riesmeier
  *
  *  Purpose:
  *    classes: DSRSOPInstanceReferenceList
@@ -83,8 +83,7 @@ size_t DSRSOPInstanceReferenceList::SeriesStruct::getNumberOfInstances() const
 }
 
 
-OFCondition DSRSOPInstanceReferenceList::SeriesStruct::read(DcmItem &dataset,
-                                                            const size_t flags)
+OFCondition DSRSOPInstanceReferenceList::SeriesStruct::read(DcmItem &dataset)
 {
     /* first, read optional attributes on series level */
     getAndCheckStringValueFromDataset(dataset, DCM_RetrieveAETitle, RetrieveAETitle, "1-n", "3", "ReferencedSeriesSequence");
@@ -120,7 +119,7 @@ OFCondition DSRSOPInstanceReferenceList::SeriesStruct::read(DcmItem &dataset,
                         /* set cursor to new position */
                         Iterator = --InstanceList.end();
                         /* read additional information */
-                        instance->PurposeOfReference.readSequence(*item, DCM_PurposeOfReferenceCodeSequence, "3", flags);
+                        instance->PurposeOfReference.readSequence(*item, DCM_PurposeOfReferenceCodeSequence, "3");
                     } else {
                         result = EC_MemoryExhausted;
                         break;
@@ -178,8 +177,7 @@ OFCondition DSRSOPInstanceReferenceList::SeriesStruct::write(DcmItem &dataset) c
 
 
 OFCondition DSRSOPInstanceReferenceList::SeriesStruct::readXML(const DSRXMLDocument &doc,
-                                                               DSRXMLCursor cursor,
-                                                               const size_t flags)
+                                                               DSRXMLCursor cursor)
 {
     OFCondition result = SR_EC_InvalidDocument;
     if (cursor.valid())
@@ -223,7 +221,7 @@ OFCondition DSRSOPInstanceReferenceList::SeriesStruct::readXML(const DSRXMLDocum
                             {
                                 /* check for known element tags */
                                 if (doc.matchNode(instanceCursor, "purpose"))
-                                    instance->PurposeOfReference.readXML(doc, instanceCursor, flags);
+                                    instance->PurposeOfReference.readXML(doc, instanceCursor);
                                 /* proceed with next node */
                                 instanceCursor.gotoNext();
                             }
@@ -445,8 +443,7 @@ size_t DSRSOPInstanceReferenceList::StudyStruct::getNumberOfInstances() const
 }
 
 
-OFCondition DSRSOPInstanceReferenceList::StudyStruct::read(DcmItem &dataset,
-                                                           const size_t flags)
+OFCondition DSRSOPInstanceReferenceList::StudyStruct::read(DcmItem &dataset)
 {
     /* first, check whether sequence is present and non-empty */
     DcmSequenceOfItems *sequence = NULL;
@@ -484,7 +481,7 @@ OFCondition DSRSOPInstanceReferenceList::StudyStruct::read(DcmItem &dataset,
                     /* set cursor to new position */
                     Iterator = --SeriesList.end();
                     /* read further attributes on series level and the instance level */
-                    result = series->read(*item, flags);
+                    result = series->read(*item);
                 }
             }
         }
@@ -521,8 +518,7 @@ OFCondition DSRSOPInstanceReferenceList::StudyStruct::write(DcmItem &dataset) co
 
 
 OFCondition DSRSOPInstanceReferenceList::StudyStruct::readXML(const DSRXMLDocument &doc,
-                                                              DSRXMLCursor cursor,
-                                                              const size_t flags)
+                                                              DSRXMLCursor cursor)
 {
     OFCondition result = SR_EC_InvalidDocument;
     if (cursor.valid())
@@ -556,7 +552,7 @@ OFCondition DSRSOPInstanceReferenceList::StudyStruct::readXML(const DSRXMLDocume
                         /* set cursor to new position */
                         Iterator = --SeriesList.end();
                         /* read further attributes on series level and the instance level */
-                        result = series->readXML(doc, cursor.getChild(), flags);
+                        result = series->readXML(doc, cursor.getChild());
                     }
                 }
             }
@@ -820,8 +816,7 @@ size_t DSRSOPInstanceReferenceList::getNumberOfInstances() const
 }
 
 
-OFCondition DSRSOPInstanceReferenceList::read(DcmItem &dataset,
-                                              const size_t flags)
+OFCondition DSRSOPInstanceReferenceList::read(DcmItem &dataset)
 {
     /* first, check whether sequence is present and non-empty */
     DcmSequenceOfItems *sequence = NULL;
@@ -860,7 +855,7 @@ OFCondition DSRSOPInstanceReferenceList::read(DcmItem &dataset,
                     /* set cursor to new position */
                     Iterator = --StudyList.end();
                     /* read attributes on series and instance level */
-                    result = study->read(*item, flags);
+                    result = study->read(*item);
                 }
             }
         }
@@ -898,7 +893,7 @@ OFCondition DSRSOPInstanceReferenceList::write(DcmItem &dataset) const
 
 OFCondition DSRSOPInstanceReferenceList::readXML(const DSRXMLDocument &doc,
                                                  DSRXMLCursor cursor,
-                                                 const size_t flags)
+                                                 const size_t /*flags*/)
 {
     /* default: no error, e.g. for empty list of references */
     OFCondition result = EC_Normal;
@@ -933,7 +928,7 @@ OFCondition DSRSOPInstanceReferenceList::readXML(const DSRXMLDocument &doc,
                         /* set cursor to new position */
                         Iterator = --StudyList.end();
                         /* read attributes on series and instance level */
-                        result = study->readXML(doc, cursor.getChild(), flags);
+                        result = study->readXML(doc, cursor.getChild());
                     }
                 }
             }
@@ -1037,10 +1032,10 @@ OFCondition DSRSOPInstanceReferenceList::addItem(DcmItem &dataset,
 {
     OFString studyUID, seriesUID, sopClassUID, instanceUID;
     /* retrieve element values from dataset */
-    getStringValueFromDataset(dataset, DCM_StudyInstanceUID, studyUID);
-    getStringValueFromDataset(dataset, DCM_SeriesInstanceUID, seriesUID);
-    getStringValueFromDataset(dataset, DCM_SOPClassUID, sopClassUID);
-    getStringValueFromDataset(dataset, DCM_SOPInstanceUID, instanceUID);
+    dataset.findAndGetOFString(DCM_StudyInstanceUID, studyUID);
+    dataset.findAndGetOFString(DCM_SeriesInstanceUID, seriesUID);
+    dataset.findAndGetOFString(DCM_SOPClassUID, sopClassUID);
+    dataset.findAndGetOFString(DCM_SOPInstanceUID, instanceUID);
     /* add new item to the list of references (if valid) */
     return addItem(studyUID, seriesUID, sopClassUID, instanceUID, check);
 }
