@@ -1,6 +1,6 @@
 /*
  *
- *  Copyright (C) 2000-2015, OFFIS e.V.
+ *  Copyright (C) 2000-2012, OFFIS e.V.
  *  All rights reserved.  See COPYRIGHT file for details.
  *
  *  This software and supporting documentation were developed by
@@ -11,9 +11,9 @@
  *    D-26121 Oldenburg, Germany
  *
  *
- *  Module: dcmsr
+ *  Module:  dcmsr
  *
- *  Author: Joerg Riesmeier
+ *  Author:  Joerg Riesmeier
  *
  *  Purpose:
  *    classes: DSRStringValue
@@ -86,12 +86,10 @@ void DSRStringValue::print(STD_NAMESPACE ostream &stream,
 
 
 OFCondition DSRStringValue::read(DcmItem &dataset,
-                                 const DcmTagKey &tagKey,
-                                 const size_t flags)
+                                 const DcmTagKey &tagKey)
 {
-    const OFBool acceptViolation = (flags & DSRTypes::RF_acceptInvalidContentItemValue) > 0;
     /* read value */
-    return DSRTypes::getAndCheckStringValueFromDataset(dataset, tagKey, Value, "1", "1", "content item", acceptViolation);
+    return DSRTypes::getAndCheckStringValueFromDataset(dataset, tagKey, Value, "1", "1", "content item");
 }
 
 
@@ -105,7 +103,6 @@ OFCondition DSRStringValue::write(DcmItem &dataset,
 
 OFCondition DSRStringValue::readXML(const DSRXMLDocument &doc,
                                     DSRXMLCursor cursor,
-                                    const size_t /*flags*/,
                                     const OFBool encoding)
 {
     OFCondition result = SR_EC_CorruptedXMLStructure;
@@ -163,39 +160,6 @@ OFCondition DSRStringValue::setValue(const OFString &stringValue,
 }
 
 
-OFCondition DSRStringValue::setValue(const DcmElement &delem,
-                                     const unsigned long pos,
-                                     const OFBool check)
-{
-    OFString stringValue;
-    /* first, get the value from the element (need to cast away "const") */
-    OFCondition result = OFconst_cast(DcmElement &, delem).getOFString(stringValue, pos);
-    if (result.good())
-    {
-        /* then, check and set the value */
-        result = setValue(stringValue, check);
-    }
-    return result;
-}
-
-
-OFCondition DSRStringValue::setValue(DcmItem &dataset,
-                                     const DcmTagKey &tagKey,
-                                     const unsigned long pos,
-                                     const OFBool check)
-{
-    OFString stringValue;
-    /* first, get the element value from the dataset */
-    OFCondition result = DSRTypes::getStringValueFromDataset(dataset, tagKey, stringValue, pos);
-    if (result.good())
-    {
-        /* then, check and set the value */
-        result = setValue(stringValue, check);
-    }
-    return result;
-}
-
-
 OFCondition DSRStringValue::checkValue(const OFString &stringValue) const
 {
     /* all corresponding DICOM attributes are type 1, i.e. mandatory */
