@@ -1,6 +1,6 @@
 /*
  *
- *  Copyright (C) 2000-2015, OFFIS e.V.
+ *  Copyright (C) 2000-2012, OFFIS e.V.
  *  All rights reserved.  See COPYRIGHT file for details.
  *
  *  This software and supporting documentation were developed by
@@ -11,9 +11,9 @@
  *    D-26121 Oldenburg, Germany
  *
  *
- *  Module: dcmsr
+ *  Module:  dcmsr
  *
- *  Author: Joerg Riesmeier
+ *  Author:  Joerg Riesmeier
  *
  *  Purpose:
  *    classes: DSRReferencedSamplePositionList
@@ -87,8 +87,7 @@ OFCondition DSRReferencedSamplePositionList::print(STD_NAMESPACE ostream &stream
 }
 
 
-OFCondition DSRReferencedSamplePositionList::read(DcmItem &dataset,
-                                                  const size_t /*flags*/)
+OFCondition DSRReferencedSamplePositionList::read(DcmItem &dataset)
 {
     /* get element from dataset */
     DcmUnsignedLong delem(DCM_ReferencedSamplePositions);
