@@ -1,6 +1,6 @@
 /*
  *
- *  Copyright (C) 2000-2016, OFFIS e.V.
+ *  Copyright (C) 2000-2012, OFFIS e.V.
  *  All rights reserved.  See COPYRIGHT file for details.
  *
  *  This software and supporting documentation were developed by
@@ -11,9 +11,9 @@
  *    D-26121 Oldenburg, Germany
  *
  *
- *  Module: dcmsr
+ *  Module:  dcmsr
  *
- *  Author: Joerg Riesmeier
+ *  Author:  Joerg Riesmeier
  *
  *  Purpose:
  *    classes: DSRReferencedTimeOffsetList
@@ -29,8 +29,14 @@
 #define INCLUDE_CSTDIO
 #include "dcmtk/ofstd/ofstdinc.h"
 
+#ifdef HAVE_EXPLICIT_TEMPLATE_SPECIALIZATION
+#define EXPLICIT_SPECIALIZATION template<>
+#else
+#define EXPLICIT_SPECIALIZATION
+#endif
+
 /* declared in class DSRListOfItems<T> */
-DCMTK_EXPLICIT_SPECIALIZATION const Float64 DSRListOfItems<Float64>::EmptyItem = 0;
+EXPLICIT_SPECIALIZATION const Float64 DSRListOfItems<Float64>::EmptyItem = 0;
 
 
 DSRReferencedTimeOffsetList::DSRReferencedTimeOffsetList()
@@ -85,8 +91,7 @@ OFCondition DSRReferencedTimeOffsetList::print(STD_NAMESPACE ostream &stream,
 }
 
 
-OFCondition DSRReferencedTimeOffsetList::read(DcmItem &dataset,
-                                              const size_t /*flags*/)
+OFCondition DSRReferencedTimeOffsetList::read(DcmItem &dataset)
 {
     /* get decimal string from dataset */
     DcmDecimalString delem(DCM_ReferencedTimeOffsets);
