@@ -1,6 +1,6 @@
 /*
  *
- *  Copyright (C) 2000-2015, OFFIS e.V.
+ *  Copyright (C) 2000-2013, OFFIS e.V.
  *  All rights reserved.  See COPYRIGHT file for details.
  *
  *  This software and supporting documentation were developed by
@@ -11,9 +11,9 @@
  *    D-26121 Oldenburg, Germany
  *
  *
- *  Module: dcmsr
+ *  Module:  dcmsr
  *
- *  Author: Joerg Riesmeier
+ *  Author:  Joerg Riesmeier
  *
  *  Purpose:
  *    classes: DSRTemporalCoordinatesValue
@@ -111,8 +111,7 @@ OFCondition DSRTemporalCoordinatesValue::print(STD_NAMESPACE ostream &stream,
 
 
 OFCondition DSRTemporalCoordinatesValue::readXML(const DSRXMLDocument &doc,
-                                                 DSRXMLCursor cursor,
-                                                 const size_t /*flags*/)
+                                                 DSRXMLCursor cursor)
 {
     OFCondition result = SR_EC_CorruptedXMLStructure;
     if (cursor.valid())
@@ -177,8 +176,7 @@ OFCondition DSRTemporalCoordinatesValue::writeXML(STD_NAMESPACE ostream &stream,
 }
 
 
-OFCondition DSRTemporalCoordinatesValue::read(DcmItem &dataset,
-                                              const size_t flags)
+OFCondition DSRTemporalCoordinatesValue::read(DcmItem &dataset)
 {
     /* read TemporalRangeType */
     OFString tmpString;
@@ -190,9 +188,9 @@ OFCondition DSRTemporalCoordinatesValue::read(DcmItem &dataset,
         if (TemporalRangeType == DSRTypes::TRT_invalid)
             DSRTypes::printUnknownValueWarningMessage("TemporalRangeType", tmpString.c_str());
         /* first read data (all three lists) */
-        SamplePositionList.read(dataset, flags);
-        TimeOffsetList.read(dataset, flags);
-        DateTimeList.read(dataset, flags);
+        SamplePositionList.read(dataset);
+        TimeOffsetList.read(dataset);
+        DateTimeList.read(dataset);
         /* then check data and report warnings if any */
         checkData(TemporalRangeType, SamplePositionList, TimeOffsetList, DateTimeList, OFTrue /*reportWarnings*/);
     }
