@@ -1,6 +1,6 @@
 /*
  *
- *  Copyright (C) 2000-2015, OFFIS e.V.
+ *  Copyright (C) 2000-2013, OFFIS e.V.
  *  All rights reserved.  See COPYRIGHT file for details.
  *
  *  This software and supporting documentation were developed by
@@ -11,9 +11,9 @@
  *    D-26121 Oldenburg, Germany
  *
  *
- *  Module: dcmsr
+ *  Module:  dcmsr
  *
- *  Author: Joerg Riesmeier
+ *  Author:  Joerg Riesmeier
  *
  *  Purpose:
  *    classes: DSRTextTreeNode
@@ -45,24 +45,11 @@ DSRTextTreeNode::DSRTextTreeNode(const E_RelationshipType relationshipType,
 }
 
 
-DSRTextTreeNode::DSRTextTreeNode(const DSRTextTreeNode &node)
-  : DSRDocumentTreeNode(node),
-    DSRStringValue(node)
-{
-}
-
-
 DSRTextTreeNode::~DSRTextTreeNode()
 {
 }
 
 
-DSRTextTreeNode *DSRTextTreeNode::clone() const
-{
-    return new DSRTextTreeNode(*this);
-}
-
-
 void DSRTextTreeNode::clear()
 {
     DSRDocumentTreeNode::clear();
@@ -73,13 +60,7 @@ void DSRTextTreeNode::clear()
 OFBool DSRTextTreeNode::isValid() const
 {
     /* ConceptNameCodeSequence required */
-    return DSRDocumentTreeNode::isValid() && getConceptName().isValid() && hasValidValue();
-}
-
-
-OFBool DSRTextTreeNode::hasValidValue() const
-{
-    return checkCurrentValue().good();
+    return DSRDocumentTreeNode::isValid() && getConceptName().isValid() && checkCurrentValue().good();
 }
 
 
@@ -119,11 +100,10 @@ OFCondition DSRTextTreeNode::writeXML(STD_NAMESPACE ostream &stream,
 }
 
 
-OFCondition DSRTextTreeNode::readContentItem(DcmItem &dataset,
-                                             const size_t flags)
+OFCondition DSRTextTreeNode::readContentItem(DcmItem &dataset)
 {
     /* read TextValue */
-    return DSRStringValue::read(dataset, DCM_TextValue, flags);
+    return DSRStringValue::read(dataset, DCM_TextValue);
 }
 
 
@@ -135,11 +115,10 @@ OFCondition DSRTextTreeNode::writeContentItem(DcmItem &dataset) const
 
 
 OFCondition DSRTextTreeNode::readXMLContentItem(const DSRXMLDocument &doc,
-                                                DSRXMLCursor cursor,
-                                                const size_t flags)
+                                                DSRXMLCursor cursor)
 {
     /* retrieve value from XML element "value" */
-    return DSRStringValue::readXML(doc, doc.getNamedNode(cursor.gotoChild(), "value"), flags, OFTrue /*encoding*/);
+    return DSRStringValue::readXML(doc, doc.getNamedNode(cursor.gotoChild(), "value"), OFTrue /*encoding*/);
 }
 
 
