@@ -1,6 +1,6 @@
 /*
  *
- *  Copyright (C) 2000-2015, OFFIS e.V.
+ *  Copyright (C) 2000-2012, OFFIS e.V.
  *  All rights reserved.  See COPYRIGHT file for details.
  *
  *  This software and supporting documentation were developed by
@@ -11,9 +11,9 @@
  *    D-26121 Oldenburg, Germany
  *
  *
- *  Module: dcmsr
+ *  Module:  dcmsr
  *
- *  Author: Joerg Riesmeier
+ *  Author:  Joerg Riesmeier
  *
  *  Purpose:
  *    classes: DSRTimeTreeNode
@@ -44,24 +44,11 @@ DSRTimeTreeNode::DSRTimeTreeNode(const E_RelationshipType relationshipType,
 }
 
 
-DSRTimeTreeNode::DSRTimeTreeNode(const DSRTimeTreeNode &node)
-  : DSRDocumentTreeNode(node),
-    DSRStringValue(node)
-{
-}
-
-
 DSRTimeTreeNode::~DSRTimeTreeNode()
 {
 }
 
 
-DSRTimeTreeNode *DSRTimeTreeNode::clone() const
-{
-    return new DSRTimeTreeNode(*this);
-}
-
-
 void DSRTimeTreeNode::clear()
 {
     DSRDocumentTreeNode::clear();
@@ -72,13 +59,7 @@ void DSRTimeTreeNode::clear()
 OFBool DSRTimeTreeNode::isValid() const
 {
     /* ConceptNameCodeSequence required */
-    return DSRDocumentTreeNode::isValid() && getConceptName().isValid() && hasValidValue();
-}
-
-
-OFBool DSRTimeTreeNode::hasValidValue() const
-{
-    return checkCurrentValue().good();
+    return DSRDocumentTreeNode::isValid() && getConceptName().isValid() && checkCurrentValue().good();
 }
 
 
@@ -112,11 +93,10 @@ OFCondition DSRTimeTreeNode::writeXML(STD_NAMESPACE ostream &stream,
 }
 
 
-OFCondition DSRTimeTreeNode::readContentItem(DcmItem &dataset,
-                                             const size_t flags)
+OFCondition DSRTimeTreeNode::readContentItem(DcmItem &dataset)
 {
     /* read Time */
-    return DSRStringValue::read(dataset, DCM_Time, flags);
+    return DSRStringValue::read(dataset, DCM_Time);
 }
 
 
@@ -128,8 +108,7 @@ OFCondition DSRTimeTreeNode::writeContentItem(DcmItem &dataset) const
 
 
 OFCondition DSRTimeTreeNode::readXMLContentItem(const DSRXMLDocument &doc,
-                                                DSRXMLCursor cursor,
-                                                const size_t /*flags*/)
+                                                DSRXMLCursor cursor)
 {
     OFString tmpString;
     /* retrieve value from XML element "value" */
