@@ -1,6 +1,6 @@
 /*
  *
- *  Copyright (C) 2000-2015, OFFIS e.V.
+ *  Copyright (C) 2000-2012, OFFIS e.V.
  *  All rights reserved.  See COPYRIGHT file for details.
  *
  *  This software and supporting documentation were developed by
@@ -11,9 +11,9 @@
  *    D-26121 Oldenburg, Germany
  *
  *
- *  Module: dcmsr
+ *  Module:  dcmsr
  *
- *  Author: Joerg Riesmeier
+ *  Author:  Joerg Riesmeier
  *
  *  Purpose:
  *    classes: DSRUIDRefTreeNode
@@ -44,24 +44,11 @@ DSRUIDRefTreeNode::DSRUIDRefTreeNode(const E_RelationshipType relationshipType,
 }
 
 
-DSRUIDRefTreeNode::DSRUIDRefTreeNode(const DSRUIDRefTreeNode &node)
-  : DSRDocumentTreeNode(node),
-    DSRStringValue(node)
-{
-}
-
-
 DSRUIDRefTreeNode::~DSRUIDRefTreeNode()
 {
 }
 
 
-DSRUIDRefTreeNode *DSRUIDRefTreeNode::clone() const
-{
-    return new DSRUIDRefTreeNode(*this);
-}
-
-
 void DSRUIDRefTreeNode::clear()
 {
     DSRDocumentTreeNode::clear();
@@ -72,13 +59,7 @@ void DSRUIDRefTreeNode::clear()
 OFBool DSRUIDRefTreeNode::isValid() const
 {
     /* ConceptNameCodeSequence required */
-    return DSRDocumentTreeNode::isValid() && getConceptName().isValid() && hasValidValue();
-}
-
-
-OFBool DSRUIDRefTreeNode::hasValidValue() const
-{
-    return checkCurrentValue().good();
+    return DSRDocumentTreeNode::isValid() && getConceptName().isValid() && checkCurrentValue().good();
 }
 
 
@@ -109,11 +90,10 @@ OFCondition DSRUIDRefTreeNode::writeXML(STD_NAMESPACE ostream &stream,
 }
 
 
-OFCondition DSRUIDRefTreeNode::readContentItem(DcmItem &dataset,
-                                               const size_t flags)
+OFCondition DSRUIDRefTreeNode::readContentItem(DcmItem &dataset)
 {
     /* read UID */
-    return DSRStringValue::read(dataset, DCM_UID, flags);
+    return DSRStringValue::read(dataset, DCM_UID);
 }
 
 
@@ -125,11 +105,10 @@ OFCondition DSRUIDRefTreeNode::writeContentItem(DcmItem &dataset) const
 
 
 OFCondition DSRUIDRefTreeNode::readXMLContentItem(const DSRXMLDocument &doc,
-                                                  DSRXMLCursor cursor,
-                                                  const size_t flags)
+                                                  DSRXMLCursor cursor)
 {
     /* retrieve value from XML element "value" */
-    return DSRStringValue::readXML(doc, doc.getNamedNode(cursor.gotoChild(), "value"), flags, OFFalse /*encoding*/);
+    return DSRStringValue::readXML(doc, doc.getNamedNode(cursor.gotoChild(), "value"));
 }
 
 
