@@ -1,6 +1,6 @@
 /*
  *
- *  Copyright (C) 2000-2015, OFFIS e.V.
+ *  Copyright (C) 2000-2012, OFFIS e.V.
  *  All rights reserved.  See COPYRIGHT file for details.
  *
  *  This software and supporting documentation were developed by
@@ -11,9 +11,9 @@
  *    D-26121 Oldenburg, Germany
  *
  *
- *  Module: dcmsr
+ *  Module:  dcmsr
  *
- *  Author: Joerg Riesmeier
+ *  Author:  Joerg Riesmeier
  *
  *  Purpose:
  *    classes: DSRWaveformChannelList
@@ -88,8 +88,7 @@ OFCondition DSRWaveformChannelList::print(STD_NAMESPACE ostream &stream,
 }
 
 
-OFCondition DSRWaveformChannelList::read(DcmItem &dataset,
-                                         const size_t /*flags*/)
+OFCondition DSRWaveformChannelList::read(DcmItem &dataset)
 {
     /* get integer array from dataset */
     DcmUnsignedShort delem(DCM_ReferencedWaveformChannels);
