@@ -1,6 +1,6 @@
 /*
  *
- *  Copyright (C) 2000-2015, OFFIS e.V.
+ *  Copyright (C) 2000-2013, OFFIS e.V.
  *  All rights reserved.  See COPYRIGHT file for details.
  *
  *  This software and supporting documentation were developed by
@@ -11,9 +11,9 @@
  *    D-26121 Oldenburg, Germany
  *
  *
- *  Module: dcmsr
+ *  Module:  dcmsr
  *
- *  Author: Joerg Riesmeier
+ *  Author:  Joerg Riesmeier
  *
  *  Purpose:
  *    classes: DSRWaveformReferenceValue
@@ -109,11 +109,10 @@ OFCondition DSRWaveformReferenceValue::print(STD_NAMESPACE ostream &stream,
 
 
 OFCondition DSRWaveformReferenceValue::readXML(const DSRXMLDocument &doc,
-                                               DSRXMLCursor cursor,
-                                               const size_t flags)
+                                               DSRXMLCursor cursor)
 {
     /* first read general composite reference information */
-    OFCondition result = DSRCompositeReferenceValue::readXML(doc, cursor, flags);
+    OFCondition result = DSRCompositeReferenceValue::readXML(doc, cursor);
     /* then read waveform related XML tags */
     if (result.good())
     {
@@ -144,14 +143,13 @@ OFCondition DSRWaveformReferenceValue::writeXML(STD_NAMESPACE ostream &stream,
 }
 
 
-OFCondition DSRWaveformReferenceValue::readItem(DcmItem &dataset,
-                                                const size_t flags)
+OFCondition DSRWaveformReferenceValue::readItem(DcmItem &dataset)
 {
     /* read ReferencedSOPClassUID and ReferencedSOPInstanceUID */
-    OFCondition result = DSRCompositeReferenceValue::readItem(dataset, flags);
+    OFCondition result = DSRCompositeReferenceValue::readItem(dataset);
     /* read ReferencedWaveformChannels (conditional) */
     if (result.good())
-        ChannelList.read(dataset, flags);
+        ChannelList.read(dataset);
     return result;
 }
 
@@ -245,7 +243,7 @@ OFCondition DSRWaveformReferenceValue::checkSOPClassUID(const OFString &sopClass
     OFCondition result = DSRCompositeReferenceValue::checkSOPClassUID(sopClassUID);
     if (result.good())
     {
-        /* check for all valid/known SOP classes (according to DICOM PS 3.6-2014a) */
+        /* check for all valid/known SOP classes (according to DICOM PS 3.6-2011) */
         if ((sopClassUID != UID_TwelveLeadECGWaveformStorage) &&
             (sopClassUID != UID_GeneralECGWaveformStorage) &&
             (sopClassUID != UID_AmbulatoryECGWaveformStorage) &&
