@@ -1,6 +1,6 @@
 /*
  *
- *  Copyright (C) 2000-2015, OFFIS e.V.
+ *  Copyright (C) 2000-2013, OFFIS e.V.
  *  All rights reserved.  See COPYRIGHT file for details.
  *
  *  This software and supporting documentation were developed by
@@ -42,12 +42,6 @@ END_EXTERN_C
 #include "dcmtk/dcmtls/tlstrans.h"
 #include "dcmtk/dcmnet/dicom.h"
 
-#ifdef HAVE_SSL_CTX_GET0_PARAM
-#define DCMTK_SSL_CTX_get0_param SSL_CTX_get0_param
-#else
-#define DCMTK_SSL_CTX_get0_param(A) A->param;
-#endif
-
 extern "C" int DcmTLSTransportLayer_certificateValidationCallback(int ok, X509_STORE_CTX *storeContext);
 
 OFLogger DCM_dcmtlsLogger = OFLog::getLogger("dcmtk.dcmtls");
@@ -319,12 +313,6 @@ OFBool DcmTLSTransportLayer::checkPrivateKeyMatchesCertificate()
   return OFFalse;
 }
 
-DcmTransportLayerStatus DcmTLSTransportLayer::addVerificationFlags(unsigned long flags)
-{
-  X509_VERIFY_PARAM* const parameter = DCMTK_SSL_CTX_get0_param(transportLayerContext);
-  return parameter && X509_VERIFY_PARAM_set_flags(parameter,flags) ? TCS_ok : TCS_unspecifiedError;
-}
-
 DcmTransportLayerStatus DcmTLSTransportLayer::addTrustedCertificateFile(const char *fileName, int fileType)
 {
   /* fileType should be SSL_FILETYPE_ASN1 or SSL_FILETYPE_PEM */
@@ -349,26 +337,6 @@ DcmTransportLayerStatus DcmTLSTransportLayer::addTrustedCertificateDir(const cha
   return TCS_ok;
 }
 
-DcmTransportLayerStatus DcmTLSTransportLayer::addTrustedClientCertificateFile(const char *fileName)
-{
-  if (transportLayerContext)
-  {
-    STACK_OF(X509_NAME) *caNames = sk_X509_NAME_dup(SSL_CTX_get_client_CA_list(transportLayerContext));
-    if (caNames == NULL)
-      caNames = sk_X509_NAME_new_null();
-    STACK_OF(X509_NAME) *newCaNames = SSL_load_client_CA_file(fileName);
-    for (int i = 0; i < sk_X509_NAME_num(newCaNames); ++i)
-    {
-      X509_NAME *newCaName = sk_X509_NAME_value(newCaNames,i);
-      if (sk_X509_NAME_find(caNames,newCaName) == -1)
-        sk_X509_NAME_push(caNames,X509_NAME_dup(newCaName));
-    }
-    sk_X509_NAME_pop_free(newCaNames,X509_NAME_free);
-    SSL_CTX_set_client_CA_list(transportLayerContext,caNames);
-  } else return TCS_illegalCall;
-  return TCS_ok;
-}
-
 DcmTransportConnection *DcmTLSTransportLayer::createConnection(int openSocket, OFBool useSecureLayer)
 {
   if (useSecureLayer)
@@ -394,9 +362,7 @@ void DcmTLSTransportLayer::seedPRNG(const char *randFile)
 #endif
   if (randFile)
   {
-#ifdef HAVE_RAND_EGD
     if (RAND_egd(randFile) <= 0)
-#endif
     {
       RAND_load_file(randFile ,-1);
     }
@@ -496,11 +462,6 @@ OFString DcmTLSTransportLayer::dumpX509Certificate(X509 *peerCertificate)
   }
 }
 
-DcmTLSTransportLayer::native_handle_type DcmTLSTransportLayer::getNativeHandle()
-{
-  return transportLayerContext;
-}
-
 #else  /* WITH_OPENSSL */
 
 /* make sure that the object file is not completely empty if compiled
