@@ -1,6 +1,6 @@
 /*
  *
- *  Copyright (C) 1996-2014, OFFIS e.V.
+ *  Copyright (C) 1996-2013, OFFIS e.V.
  *  All rights reserved.  See COPYRIGHT file for details.
  *
  *  This software and supporting documentation were developed by
@@ -260,8 +260,20 @@ WlmConsoleEngineFileSystem::WlmConsoleEngineFileSystem( int argc, char *argv[],
 #endif
 
     cmd->beginOptionBlock();
-    if (cmd->findOption("--enable-new-vr")) dcmEnableGenerationOfNewVRs();
-    if (cmd->findOption("--disable-new-vr")) dcmDisableGenerationOfNewVRs();
+    if( cmd->findOption("--enable-new-vr") )
+    {
+      dcmEnableUnknownVRGeneration.set(OFTrue);
+      dcmEnableUnlimitedTextVRGeneration.set(OFTrue);
+      dcmEnableOtherFloatStringVRGeneration.set(OFTrue);
+      dcmEnableOtherDoubleStringVRGeneration.set(OFTrue);
+    }
+    if( cmd->findOption("--disable-new-vr") )
+    {
+      dcmEnableUnknownVRGeneration.set(OFFalse);
+      dcmEnableUnlimitedTextVRGeneration.set(OFFalse);
+      dcmEnableOtherFloatStringVRGeneration.set(OFFalse);
+      dcmEnableOtherDoubleStringVRGeneration.set(OFFalse);
+    }
     cmd->endOptionBlock();
 
 #ifdef WITH_ZLIB
