@@ -1,6 +1,6 @@
 /*
  *
- *  Copyright (C) 2006-2016, OFFIS e.V.
+ *  Copyright (C) 2006-2014, OFFIS e.V.
  *  All rights reserved.  See COPYRIGHT file for details.
  *
  *  This software and supporting documentation were developed by
@@ -70,36 +70,26 @@ END_EXTERN_C
   #endif
 #endif
 
-// Explicit LFS (LFS64) and Windows need 64 bit types
-#if defined(EXPLICIT_LFS_64) || defined(_WIN32)
-
-// Use POSIX 64 bit file position type when available
-#ifdef HAVE_FPOS64_T
-typedef fpos64_t offile_fpos_t;
-#else // Otherwise this should be sufficient
-typedef fpos_t offile_fpos_t;
-#endif
-
-// Use POSIX 64 bit file offset type when available
-#ifdef HAVE_OFF64_T
-typedef off64_t offile_off_t;
-#elif !defined(OF_NO_SINT64) // Otherwise use a 64 bit integer
-typedef Sint64 offile_off_t;
-#else // Cry when 64 LFS is required but no 64 bit integer exists
-#error \
-  Could not find a suitable offset-type for LFS64 support.
-#endif
-
-#else // Implicit LFS or no LFS
-
-#ifdef HAVE_FSEEKO
-typedef off_t offile_off_t;
+#if defined(_WIN32) && !defined(__MINGW32__)
+  // On Win32 systems except MinGW (where Posix definitions are available)
+  // we use Win32 specific definitions
+  typedef __int64 offile_off_t;
+  typedef fpos_t offile_fpos_t;
 #else
-typedef long offile_off_t;
+  #if defined(EXPLICIT_LFS_64) && !defined(__MINGW64__)
+    // Explicit LFS (LFS64)
+    typedef fpos64_t offile_fpos_t;
+    typedef off64_t offile_off_t;
+  #else
+    // Implicit LFS or no LFS
+    #ifdef HAVE_FSEEKO
+      typedef off_t offile_off_t;
+    #else
+      typedef long offile_off_t;
+    #endif
+    typedef fpos_t offile_fpos_t;
+  #endif
 #endif
-typedef fpos_t offile_fpos_t;
-
-#endif // basic type definitions
 
 // the type we use to store the last error.
 typedef int offile_errno_t;
@@ -140,7 +130,7 @@ public:
    *    alternative representation.  Only works on Windows systems.
    */
   OFFilename(const wchar_t *filename,
-             const OFBool convert = OFTrue);
+             const OFBool convert = OFFalse);
 #endif
 
   /** copy constructor
@@ -226,7 +216,7 @@ public:
    *    representation.  Only works on Windows systems.
    */
   void set(const wchar_t *filename,
-           const OFBool convert = OFTrue);
+           const OFBool convert = OFFalse);
 #endif
 
 private:
@@ -391,10 +381,10 @@ public:
   OFBool popen(const char *command, const char *modes)
   {
     if (file_) fclose();
-#ifdef HAVE_POPEN
-    file_ = :: popen(command, modes);
-#else
+#if defined(_WIN32) && !defined(__MINGW64__)
     file_ = _popen(command, modes);
+#else
+    file_ = :: popen(command, modes);
 #endif
     if (file_) popened_ = OFTrue; else storeLastError();
     return (file_ != NULL);
@@ -455,10 +445,10 @@ public:
     {
       if (popened_)
       {
-#ifdef HAVE_PCLOSE
-        result = :: pclose(file_);
-#else
+#if defined(_WIN32) && !defined(__MINGW64__)
         result = _pclose(file_);
+#else
+        result = :: pclose(file_);
 #endif
       }
       else
