@@ -1,6 +1,6 @@
 /*
  *
- *  Copyright (C) 2001-2015, OFFIS e.V.
+ *  Copyright (C) 2001-2014, OFFIS e.V.
  *  All rights reserved.  See COPYRIGHT file for details.
  *
  *  This software and supporting documentation were developed by
@@ -96,7 +96,6 @@
 #include "dcmtk/ofstd/ofcond.h"
 #include "dcmtk/ofstd/offile.h"
 #include "dcmtk/ofstd/ofstream.h"
-#include "dcmtk/ofstd/oftuple.h"
 
 #define INCLUDE_CMATH
 #define INCLUDE_CFLOAT
@@ -136,15 +135,11 @@ BEGIN_EXTERN_C
 #ifdef HAVE_IEEEFP_H
 #include <ieeefp.h>      /* for finite() on Solaris 2.5.1 */
 #endif
-#ifdef HAVE_SYS_UTSNAME_H
-#include <sys/utsname.h>
-#endif
 END_EXTERN_C
 
 #ifdef HAVE_WINDOWS_H
 #include <windows.h>     /* for GetFileAttributes() */
 #include <direct.h>      /* for _mkdir() */
-#include <lm.h>          /* for NetWkstaUserGetInfo */
 
 #ifndef R_OK /* Windows defines access() but not the constants */
 #define W_OK 02 /* Write permission */
@@ -172,6 +167,61 @@ const unsigned int OFStandard::ftoa_alternate = 0x08;
 const unsigned int OFStandard::ftoa_leftadj   = 0x10;
 const unsigned int OFStandard::ftoa_zeropad   = 0x20;
 
+
+/* Some MacOS X versions define isinf() and isnan() in <math.h> but not in <cmath> */
+#if defined(__APPLE__) && defined(__MACH__) && !defined (__INTEL_COMPILER)
+#undef HAVE_PROTOTYPE_ISINF
+#undef HAVE_PROTOTYPE_ISNAN
+#endif
+
+
+// some systems don't properly define isnan()
+#ifdef HAVE_ISNAN
+#ifndef HAVE_PROTOTYPE_ISNAN
+extern "C"
+{
+  int isnan(double value);
+}
+#endif
+#endif
+
+
+// some systems don't properly define finite()
+#ifdef HAVE_FINITE
+#ifndef HAVE_PROTOTYPE_FINITE
+extern "C"
+{
+  int finite(double value);
+}
+#endif
+#endif
+
+
+// some systems don't properly define isinf()
+#ifdef HAVE_ISINF
+#ifndef HAVE_PROTOTYPE_ISINF
+extern "C"
+{
+  int isinf(double value);
+}
+#endif
+
+#else /* HAVE_ISINF */
+
+static int my_isinf(double x)
+{
+#if defined(DCMTK_USE_CXX11_STL) || ( defined(__MINGW32__) && __cplusplus >= 201103L )
+  return STD_NAMESPACE isinf(x);
+#elif defined(HAVE_WINDOWS_H)
+  return (! _finite(x)) && (! _isnan(x));
+#else
+  // Solaris 2.5.1 has finite() and isnan() but not isinf().
+  return (! finite(x)) && (! isnan(x));
+#endif
+}
+#endif /* HAVE_ISINF */
+
+
 // --- string functions ---
 
 #ifndef HAVE_STRLCPY
@@ -724,8 +774,8 @@ OFFilename &OFStandard::combineDirAndFilename(OFFilename &result,
             OFFilename tmpDirName(result);
             result.set(tmpDirName.getCharPointer(), OFTrue /*convert*/);
         }
-        /* check file name (ignore empty string and ".") */
-        if ((strLength > 1) || ((strLength == 1) && (strValue[0] != L'.')))
+        /* check file name */
+        if ((strLength > 0) && (strValue[0] != L'.'))
         {
             if (result.isEmpty())
                 result.set(strValue, OFTrue /*convert*/);
@@ -777,8 +827,8 @@ OFFilename &OFStandard::combineDirAndFilename(OFFilename &result,
         /* we only get here, if we don't have an absolute directory in "fileName" */
         /* now normalize the directory name */
         normalizeDirName(result, dirName, allowEmptyDirName);
-        /* check file name (ignore empty string and ".") */
-        if ((strLength > 1) || ((strLength == 1) && (strValue[0] != '.')))
+        /* check file name */
+        if ((strLength > 0) && (strValue[0] != '.'))
         {
             if (result.isEmpty())
                 result.set(strValue);
@@ -1084,7 +1134,7 @@ size_t OFStandard::searchDirectoryRecursively(const OFFilename &directory,
         while ((entry = readdir(dirPtr)) != NULL)
 #endif
         {
-            /* filter out current (".") and parent directory ("..") */
+            /* filter out current and parent directory */
             if ((strcmp(entry->d_name, ".") != 0) && (strcmp(entry->d_name, "..") != 0))
             {
                 /* avoid leading "." */
@@ -1934,6 +1984,7 @@ double OFStandard::atof(const char *s, OFBool *success)
 
 #endif /* DISABLE_OFSTD_ATOF */
 
+
 /* 11-bit exponent (VAX G floating point) is 308 decimal digits */
 #define FTOA_MAXEXP          308
 /* 128 bit fraction takes up 39 decimal digits; max reasonable precision */
@@ -1973,14 +2024,22 @@ void OFStandard::ftoa(
   unsigned char fmtch = 'G';
 
   // check if val is NAN
+#ifdef HAVE_WINDOWS_H
+  if (_isnan(val))
+#else
   if (isnan(val))
+#endif
   {
     OFStandard::strlcpy(dst, "nan", siz);
     return;
   }
 
   // check if val is infinity
+#ifdef HAVE_ISINF
   if (isinf(val))
+#else
+  if (my_isinf(val))
+#endif
   {
     if (val < 0)
         OFStandard::strlcpy(dst, "-inf", siz);
@@ -2398,14 +2457,24 @@ void OFStandard::ftoa(
   if (!dst || !siz) return;
 
   // check if val is NAN
-  if (OFStandard::isnan(val))
+#if defined(DCMTK_USE_CXX11_STL) || ( defined(__MINGW32__) && __cplusplus >= 201103L )
+  if (STD_NAMESPACE isnan(val))
+#elif defined(HAVE_WINDOWS_H)
+  if (_isnan(val))
+#else
+  if (isnan(val))
+#endif
   {
     OFStandard::strlcpy(dst, "nan", siz);
     return;
   }
 
   // check if val is infinity
-  if (OFStandard::isinf(val))
+#ifdef HAVE_ISINF
+  if (isinf(val))
+#else
+  if (my_isinf(val))
+#endif
   {
     if (val < 0)
         OFStandard::strlcpy(dst, "-inf", siz);
@@ -2766,9 +2835,7 @@ OFStandard::OFPasswd::OFPasswd( passwd* const p )
         pw_passwd = p->pw_passwd;
         pw_uid    = p->pw_uid;
         pw_gid    = p->pw_gid;
-#ifdef HAVE_PASSWD_GECOS
         pw_gecos  = p->pw_gecos;
-#endif
         pw_dir    = p->pw_dir;
         pw_shell  = p->pw_shell;
     }
@@ -2802,68 +2869,4 @@ OFCondition OFStandard::dropPrivileges()
 #ifndef DCMTK_USE_CXX11_STL
 DCMTK_OFSTD_EXPORT OFnullptr_t OFnullptr;
 DCMTK_OFSTD_EXPORT OFnullopt_t OFnullopt;
-static const OFignore_t OFignore_value;
-DCMTK_OFSTD_EXPORT const OFignore_t& OFignore( OFignore_value );
-OFtuple<> OFmake_tuple() { return OFtuple<>(); }
-OFtuple<> OFtie() { return OFtuple<>(); }
 #endif
-
-
-OFString OFStandard::getUserName()
-{
-#ifdef _WIN32
-    WKSTA_USER_INFO_0 *userinfo;
-    if( NetWkstaUserGetInfo( OFnullptr, 0, OFreinterpret_cast( LPBYTE*, &userinfo ) ) != NERR_Success )
-        return "<no-user-information-available>";
-    // Convert the Unicode full name to ANSI.
-    const WCHAR* const name = OFstatic_cast( WCHAR*, userinfo->wkui0_username );
-    OFVector<char> buf( wcslen( name ) * 2 );
-    WideCharToMultiByte
-    (
-        CP_ACP,
-        0,
-        name,
-        -1,
-        &*buf.begin(),
-        buf.size(),
-        OFnullptr,
-        OFnullptr
-    );
-    return &*buf.begin();
-#elif defined(HAVE_CUSERID)
-    char buf[L_cuserid];
-    return cuserid( buf );
-#elif defined(HAVE_GETLOGIN)
-#if defined(_REENTRANT) && !defined(_WIN32) && !defined(__CYGWIN__)
-    // use getlogin_r instead of getlogin
-    char buf[513];
-    if( getlogin_r( buf, 512 ) != 0 )
-        return "<no-utmp-entry>";
-    buf[512] = 0;
-    return buf;
-#else
-    // thread unsafe
-    if( const char* s = getlogin() )
-        return s;
-    return "<no-utmp-entry>";
-#endif
-#else
-    return "<unknown-user>";
-#endif
-}
-
-OFString OFStandard::getHostName()
-{
-#ifdef HAVE_UNAME
-    struct utsname n;
-    uname( &n );
-    return n.nodename;
-#elif defined(HAVE_GETHOSTNAME)
-    char buf[513];
-    gethostname( buf, 512 );
-    buf[512] = 0;
-    return buf;
-#else
-    return "localhost";
-#endif
-}
